@@ -2,7 +2,6 @@
 # File: api2man.pl
 # Description: Convert the PLplot API chapter (file api.xml of the DocBook
 #              manual) into a swig documentation file.
-# $Id: api2text.pl 11276 2010-10-27 01:39:26Z airwin $
 #
 # Copyright (C) 2000, 2003  Rafael Laboissiere
 # Copyright (C) 2010 Alan W. Irwin
@@ -54,10 +53,26 @@
 #     </para>
 #   </sect1>
 
-#  Call this script by giving the master file (typically
-#  plplotdoc.xml) as the first argument, the API chapter file
-#  (typically api.xml) as the second argument, and output file
-#  (typically swig_documentation.i) as third.
+#  Call this script by giving the swig *.i file defining the
+#  octave binding of PLplot as the first argument, the master file (typically
+#  plplotdoc.xml) as the second argument, and the API chapter file
+#  (typically api.xml) as the third argument, and output file
+#  (typically swig_documentation.i) as the fourth argument.
+
+%rename_hash = ();
+
+open (PLPLOT_OCTAVE_I, "< $ARGV[0]") or die "Can't open $ARGV[0] : $!";
+while( <PLPLOT_OCTAVE_I>){
+    if(/^%rename\( *([\w]*) *\) *([\w]*);$/){
+	$rename_hash{ $1 } = $2;
+    }
+}
+close (PLPLOT_OCTAVE_I);
+
+#print "the complete rename hash is\n";
+#while ( ($key, $value) = each(%rename_hash) ) {
+#    print "$key => $value\n";
+#}
 
 use XML::Parser;
 use XML::DOM;
@@ -67,7 +82,7 @@ use Text::Tabs;
 $tabstop = 4;
 
 $api = "";
-open (MASTER, "< $ARGV[0]");
+open (MASTER, "< $ARGV[1]");
 while (<MASTER>) {
   if (/^(<!DOCTYPE.*)\[/) {
     $api .= "$1 [\n";
@@ -89,7 +104,7 @@ $api .= "<!ENTITY amp '#38;#38;'>
 ]>\n";
 close MASTER;
 
-open (API, "< $ARGV[1]");
+open (API, "< $ARGV[2]");
 $/ = undef;
 $api .= <API>;
 close API;
@@ -171,10 +186,13 @@ $sects = $p->parse ($api)->getElementsByTagName ("sect1");
 my $ns = $sects->getLength;
 $titles = "";
 
-open (MAN, "> $ARGV[2]");
-print MAN "// This file is generated by doc/docbook/src/api2swigdoc.pl from\n";
-print MAN "// doc/docbook/src/api.xml.  Do not modify by hand since this file\n";
-print MAN "// will be overwritten.  Edit doc/docbook/src/api.xml instead.\n\n";
+open (SWIG_DOC, "> $ARGV[3]");
+# Suppress warnings about UTF-8 in SWIG_DOC.
+binmode SWIG_DOC, ':utf8';
+
+print SWIG_DOC "// This file is generated by doc/docbook/src/api2swigdoc.pl from\n";
+print SWIG_DOC "// doc/docbook/src/api.xml.  Do not modify by hand since this file\n";
+print SWIG_DOC "// will be overwritten.  Edit doc/docbook/src/api.xml instead.\n\n";
 for ($i = 0; $i < $ns; $i++) {
   $fun = $sects->item ($i);
   $name = $fun->getAttribute ("id");
@@ -214,18 +232,27 @@ for ($i = 0; $i < $ns; $i++) {
                            s/\t/    /g;
                            $_;
                          } split ("\n", $varlist));
-  # Get rid of preceding name identifier followed by ":" that is normally
-  # part of the raw title in api.xml.
-  $title =~s/^.*: //;
+  # Get rid of preceding name identifier followed by ":" and any extra
+  # blanks that is normally part of the raw title in api.xml.
+  $title =~s/^.*: *//;
 
   # Escape double quotes in description and arguments
   $desc =~ s/\"/\\"/g;
   $varlist =~ s/\"/\\"/g;
-  print MAN "%feature( \"docstring\", \"$title\n";
-  print MAN "\nDESCRIPTION:\n\n$desc\n";
-  print MAN "\nSYNOPSIS:\n\n$synopsis\n";
-  print MAN "\nARGUMENTS:\n\n$varlist\n"
+  print SWIG_DOC "%feature( \"docstring\", \"$title\n";
+  print SWIG_DOC "\nDESCRIPTION:\n\n$desc\n";
+  print SWIG_DOC "\nSYNOPSIS:\n\n$synopsis\n";
+  print SWIG_DOC "\nARGUMENTS:\n\n$varlist\n"
     if not $varlist eq "";
-  print MAN "\")\n$name;\n\n";
+  print SWIG_DOC "\")\n";
+  if(exists  $rename_hash{ $name } ) {
+      print SWIG_DOC "#ifdef SWIG_OCTAVE\n";
+      print SWIG_DOC "$rename_hash{ $name };\n";
+      print SWIG_DOC "#else\n";
+      print SWIG_DOC "$name;\n";
+      print SWIG_DOC "#endif\n\n";
+  } else {
+      print SWIG_DOC "$name;\n\n";
+  }
 }
-close MAN;
+close SWIG_DOC;
