@@ -3,13 +3,15 @@ var classplplot =
     [ "pladv", "interfaceplplot_1_1pladv.html", "interfaceplplot_1_1pladv" ],
     [ "plbin", "interfaceplplot_1_1plbin.html", "interfaceplplot_1_1plbin" ],
     [ "plbop", "interfaceplplot_1_1plbop.html", "interfaceplplot_1_1plbop" ],
+    [ "plbtime", "interfaceplplot_1_1plbtime.html", "interfaceplplot_1_1plbtime" ],
     [ "plcalc_world", "interfaceplplot_1_1plcalc__world.html", "interfaceplplot_1_1plcalc__world" ],
     [ "plclear", "interfaceplplot_1_1plclear.html", "interfaceplplot_1_1plclear" ],
     [ "plcol0", "interfaceplplot_1_1plcol0.html", "interfaceplplot_1_1plcol0" ],
     [ "plcol1", "interfaceplplot_1_1plcol1.html", "interfaceplplot_1_1plcol1" ],
     [ "plcolorbar", "interfaceplplot_1_1plcolorbar.html", "interfaceplplot_1_1plcolorbar" ],
+    [ "plconfigtime", "interfaceplplot_1_1plconfigtime.html", "interfaceplplot_1_1plconfigtime" ],
     [ "plcpstrm", "interfaceplplot_1_1plcpstrm.html", "interfaceplplot_1_1plcpstrm" ],
-    [ "plend", "interfaceplplot_1_1plend.html", "interfaceplplot_1_1plend" ],
+    [ "plctime", "interfaceplplot_1_1plctime.html", "interfaceplplot_1_1plctime" ],
     [ "plend1", "interfaceplplot_1_1plend1.html", "interfaceplplot_1_1plend1" ],
     [ "plenv", "interfaceplplot_1_1plenv.html", "interfaceplplot_1_1plenv" ],
     [ "pleop", "interfaceplplot_1_1pleop.html", "interfaceplplot_1_1pleop" ],
@@ -58,6 +60,10 @@ var classplplot =
     [ "plline3", "interfaceplplot_1_1plline3.html", "interfaceplplot_1_1plline3" ],
     [ "pllsty", "interfaceplplot_1_1pllsty.html", "interfaceplplot_1_1pllsty" ],
     [ "plmap", "interfaceplplot_1_1plmap.html", "interfaceplplot_1_1plmap" ],
+    [ "plmapfill", "interfaceplplot_1_1plmapfill.html", "interfaceplplot_1_1plmapfill" ],
+    [ "plmapline", "interfaceplplot_1_1plmapline.html", "interfaceplplot_1_1plmapline" ],
+    [ "plmapstring", "interfaceplplot_1_1plmapstring.html", "interfaceplplot_1_1plmapstring" ],
+    [ "plmaptex", "interfaceplplot_1_1plmaptex.html", "interfaceplplot_1_1plmaptex" ],
     [ "plmeridians", "interfaceplplot_1_1plmeridians.html", "interfaceplplot_1_1plmeridians" ],
     [ "plmesh", "interfaceplplot_1_1plmesh.html", "interfaceplplot_1_1plmesh" ],
     [ "plmeshc", "interfaceplplot_1_1plmeshc.html", "interfaceplplot_1_1plmeshc" ],
