@@ -74,6 +74,10 @@ var classplplot_1_1core_1_1PLStream =
     [ "line3", "classplplot_1_1core_1_1PLStream.html#aac6cbede200f4ceb5630f36886c1d99c", null ],
     [ "lsty", "classplplot_1_1core_1_1PLStream.html#a972e089112cb93d4497c523cfa1c26fa", null ],
     [ "map", "classplplot_1_1core_1_1PLStream.html#a7e048d1d5ae31ffa9bae5bac032b9047", null ],
+    [ "mapfill", "classplplot_1_1core_1_1PLStream.html#ad0c3c19f75184750f981703167aa3d50", null ],
+    [ "mapline", "classplplot_1_1core_1_1PLStream.html#a0f97a738a8c711463fbfd8446aa34fad", null ],
+    [ "mapstring", "classplplot_1_1core_1_1PLStream.html#a91be867b9cee0ae295de464b3aa69f1e", null ],
+    [ "maptex", "classplplot_1_1core_1_1PLStream.html#a6ea14b79d4628e0c163918ce1356611b", null ],
     [ "meridians", "classplplot_1_1core_1_1PLStream.html#a7d3305012f5956cbd2ccb7d6bbf166a2", null ],
     [ "mesh", "classplplot_1_1core_1_1PLStream.html#a8c4ba1056b1b1d2379d3ad1ebd534d98", null ],
     [ "meshc", "classplplot_1_1core_1_1PLStream.html#a326cadbcaac308d945efd1812477c99f", null ],
@@ -181,6 +185,7 @@ var classplplot_1_1core_1_1PLStream =
     [ "vpor", "classplplot_1_1core_1_1PLStream.html#a68f6f3430b9e23cadf32be4ee987dfc9", null ],
     [ "vsta", "classplplot_1_1core_1_1PLStream.html#a94b0cf12968032aedb1419a4c274f5c0", null ],
     [ "w3d", "classplplot_1_1core_1_1PLStream.html#ab9cace93368bb2c75e80bc40ea614880", null ],
+    [ "width", "classplplot_1_1core_1_1PLStream.html#a55792ad22e042bc8f3a0ea8f1effb401", null ],
     [ "width", "classplplot_1_1core_1_1PLStream.html#a33e0353dc3495c37f208c58d1206b3bc", null ],
     [ "wind", "classplplot_1_1core_1_1PLStream.html#a9ff162968aefdc6773fb263e09fdf02c", null ],
     [ "xormod", "classplplot_1_1core_1_1PLStream.html#ae492899fa93e15c29a853ae786fdee79", null ],
