@@ -74,7 +74,11 @@ var classplplot_1_1core_1_1plplotjavac =
     [ "plline", "classplplot_1_1core_1_1plplotjavac.html#ab7dbdfc180f1cad5adb35ab9d92083ca", null ],
     [ "plline3", "classplplot_1_1core_1_1plplotjavac.html#a18e7df412f9a725e50684efa3ccbd5aa", null ],
     [ "pllsty", "classplplot_1_1core_1_1plplotjavac.html#ae17fd662887448e065e219dee2364f3e", null ],
-    [ "plmap", "classplplot_1_1core_1_1plplotjavac.html#a2b3d5d990d90cb11bf2bbe0acd08581f", null ],
+    [ "plmap", "classplplot_1_1core_1_1plplotjavac.html#aa4687f4117e361df48340ad46225801c", null ],
+    [ "plmapfill", "classplplot_1_1core_1_1plplotjavac.html#ae47c6fa53755b03fa432a766f2a84966", null ],
+    [ "plmapline", "classplplot_1_1core_1_1plplotjavac.html#af6bebf1541e99ff524672adb8b469f18", null ],
+    [ "plmapstring", "classplplot_1_1core_1_1plplotjavac.html#ae664bf83af75601d394ef911ce09fc8f", null ],
+    [ "plmaptex", "classplplot_1_1core_1_1plplotjavac.html#a247faebeaa76422476d5c92d94d5c0dc", null ],
     [ "plmeridians", "classplplot_1_1core_1_1plplotjavac.html#a816ca5e59bdabea5f6cb37dfb58b8ddf", null ],
     [ "plmesh", "classplplot_1_1core_1_1plplotjavac.html#aa352a17675fc17234aa4d9975c027099", null ],
     [ "plmeshc", "classplplot_1_1core_1_1plplotjavac.html#a376d0f1e234b1ac944c46d51c19f2c88", null ],
@@ -168,7 +172,7 @@ var classplplot_1_1core_1_1plplotjavac =
     [ "plvpor", "classplplot_1_1core_1_1plplotjavac.html#af9f58e19b12874eb0545bb04658c1556", null ],
     [ "plvsta", "classplplot_1_1core_1_1plplotjavac.html#a2b7967478f182ce1c420445561fc6c78", null ],
     [ "plw3d", "classplplot_1_1core_1_1plplotjavac.html#ad2a04faea2371864eca40b85711367b5", null ],
-    [ "plwidth", "classplplot_1_1core_1_1plplotjavac.html#a35421de2c176d5e44ecf2a671ef9aa23", null ],
+    [ "plwidth", "classplplot_1_1core_1_1plplotjavac.html#adb3bab18ff8e5c5d73db1cc3dd661d9e", null ],
     [ "plwind", "classplplot_1_1core_1_1plplotjavac.html#a99a19baca13a1998142ee0081e6c7282", null ],
     [ "plxormod", "classplplot_1_1core_1_1plplotjavac.html#a620fa8b9a963e5797d55c966df1912fb", null ]
 ];
\ No newline at end of file
