@@ -138,6 +138,7 @@ var classplplot_1_1core_1_1plplotjavacJNI =
     [ "plerrx", "classplplot_1_1core_1_1plplotjavacJNI.html#ac3a4980f635edf3f944482182d8b1a3f", null ],
     [ "plerry", "classplplot_1_1core_1_1plplotjavacJNI.html#abac95a0af408299a3a95279266748610", null ],
     [ "PLESC_ALLOC_NCOL_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aea9edda1459fc3b18580eb7dbd1d90b7", null ],
+    [ "PLESC_APPEND_BUFFER_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a14381d0419a637627eb8074999705b6c", null ],
     [ "PLESC_ARC_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aa36fe8ff9f5a8858461c76a210c8d2a3", null ],
     [ "PLESC_BEGIN_TEXT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a0d17f2a2737c3cd9ad5543567e5b1b0a", null ],
     [ "PLESC_CLEAR_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a0a1d8b30487470d1bd73175c7e23d745", null ],
@@ -155,7 +156,9 @@ var classplplot_1_1core_1_1plplotjavacJNI =
     [ "PLESC_END_TEXT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a2bd2c9bb5ec143edfd7daec94e8554c2", null ],
     [ "PLESC_EXPOSE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a066276ed94e38039312083208ba265e9", null ],
     [ "PLESC_FILL_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a0b39c36a8a969fa12467a41e952e7510", null ],
+    [ "PLESC_FIXASPECT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#adc0374d67e34260fb6ce8def7c0ef181", null ],
     [ "PLESC_FLUSH_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aff852a6595dfe67e61e864430cf83cb6", null ],
+    [ "PLESC_FLUSH_REMAINING_BUFFER_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aae9e3b0a42e98d6871a9da78e159d7f7", null ],
     [ "PLESC_GETBACKEND_get", "classplplot_1_1core_1_1plplotjavacJNI.html#abca643e49c0e7c5ebf91aabe490e4142", null ],
     [ "PLESC_GETC_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aa3b0aa3fd019c150dd61c921866003cd", null ],
     [ "PLESC_GRADIENT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a8900c4341b2490cab3aaeb440a93865d", null ],
@@ -163,6 +166,7 @@ var classplplot_1_1core_1_1plplotjavacJNI =
     [ "PLESC_HAS_TEXT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aad01df012951b7efb2233edbd9f52d16", null ],
     [ "PLESC_IMAGE_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a2c074e1f1436d34676e95331e6282740", null ],
     [ "PLESC_IMAGEOPS_get", "classplplot_1_1core_1_1plplotjavacJNI.html#aec0a63e4fd5a6bab2c36fb49af547286", null ],
+    [ "PLESC_IMPORT_BUFFER_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a4fd56258635ed584c6950a3a1d702404", null ],
     [ "PLESC_MODEGET_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a9abc59d742b9c4b9cd382632dd9a361e", null ],
     [ "PLESC_MODESET_get", "classplplot_1_1core_1_1plplotjavacJNI.html#abcb01ce92c17e8d0e4c9deba5d80f1ee", null ],
     [ "PLESC_PL2DEVCOL_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a37f26a846af5f16f81430d6e65af1e8f", null ],
@@ -249,6 +253,10 @@ var classplplot_1_1core_1_1plplotjavacJNI =
     [ "plline3", "classplplot_1_1core_1_1plplotjavacJNI.html#a4dbcc1f886f82f70cfb5216311d2d823", null ],
     [ "pllsty", "classplplot_1_1core_1_1plplotjavacJNI.html#a649aa5680159ea5e3abac44b1a61757e", null ],
     [ "plmap", "classplplot_1_1core_1_1plplotjavacJNI.html#abc69bb4b4bdde4a75222bde94ad667f7", null ],
+    [ "plmapfill", "classplplot_1_1core_1_1plplotjavacJNI.html#ae65d5a5d3e5f356dc28cebdf2acc10b9", null ],
+    [ "plmapline", "classplplot_1_1core_1_1plplotjavacJNI.html#aae104760a2036531776c64b6409ab6ff", null ],
+    [ "plmapstring", "classplplot_1_1core_1_1plplotjavacJNI.html#ac4686b5179570ecf8f50d556bd9e38b6", null ],
+    [ "plmaptex", "classplplot_1_1core_1_1plplotjavacJNI.html#af6022f29e0dfd0482d2ea9b92c1c482f", null ],
     [ "plmeridians", "classplplot_1_1core_1_1plplotjavacJNI.html#aeb62093153bf894d263a6aad628e5ba9", null ],
     [ "plmesh", "classplplot_1_1core_1_1plplotjavacJNI.html#abe05ea069c29a7d8ae005f6f7fc5ba32", null ],
     [ "plmeshc", "classplplot_1_1core_1_1plplotjavacJNI.html#a0e514d9afdebbe7fff032391f9f11fbf", null ],
@@ -350,7 +358,7 @@ var classplplot_1_1core_1_1plplotjavacJNI =
     [ "plvpor", "classplplot_1_1core_1_1plplotjavacJNI.html#a97d910743b2b154e199480c077822f5a", null ],
     [ "plvsta", "classplplot_1_1core_1_1plplotjavacJNI.html#a522a271673e4bd05ac3632895e03fd65", null ],
     [ "plw3d", "classplplot_1_1core_1_1plplotjavacJNI.html#ac923fef3a89354581c8cf10e0b3b0894", null ],
-    [ "plwidth", "classplplot_1_1core_1_1plplotjavacJNI.html#a06324b5e37545d21871e57755c12474c", null ],
+    [ "plwidth", "classplplot_1_1core_1_1plplotjavacJNI.html#a32ac5d4111d4ba92b11ce1fd3f96084e", null ],
     [ "plwind", "classplplot_1_1core_1_1plplotjavacJNI.html#ae11ef2c78ca7f87b62228dcaa3f913c6", null ],
     [ "plxormod", "classplplot_1_1core_1_1plplotjavacJNI.html#a51d17bd4551d4809ce6027332a0b1576", null ],
     [ "SURF_CONT_get", "classplplot_1_1core_1_1plplotjavacJNI.html#a8aefa8e92cbfa3f414b2098fcf441ca6", null ],
