@@ -99,7 +99,11 @@ var classplstream =
     [ "line", "classplstream.html#ab94015dfd576f331c581d6389368d013", null ],
     [ "line3", "classplstream.html#a2e15a0c1823c1c405353603ed7311ce4", null ],
     [ "lsty", "classplstream.html#a4a571952c811953cba099f45bcbe3eed", null ],
-    [ "map", "classplstream.html#a651bd9dd38285d2eabbdba3419924506", null ],
+    [ "map", "classplstream.html#a3f7b258f7f6e05c69d7f87f088a3070d", null ],
+    [ "mapfill", "classplstream.html#af9ad80e5cb56b3db6e2b84aef1776f91", null ],
+    [ "mapline", "classplstream.html#afbc42d619c901c9ed8aeca521031e0f5", null ],
+    [ "mapstring", "classplstream.html#ae4a7e75e95f44fbdd0c7c3a30d1d6bc8", null ],
+    [ "maptex", "classplstream.html#a267d023c22958c524f145657db3819e3", null ],
     [ "MergeOpts", "classplstream.html#aa4b6c18444bf29ac7de17528c97ea388", null ],
     [ "meridians", "classplstream.html#ae825893fb4fc81d97a9352c7e06b2b60", null ],
     [ "mesh", "classplstream.html#aef940236ed0723c5d3342f1f443e1584", null ],
@@ -148,6 +152,7 @@ var classplstream =
     [ "scolor", "classplstream.html#a84ef4d99ad19875b8cdd8bd981da11c7", null ],
     [ "scompression", "classplstream.html#a36776b135f2944457d425137e5cf74b6", null ],
     [ "sdev", "classplstream.html#a7d20d33e51027b1f9f51741e3077118a", null ],
+    [ "sdevdata", "classplstream.html#a1cf1d9758ff57dc3e28edcad96c14b86", null ],
     [ "sdidev", "classplstream.html#ae543f281616cc859ef0df3dcbd69f596", null ],
     [ "sdimap", "classplstream.html#a1a602824a9006c3f738604a4896157b6", null ],
     [ "sdiori", "classplstream.html#a78c74852bf35b9702a6dcd93d42234d4", null ],
@@ -214,10 +219,6 @@ var classplstream =
     [ "szax", "classplstream.html#aa1deeb534cd28668cbf878782d205119", null ],
     [ "text", "classplstream.html#a3cdd797ab78f23697ba7a349dc0f0e74", null ],
     [ "timefmt", "classplstream.html#a748813a8db4e3cc186b5d9fae8538c39", null ],
-    [ "tr0", "classplstream.html#a2c4b8d115749666eaf55eff4c76926ec", null ],
-    [ "tr1", "classplstream.html#a42a2e792b9a60193c335aa7e6543b86a", null ],
-    [ "tr2", "classplstream.html#a8220e4e66a54eb70e152f8b943c0a6eb", null ],
-    [ "tr2p", "classplstream.html#afbd3996bfd02a5c4c7f6f1d85405930a", null ],
     [ "vasp", "classplstream.html#a18f26cc66fed4937f5bfc6267672b4f3", null ],
     [ "vect", "classplstream.html#ad7446f51202251dc368b1f95ea523953", null ],
     [ "vpas", "classplstream.html#a99cca3086170b0961ced3f6f64fa3166", null ],
