@@ -16,8 +16,6 @@ var files =
     [ "config.java", "config_8java.html", [
       [ "config", "classplplot_1_1core_1_1config.html", "classplplot_1_1core_1_1config" ]
     ] ],
-    [ "configurable.f90", "configurable_8f90.html", "configurable_8f90" ],
-    [ "cplplotcanvasmodule.c", "cplplotcanvasmodule_8c.html", "cplplotcanvasmodule_8c" ],
     [ "csa.c", "csa_8c.html", "csa_8c" ],
     [ "csa.h", "csa_8h.html", "csa_8h" ],
     [ "csadll.h", "csadll_8h.html", "csadll_8h" ],
@@ -27,7 +25,6 @@ var files =
     [ "deltaT-gen.c", "deltaT-gen_8c.html", "deltaT-gen_8c" ],
     [ "deltaT.h", "deltaT_8h.html", "deltaT_8h" ],
     [ "deltaT_test.c", "deltaT__test_8c.html", "deltaT__test_8c" ],
-    [ "dg300.c", "dg300_8c.html", "dg300_8c" ],
     [ "dirent_msvc.h", "dirent__msvc_8h.html", "dirent__msvc_8h" ],
     [ "disptab.h", "disptab_8h.html", "disptab_8h" ],
     [ "drivers.h", "drivers_8h.html", "drivers_8h" ],
@@ -35,25 +32,15 @@ var files =
     [ "dspline.h", "dspline_8h.html", "dspline_8h" ],
     [ "dsplint.c", "dsplint_8c.html", "dsplint_8c" ],
     [ "dsplint.h", "dsplint_8h.html", "dsplint_8h" ],
-    [ "gcw-lib.c", "gcw-lib_8c.html", "gcw-lib_8c" ],
-    [ "gcw.c", "gcw_8c.html", "gcw_8c" ],
-    [ "gcw.h", "gcw_8h.html", "gcw_8h" ],
-    [ "gcwmodule.c", "gcwmodule_8c.html", "gcwmodule_8c" ],
     [ "gd.c", "gd_8c.html", "gd_8c" ],
     [ "hash.c", "hash_8c.html", "hash_8c" ],
     [ "hash.h", "hash_8h.html", "hash_8h" ],
-    [ "hpgl.c", "hpgl_8c.html", "hpgl_8c" ],
-    [ "impress.c", "impress_8c.html", "impress_8c" ],
     [ "istack.c", "istack_8c.html", "istack_8c" ],
     [ "istack.h", "istack_8h.html", "istack_8h" ],
-    [ "linuxvga.c", "linuxvga_8c.html", "linuxvga_8c" ],
-    [ "ljii.c", "ljii_8c.html", "ljii_8c" ],
-    [ "ljiip.c", "ljiip_8c.html", "ljiip_8c" ],
     [ "lpi.c", "lpi_8c.html", "lpi_8c" ],
     [ "ltdl_win32.c", "ltdl__win32_8c.html", "ltdl__win32_8c" ],
     [ "ltdl_win32.h", "ltdl__win32_8h.html", "ltdl__win32_8h" ],
     [ "makedocstrings.py", "makedocstrings_8py.html", "makedocstrings_8py" ],
-    [ "massage.c", "massage_8c.html", "massage_8c" ],
     [ "matrixInit.c", "matrixInit_8c.html", "matrixInit_8c" ],
     [ "mem.c", "mem_8c.html", null ],
     [ "metadefs.h", "metadefs_8h.html", "metadefs_8h" ],
@@ -69,7 +56,6 @@ var files =
     [ "nnpi.c", "nnpi_8c.html", "nnpi_8c" ],
     [ "ntk.c", "ntk_8c.html", "ntk_8c" ],
     [ "null.c", "null_8c.html", "null_8c" ],
-    [ "pbm.c", "pbm_8c.html", "pbm_8c" ],
     [ "pdf.c", "pdf_8c.html", "pdf_8c" ],
     [ "pdf.h", "pdf_8h.html", "pdf_8h" ],
     [ "pdfutils.c", "pdfutils_8c.html", "pdfutils_8c" ],
@@ -95,7 +81,6 @@ var files =
     [ "plctrl.c", "plctrl_8c.html", "plctrl_8c" ],
     [ "plcvt.c", "plcvt_8c.html", "plcvt_8c" ],
     [ "pldebug.h", "pldebug_8h.html", "pldebug_8h" ],
-    [ "pldeprecated.c", "pldeprecated_8c.html", null ],
     [ "plDevs.h", "plDevs_8h.html", "plDevs_8h" ],
     [ "pldll.h", "pldll_8h.html", "pldll_8h" ],
     [ "pldtik.c", "pldtik_8c.html", "pldtik_8c" ],
@@ -119,26 +104,23 @@ var files =
     [ "pllegend.c", "pllegend_8c.html", "pllegend_8c" ],
     [ "plline.c", "plline_8c.html", "plline_8c" ],
     [ "plmap.c", "plmap_8c.html", "plmap_8c" ],
+    [ "plmem.c", "plmem_8c.html", "plmem_8c" ],
     [ "plmeta.c", "plmeta_8c.html", "plmeta_8c" ],
+    [ "plmetafile.c", "plmetafile_8c.html", "plmetafile_8c" ],
     [ "plot3d.c", "plot3d_8c.html", "plot3d_8c" ],
     [ "plpage.c", "plpage_8c.html", "plpage_8c" ],
+    [ "plparseopts.f90", "plparseopts_8f90.html", "plparseopts_8f90" ],
     [ "plplot.d", "plplot_8d.html", "plplot_8d" ],
     [ "plplot.h", "plplot_8h.html", "plplot_8h" ],
     [ "plplot_config.h", "plplot__config_8h.html", "plplot__config_8h" ],
     [ "plplot_impl.c", "plplot__impl_8c.html", "plplot__impl_8c" ],
-    [ "plplot_octave.h", "plplot__octave_8h.html", "plplot__octave_8h" ],
-    [ "plplot_octave_rej.h", "plplot__octave__rej_8h.html", "plplot__octave__rej_8h" ],
     [ "plplot_octaveOCTAVE_wrap.cxx", "plplot__octaveOCTAVE__wrap_8cxx.html", "plplot__octaveOCTAVE__wrap_8cxx" ],
     [ "plplot_parameters.h", "plplot__parameters_8h.html", "plplot__parameters_8h" ],
+    [ "plplot_types.f90", "plplot__types_8f90.html", [
+      [ "plplot_types", "classplplot__types.html", "classplplot__types" ]
+    ] ],
     [ "plplot_widgetmodule.c", "plplot__widgetmodule_8c.html", "plplot__widgetmodule_8c" ],
     [ "plplotc.py", "plplotc_8py.html", "plplotc_8py" ],
-    [ "plplotcanvas-hacktext.c", "plplotcanvas-hacktext_8c.html", "plplotcanvas-hacktext_8c" ],
-    [ "plplotcanvas-hacktext.h", "plplotcanvas-hacktext_8h.html", "plplotcanvas-hacktext_8h" ],
-    [ "plplotcanvas.c", "plplotcanvas_8c.html", "plplotcanvas_8c" ],
-    [ "plplotcanvas.h", "plplotcanvas_8h.html", "plplotcanvas_8h" ],
-    [ "plplotcanvas.py", "plplotcanvas_8py.html", [
-      [ "Canvas", "classplplotcanvas_1_1Canvas.html", "classplplotcanvas_1_1Canvas" ]
-    ] ],
     [ "plplotcmodulePYTHON_wrap.c", "plplotcmodulePYTHON__wrap_8c.html", "plplotcmodulePYTHON__wrap_8c" ],
     [ "plplotjavac.java", "plplotjavac_8java.html", [
       [ "plplotjavac", "classplplot_1_1core_1_1plplotjavac.html", "classplplot_1_1core_1_1plplotjavac" ]
@@ -152,6 +134,8 @@ var files =
     ] ],
     [ "plplotluacLUA_wrap.c", "plplotluacLUA__wrap_8c.html", "plplotluacLUA__wrap_8c" ],
     [ "plplotP.h", "plplotP_8h.html", "plplotP_8h" ],
+    [ "plplotqt.h", "plplotqt_8h.html", null ],
+    [ "plplotqt_smoke.h", "plplotqt__smoke_8h.html", "plplotqt__smoke_8h" ],
     [ "plplotter.c", "plplotter_8c.html", "plplotter_8c" ],
     [ "Plplotter_Init.c", "Plplotter__Init_8c.html", "Plplotter__Init_8c" ],
     [ "plqt.cpp", "plqt_8cpp.html", "plqt_8cpp" ],
@@ -202,9 +186,7 @@ var files =
     [ "sc3d.c", "sc3d_8c.html", "sc3d_8c" ],
     [ "sccont.c", "sccont_8c.html", "sccont_8c" ],
     [ "scstubs.c", "scstubs_8c.html", "scstubs_8c" ],
-    [ "sfstubs.f90", "sfstubs_8f90.html", "sfstubs_8f90" ],
     [ "sfstubsf95.f90", "sfstubsf95_8f90.html", [
-      [ "plplot_flt", "classplplot__flt.html", null ],
       [ "plplot_str", "classplplot__str.html", "classplplot__str" ],
       [ "plplotp", "classplplotp.html", [
         [ "plcont", "interfaceplplotp_1_1plcont.html", "interfaceplplotp_1_1plcont" ],
@@ -218,21 +200,23 @@ var files =
       [ "plshade", "interfaceplplotp_1_1plshade.html", "interfaceplplotp_1_1plshade" ],
       [ "plshades", "interfaceplplotp_1_1plshades.html", "interfaceplplotp_1_1plshades" ],
       [ "plimagefr", "interfaceplplotp_1_1plimagefr.html", "interfaceplplotp_1_1plimagefr" ],
-      [ "plplot_types", "classplplot__types.html", [
-        [ "plgraphicsin", "structplplot__types_1_1plgraphicsin.html", "structplplot__types_1_1plgraphicsin" ]
+      [ "plplot_graphics", "classplplot__graphics.html", [
+        [ "plgraphicsin", "structplplot__graphics_1_1plgraphicsin.html", "structplplot__graphics_1_1plgraphicsin" ]
       ] ],
-      [ "plgraphicsin", "structplplot__types_1_1plgraphicsin.html", "structplplot__types_1_1plgraphicsin" ],
+      [ "plgraphicsin", "structplplot__graphics_1_1plgraphicsin.html", "structplplot__graphics_1_1plgraphicsin" ],
       [ "plplot", "classplplot.html", "classplplot" ],
       [ "pladv", "interfaceplplot_1_1pladv.html", "interfaceplplot_1_1pladv" ],
       [ "plbin", "interfaceplplot_1_1plbin.html", "interfaceplplot_1_1plbin" ],
       [ "plbop", "interfaceplplot_1_1plbop.html", "interfaceplplot_1_1plbop" ],
+      [ "plbtime", "interfaceplplot_1_1plbtime.html", "interfaceplplot_1_1plbtime" ],
       [ "plcalc_world", "interfaceplplot_1_1plcalc__world.html", "interfaceplplot_1_1plcalc__world" ],
       [ "plclear", "interfaceplplot_1_1plclear.html", "interfaceplplot_1_1plclear" ],
       [ "plcol0", "interfaceplplot_1_1plcol0.html", "interfaceplplot_1_1plcol0" ],
       [ "plcol1", "interfaceplplot_1_1plcol1.html", "interfaceplplot_1_1plcol1" ],
       [ "plcolorbar", "interfaceplplot_1_1plcolorbar.html", "interfaceplplot_1_1plcolorbar" ],
+      [ "plconfigtime", "interfaceplplot_1_1plconfigtime.html", "interfaceplplot_1_1plconfigtime" ],
       [ "plcpstrm", "interfaceplplot_1_1plcpstrm.html", "interfaceplplot_1_1plcpstrm" ],
-      [ "plend", "interfaceplplot_1_1plend.html", "interfaceplplot_1_1plend" ],
+      [ "plctime", "interfaceplplot_1_1plctime.html", "interfaceplplot_1_1plctime" ],
       [ "plend1", "interfaceplplot_1_1plend1.html", "interfaceplplot_1_1plend1" ],
       [ "plenv", "interfaceplplot_1_1plenv.html", "interfaceplplot_1_1plenv" ],
       [ "pleop", "interfaceplplot_1_1pleop.html", "interfaceplplot_1_1pleop" ],
@@ -281,6 +265,10 @@ var files =
       [ "plline3", "interfaceplplot_1_1plline3.html", "interfaceplplot_1_1plline3" ],
       [ "pllsty", "interfaceplplot_1_1pllsty.html", "interfaceplplot_1_1pllsty" ],
       [ "plmap", "interfaceplplot_1_1plmap.html", "interfaceplplot_1_1plmap" ],
+      [ "plmapline", "interfaceplplot_1_1plmapline.html", "interfaceplplot_1_1plmapline" ],
+      [ "plmapfill", "interfaceplplot_1_1plmapfill.html", "interfaceplplot_1_1plmapfill" ],
+      [ "plmapstring", "interfaceplplot_1_1plmapstring.html", "interfaceplplot_1_1plmapstring" ],
+      [ "plmaptex", "interfaceplplot_1_1plmaptex.html", "interfaceplplot_1_1plmaptex" ],
       [ "plmeridians", "interfaceplplot_1_1plmeridians.html", "interfaceplplot_1_1plmeridians" ],
       [ "plmesh", "interfaceplplot_1_1plmesh.html", "interfaceplplot_1_1plmesh" ],
       [ "plmeshc", "interfaceplplot_1_1plmeshc.html", "interfaceplplot_1_1plmeshc" ],
@@ -340,8 +328,10 @@ var files =
       [ "plstripd", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripd.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripd" ],
       [ "plstyl", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstyl.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstyl" ],
       [ "plsurf3d", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsurf3d.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsurf3d" ],
+      [ "plsurf3dl", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsurf3dl.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsurf3dl" ],
       [ "plstripc", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripc.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripc" ],
       [ "plsvect", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvect.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvect" ],
+      [ "plsvect", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvect.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvect" ],
       [ "plsvpa", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvpa.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvpa" ],
       [ "plsxax", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsxax.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsxax" ],
       [ "plsyax", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsyax.html", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsyax" ],
@@ -367,14 +357,13 @@ var files =
     [ "tclAPI.c", "tclAPI_8c.html", "tclAPI_8c" ],
     [ "tclgen.c", "tclgen_8c.html", "tclgen_8c" ],
     [ "tclgen.h", "tclgen_8h.html", "tclgen_8h" ],
-    [ "tclgen_s.h", "tclgen__s_8h.html", null ],
+    [ "tclgen_s.h", "tclgen__s_8h.html", "tclgen__s_8h" ],
     [ "tclMain.c", "tclMain_8c.html", "tclMain_8c" ],
     [ "tclMatrix.c", "tclMatrix_8c.html", "tclMatrix_8c" ],
     [ "tclMatrix.h", "tclMatrix_8h.html", "tclMatrix_8h" ],
     [ "TclSup.py", "TclSup_8py.html", "TclSup_8py" ],
     [ "tcpip.c", "tcpip_8c.html", "tcpip_8c" ],
     [ "tcpip.h", "tcpip_8h.html", "tcpip_8h" ],
-    [ "tek.c", "tek_8c.html", "tek_8c" ],
     [ "test-drv-info.c", "test-drv-info_8c.html", "test-drv-info_8c" ],
     [ "tk.c", "tk_8c.html", "tk_8c" ],
     [ "tkMain.c", "tkMain_8c.html", "tkMain_8c" ],
@@ -385,16 +374,14 @@ var files =
     [ "wingcc.c", "wingcc_8c.html", "wingcc_8c" ],
     [ "wxPLplotstream.cpp", "wxPLplotstream_8cpp.html", null ],
     [ "wxPLplotstream.h", "wxPLplotstream_8h.html", "wxPLplotstream_8h" ],
-    [ "wxPLplotwindow.cpp", "wxPLplotwindow_8cpp.html", null ],
     [ "wxPLplotwindow.h", "wxPLplotwindow_8h.html", [
       [ "wxPLplotwindow", "classwxPLplotwindow.html", "classwxPLplotwindow" ]
     ] ],
     [ "wxwidgets.cpp", "wxwidgets_8cpp.html", "wxwidgets_8cpp" ],
     [ "wxwidgets.h", "wxwidgets_8h.html", "wxwidgets_8h" ],
-    [ "wxwidgets_agg.cpp", "wxwidgets__agg_8cpp.html", "wxwidgets__agg_8cpp" ],
-    [ "wxwidgets_app.cpp", "wxwidgets__app_8cpp.html", null ],
-    [ "wxwidgets_dc.cpp", "wxwidgets__dc_8cpp.html", null ],
-    [ "wxwidgets_gc.cpp", "wxwidgets__gc_8cpp.html", null ],
+    [ "wxwidgets_comms.cpp", "wxwidgets__comms_8cpp.html", null ],
+    [ "wxwidgets_comms.h", "wxwidgets__comms_8h.html", "wxwidgets__comms_8h" ],
+    [ "wxwidgets_dev.cpp", "wxwidgets__dev_8cpp.html", "wxwidgets__dev_8cpp" ],
     [ "xfig.c", "xfig_8c.html", "xfig_8c" ],
     [ "xwin.c", "xwin_8c.html", "xwin_8c" ]
 ];
\ No newline at end of file
