@@ -11,7 +11,6 @@ var globals_func =
     [ "h", "globals_func_0x68.html", null ],
     [ "i", "globals_func_0x69.html", null ],
     [ "j", "globals_func_0x6a.html", null ],
-    [ "k", "globals_func_0x6b.html", null ],
     [ "l", "globals_func_0x6c.html", null ],
     [ "m", "globals_func_0x6d.html", null ],
     [ "n", "globals_func_0x6e.html", null ],
@@ -25,6 +24,5 @@ var globals_func =
     [ "v", "globals_func_0x76.html", null ],
     [ "w", "globals_func_0x77.html", null ],
     [ "x", "globals_func_0x78.html", null ],
-    [ "y", "globals_func_0x79.html", null ],
-    [ "z", "globals_func_0x7a.html", null ]
+    [ "y", "globals_func_0x79.html", null ]
 ];
\ No newline at end of file
