@@ -1,7 +1,6 @@
 var hierarchy =
 [
     [ "__dlhandle", "struct____dlhandle.html", null ],
-    [ "_color_map", "struct__color__map.html", null ],
     [ "plplot::_N1", "structplplot_1_1__N1.html", null ],
     [ "plplot::_N10", "structplplot_1_1__N10.html", null ],
     [ "plplot::_N11", "structplplot_1_1__N11.html", null ],
@@ -16,17 +15,14 @@ var hierarchy =
     [ "plplotc._object", "classplplotc_1_1__object.html", [
       [ "plplotc.PLGraphicsIn", "classplplotc_1_1PLGraphicsIn.html", null ]
     ] ],
-    [ "_PlplotCanvas", "struct__PlplotCanvas.html", null ],
-    [ "_PlplotCanvasClass", "struct__PlplotCanvasClass.html", null ],
-    [ "_PlplotCanvasHacktext", "struct__PlplotCanvasHacktext.html", null ],
-    [ "_PlplotCanvasHacktextClass", "struct__PlplotCanvasHacktextClass.html", null ],
-    [ "_PlplotCanvasHacktextPriv", "struct__PlplotCanvasHacktextPriv.html", null ],
+    [ "_plm_format", "struct__plm__format.html", null ],
+    [ "_plm_version", "struct__plm__version.html", null ],
     [ "_state", "struct__state.html", null ],
     [ "arc_struct", "structarc__struct.html", null ],
-    [ "plplotcanvas.Canvas", "classplplotcanvas_1_1Canvas.html", null ],
     [ "cdImageStruct", "structcdImageStruct.html", null ],
     [ "cdPointStruct", "structcdPointStruct.html", null ],
     [ "circle", "structcircle.html", null ],
+    [ "Clipper", "classClipper.html", null ],
     [ "CmdInfo", "structCmdInfo.html", null ],
     [ "Command", "structCommand.html", null ],
     [ "plplot.core.config", "classplplot_1_1core_1_1config.html", null ],
@@ -43,11 +39,12 @@ var hierarchy =
     [ "dev_entry", "structdev__entry.html", null ],
     [ "DIR", "structDIR.html", null ],
     [ "dirent", "structdirent.html", null ],
+    [ "DrawingObjectsChanger", "classDrawingObjectsChanger.html", null ],
     [ "DrvOpt", "structDrvOpt.html", null ],
     [ "DrvOptCmd", "structDrvOptCmd.html", null ],
     [ "EscText", "structEscText.html", null ],
     [ "FCI_to_FontName_Table", "structFCI__to__FontName__Table.html", null ],
-    [ "GcwPLdev", "structGcwPLdev.html", null ],
+    [ "FontGrabber", "classFontGrabber.html", null ],
     [ "hashtable", "structhashtable.html", null ],
     [ "Hershey_to_Unicode_table", "structHershey__to__Unicode__table.html", null ],
     [ "ht_bucket", "structht__bucket.html", null ],
@@ -57,6 +54,7 @@ var hierarchy =
     [ "lpi", "structlpi.html", null ],
     [ "lweights", "structlweights.html", null ],
     [ "MasterHandler", "classMasterHandler.html", null ],
+    [ "MemoryMapHeader", "structMemoryMapHeader.html", null ],
     [ "MJDtimeStruct", "structMJDtimeStruct.html", null ],
     [ "nn_weights", "structnn__weights.html", null ],
     [ "nnai", "structnnai.html", null ],
@@ -66,11 +64,14 @@ var hierarchy =
     [ "octave_swig_ref", "classoctave__swig__ref.html", null ],
     [ "octave_swig_type", "classoctave__swig__type.html", null ],
     [ "octave_value_ref", "structoctave__value__ref.html", null ],
+    [ "OriginChanger", "classOriginChanger.html", null ],
     [ "pattern", "structpattern.html", null ],
     [ "PDFstrm", "structPDFstrm.html", null ],
     [ "plplot::pladv", "interfaceplplot_1_1pladv.html", null ],
     [ "plplot::plbin", "interfaceplplot_1_1plbin.html", null ],
     [ "plplot::plbop", "interfaceplplot_1_1plbop.html", null ],
+    [ "plplot::plbtime", "interfaceplplot_1_1plbtime.html", null ],
+    [ "plbuffer", "structplbuffer.html", null ],
     [ "PLBufferingCB", "structPLBufferingCB.html", null ],
     [ "PLCairo", "structPLCairo.html", null ],
     [ "plplot::plcalc_world", "interfaceplplot_1_1plcalc__world.html", null ],
@@ -86,13 +87,14 @@ var hierarchy =
     [ "plplot::plcol1", "interfaceplplot_1_1plcol1.html", null ],
     [ "PLColor", "structPLColor.html", null ],
     [ "plplot::plcolorbar", "interfaceplplot_1_1plcolorbar.html", null ],
+    [ "plplot::plconfigtime", "interfaceplplot_1_1plconfigtime.html", null ],
     [ "plplotp::plcont", "interfaceplplotp_1_1plcont.html", null ],
     [ "PLControlPt", "structPLControlPt.html", null ],
     [ "plplot::plcpstrm", "interfaceplplot_1_1plcpstrm.html", null ],
+    [ "plplot::plctime", "interfaceplplot_1_1plctime.html", null ],
     [ "PLDev", "structPLDev.html", null ],
     [ "PLDispatchTable", "structPLDispatchTable.html", null ],
     [ "PLDisplay", "structPLDisplay.html", null ],
-    [ "plplot::plend", "interfaceplplot_1_1plend.html", null ],
     [ "plplot::plend1", "interfaceplplot_1_1plend1.html", null ],
     [ "plplot::plenv", "interfaceplplot_1_1plenv.html", null ],
     [ "plplot::pleop", "interfaceplplot_1_1pleop.html", null ],
@@ -127,8 +129,8 @@ var hierarchy =
     [ "plplot::plgpage", "interfaceplplot_1_1plgpage.html", null ],
     [ "plplot::plgra", "interfaceplplot_1_1plgra.html", null ],
     [ "plplot::plgradient", "interfaceplplot_1_1plgradient.html", null ],
-    [ "plplot_types::plgraphicsin", "structplplot__types_1_1plgraphicsin.html", null ],
     [ "plplot.core.PLGraphicsIn", "classplplot_1_1core_1_1PLGraphicsIn.html", null ],
+    [ "plplot_graphics::plgraphicsin", "structplplot__graphics_1_1plgraphicsin.html", null ],
     [ "PLGraphicsIn", "structPLGraphicsIn.html", null ],
     [ "plplot::plgriddata", "interfaceplplot_1_1plgriddata.html", null ],
     [ "plplot::plgspa", "interfaceplplot_1_1plgspa.html", null ],
@@ -152,10 +154,19 @@ var hierarchy =
     [ "plplot::plline3", "interfaceplplot_1_1plline3.html", null ],
     [ "plplot::pllsty", "interfaceplplot_1_1pllsty.html", null ],
     [ "plplot::plmap", "interfaceplplot_1_1plmap.html", null ],
+    [ "plplot::plmapfill", "interfaceplplot_1_1plmapfill.html", null ],
+    [ "plplot::plmapline", "interfaceplplot_1_1plmapline.html", null ],
+    [ "plplot::plmapstring", "interfaceplplot_1_1plmapstring.html", null ],
+    [ "plplot::plmaptex", "interfaceplplot_1_1plmaptex.html", null ],
+    [ "PLmDev", "structPLmDev.html", null ],
+    [ "PLMemoryMap", "classPLMemoryMap.html", null ],
     [ "plplot::plmeridians", "interfaceplplot_1_1plmeridians.html", null ],
     [ "plplot::plmesh", "interfaceplplot_1_1plmesh.html", null ],
     [ "plplot::plmeshc", "interfaceplplot_1_1plmeshc.html", null ],
+    [ "PLmIndex", "structPLmIndex.html", null ],
     [ "plplot::plmkstrm", "interfaceplplot_1_1plmkstrm.html", null ],
+    [ "PLNamedMutex", "classPLNamedMutex.html", null ],
+    [ "PLNamedMutexLocker", "classPLNamedMutexLocker.html", null ],
     [ "PLOptionInfo", "structPLOptionInfo.html", null ],
     [ "PLOptionTable", "structPLOptionTable.html", null ],
     [ "plplot::plot3d", "interfaceplplot_1_1plot3d.html", null ],
@@ -163,7 +174,7 @@ var hierarchy =
     [ "plplot::plpat", "interfaceplplot_1_1plpat.html", null ],
     [ "plplot::plpath", "interfaceplplot_1_1plpath.html", null ],
     [ "plplot", "classplplot.html", null ],
-    [ "plplot_flt", "classplplot__flt.html", null ],
+    [ "plplot_graphics", "classplplot__graphics.html", null ],
     [ "plplot_str", "classplplot__str.html", null ],
     [ "plplot_strutils", "classplplot__strutils.html", null ],
     [ "plplot_types", "classplplot__types.html", null ],
@@ -225,16 +236,17 @@ var hierarchy =
     [ "plplot::plsetmapformc::plslabelfunc::plssym", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plssym.html", null ],
     [ "plplot::plsetmapformc::plslabelfunc::plstar", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstar.html", null ],
     [ "plplot::plsetmapformc::plslabelfunc::plstransform", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform.html", null ],
+    [ "PLStream", "structPLStream.html", null ],
     [ "plstream", "classplstream.html", [
       [ "wxPLplotstream", "classwxPLplotstream.html", null ]
     ] ],
-    [ "PLStream", "structPLStream.html", null ],
     [ "PLStrip", "structPLStrip.html", null ],
     [ "plplot::plsetmapformc::plslabelfunc::plstransform::plstripa", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripa.html", null ],
     [ "plplot::plsetmapformc::plslabelfunc::plstransform::plstripc", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripc.html", null ],
     [ "plplot::plsetmapformc::plslabelfunc::plstransform::plstripd", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripd.html", null ],
     [ "plplot::plsetmapformc::plslabelfunc::plstransform::plstyl", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstyl.html", null ],
     [ "plplot::plsetmapformc::plslabelfunc::plstransform::plsurf3d", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsurf3d.html", null ],
+    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plsurf3dl", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsurf3dl.html", null ],
     [ "plplot::plsetmapformc::plslabelfunc::plstransform::plsvect", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvect.html", null ],
     [ "plplot::plsetmapformc::plslabelfunc::plstransform::plsvpa", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvpa.html", null ],
     [ "plplot::plsetmapformc::plslabelfunc::plstransform::plsxax", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsxax.html", null ],
@@ -257,8 +269,11 @@ var hierarchy =
     [ "PSDev", "structPSDev.html", null ],
     [ "pt", "structpt.html", null ],
     [ "PyHeapTypeObject", "structPyHeapTypeObject.html", null ],
+    [ "QGlobalSpace", "classQGlobalSpace.html", null ],
     [ "QSASConfigStruct", "structQSASConfigStruct.html", null ],
     [ "QtPLDriver", "classQtPLDriver.html", null ],
+    [ "Rand", "classRand.html", null ],
+    [ "Scaler", "classScaler.html", null ],
     [ "square", "structsquare.html", null ],
     [ "SVG", "structSVG.html", null ],
     [ "swig_cast_info", "structswig__cast__info.html", null ],
@@ -283,20 +298,16 @@ var hierarchy =
     [ "TAI_UTC", "structTAI__UTC.html", null ],
     [ "tclMatrix", "structtclMatrix.html", null ],
     [ "tclMatrixXtnsnDescr", "structtclMatrixXtnsnDescr.html", null ],
+    [ "TextObjectsChanger", "classTextObjectsChanger.html", null ],
+    [ "TextSizeInfo", "structTextSizeInfo.html", null ],
     [ "TkDev", "structTkDev.html", null ],
     [ "TkwDev", "structTkwDev.html", null ],
     [ "TkwDisplay", "structTkwDisplay.html", null ],
     [ "triangle", "structtriangle.html", null ],
     [ "triangle_neighbours", "structtriangle__neighbours.html", null ],
     [ "Unicode_to_Type1_table", "structUnicode__to__Type1__table.html", null ],
-    [ "wxGetSizeDialog", "classwxGetSizeDialog.html", null ],
-    [ "wxPLDevBase", "classwxPLDevBase.html", [
-      [ "wxPLDevDC", "classwxPLDevDC.html", null ]
-    ] ],
-    [ "wxPLplotApp", "classwxPLplotApp.html", null ],
-    [ "wxPLplotFrame", "classwxPLplotFrame.html", null ],
-    [ "wxPLplotWindow", "classwxPLplotWindow.html", null ],
-    [ "wxPLplotwindow", "classwxPLplotwindow.html", null ],
+    [ "wxPLDevice", "classwxPLDevice.html", null ],
+    [ "wxPLplotwindow< WXWINDOW >", "classwxPLplotwindow.html", null ],
     [ "XwDev", "structXwDev.html", null ],
     [ "XwDisplay", "structXwDisplay.html", null ]
 ];
\ No newline at end of file
