@@ -109,6 +109,7 @@ var interfaceplplot_1_1core_1_1plplotjavacConstants =
     [ "PL_Y_AXIS", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aaf1d2e471f3d12edcdf5591a2d648512", null ],
     [ "PL_Z_AXIS", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a1b45921af31fd7cb57084f2204ba4483", null ],
     [ "PLESC_ALLOC_NCOL", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a41fc6eb2fa8cba796619bd3e3b2eed9d", null ],
+    [ "PLESC_APPEND_BUFFER", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#abcc96efec5c065d14c392acaaae87333", null ],
     [ "PLESC_ARC", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a7de1115c29d36dec0a1108536a8b91be", null ],
     [ "PLESC_BEGIN_TEXT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a5d25cb29f74a384031210a1fbad445db", null ],
     [ "PLESC_CLEAR", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#abba9d46462fe272a1579e3ee0fdaf77a", null ],
@@ -126,7 +127,9 @@ var interfaceplplot_1_1core_1_1plplotjavacConstants =
     [ "PLESC_END_TEXT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aad130d9de5986f6dc8994a0db4e0349b", null ],
     [ "PLESC_EXPOSE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a732121025b156cc645cbebb040a811ae", null ],
     [ "PLESC_FILL", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aa347d6a6d94d07b92bb198a0ac3aa812", null ],
+    [ "PLESC_FIXASPECT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#af96ea44327119a2cbcdcfb2020cc12d9", null ],
     [ "PLESC_FLUSH", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a36f56817abcb9a8c7ce7f552fe666d06", null ],
+    [ "PLESC_FLUSH_REMAINING_BUFFER", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#af10fee918893745015482a2334d2cd4e", null ],
     [ "PLESC_GETBACKEND", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a3ecc3541843fc56aced4664dce5698e2", null ],
     [ "PLESC_GETC", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#ad109110bac666c1f71fdfa10bf70fc3c", null ],
     [ "PLESC_GRADIENT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a603e56e9a72637c930e2f275e8efa84b", null ],
@@ -134,6 +137,7 @@ var interfaceplplot_1_1core_1_1plplotjavacConstants =
     [ "PLESC_HAS_TEXT", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aa4be664bf8dd2979b3d61165fbd1cd03", null ],
     [ "PLESC_IMAGE", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a9aafbc1ffdb08e134ea4a627bc5926e6", null ],
     [ "PLESC_IMAGEOPS", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#af6cd18df87f8c8ff9daba8c228190397", null ],
+    [ "PLESC_IMPORT_BUFFER", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#aa9e45a23dd10b600a011f24bd6e04a33", null ],
     [ "PLESC_MODEGET", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#af058f8855fc78d548a5ab4f450837bed", null ],
     [ "PLESC_MODESET", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#abe5beb50d0a8723f9ae872b50b998b9b", null ],
     [ "PLESC_PL2DEVCOL", "interfaceplplot_1_1core_1_1plplotjavacConstants.html#a82c99e81b3be07f487e1eb34f5208d13", null ],
