@@ -40,53 +40,50 @@ var NAVTREEINDEX =
 [
 "PLCallbackCT_8java.html",
 "cd_8c.html",
-"classoctave__swig__packed.html#a787cad9e788d2f94bae5f1c338afef3d",
-"classplplot.html#a8ad11f18fef6acd1ac3d69c59d681ea2",
-"classplplot_1_1core_1_1PLStream.html#a7d3305012f5956cbd2ccb7d6bbf166a2",
-"classplplot_1_1core_1_1plplotjavac.html#af34744a05f6f8d3b6077ccaf1af69a4a",
-"classplplot_1_1core_1_1plplotjavacJNI.html#aaec371cc676a698fa88996cadc2c20dc",
-"classplstream.html#a66e437a73f132e600c182948bd255301",
-"classwxPLplotApp.html#a59ca5aa5eef0185b44214748ccb09b4e",
-"disptab_8h.html#a831fc632009fb03b45bff513ce0b0dbf",
-"gcw_8h.html#a86b7b8e83f31c708429ce71bf3dcf8b1",
-"interfaceplplot_1_1core_1_1plplotjavacConstants.html#a663894df6ed9e719c80e0714bd5fefe8",
-"interfaceplplot_1_1plrgb1.html",
-"ltdl__win32_8h.html#a27f994e13bb1fa8980244f212c984f03",
-"nnpi_8c.html#a63afdbb12466d8f0fa6a92cc560626cb",
-"plargs_8c.html#ab062747e48eac34977d7ff9ea808ae4b",
-"plcore_8c.html#ab4936c1ab86820efcc43ba6d2d3e98bd",
-"plevent_8h.html#a36208fd0c8699d778d0fafe589278862",
-"plframe_8c.html#a9e40812ac6b589fcc9eb6aae31d8235e",
-"plplotP_8h.html#a2d8fe21fcd4b5ed36d6df4bad0a1fcf2",
-"plplot_8d.html#a4b47230cae3dd41861550e900b35b8c6",
-"plplot_8h.html#a1158e56e4321e7570ca83f6d2bd08345",
-"plplot_8h.html#a85d3543f7602f5dd6d883dfdc1a0bd29",
-"plplot_8h.html#af55a7619d9dc46406190e135ba1a2df2",
-"plplot__octaveOCTAVE__wrap_8cxx.html#a232b2e24b1318c77c9638a3957b3de76",
-"plplot__octaveOCTAVE__wrap_8cxx.html#a7fad3d3926defa4614f8c3bd5e85fb50",
-"plplot__octaveOCTAVE__wrap_8cxx.html#ae464aacef1988de30135ec954559f7ff",
-"plplot__octave_8h.html#a63e2da015640c52a9999c55342b646fc",
-"plplot__octave_8h.html#af0d0dffc35bd75a37f400fe781ec3219",
-"plplotc_8py.html#a8ad0cfa320c20249a5672441c5d41833",
-"plplotcanvas_8c.html#a45016f9facf1d174586dd145c55cd73e",
-"plplotcmodulePYTHON__wrap_8c.html#a05b404bc7fdec8cd8fd0e899a7f6cc71",
-"plplotcmodulePYTHON__wrap_8c.html#a75f3cdb017ee70daa4eb4bc856ae1bb4",
-"plplotcmodulePYTHON__wrap_8c.html#ae66f44191f70db7b9634a8321766c840",
-"plplotjavacJAVA__wrap_8c.html#a759553ce11c7722bea834d8ff7c1bbd6a6aacbda6ab6e6550234dace9d04e9e60",
-"plplotluacLUA__wrap_8c.html#a0ef991adca430d4a150402698cde9bf0",
-"plplotluacLUA__wrap_8c.html#aa670a7d51dbbe7c945555db6b36fe715",
-"plr_8c.html#a07a997d3daa7f2ba7e6d9447e9f38b32",
-"plstubs_8h.html#a673f0152dbebb6341a6307866ac8a0c4",
-"ps_8c.html#ad72dbcf6d0153db1b8d8a58001feed83",
-"scstubs_8c.html#a1a52862400b4711a6dd2e193e91013bf",
-"structEscText.html#a5f2e150b687549f796d5346e7eab13e6",
-"structPLStream.html#a451b8d8197b4b3c0463d31850e289141",
-"structPLStrip.html#ab5f92f592afcb4cf7492ffa0eea684cd",
-"structTkwDev.html#a861c6eb415578bfa8b2d51c6a3e97925",
-"structline.html#aa3cfa32d0244ed92cb37cd8ea4f125c9",
-"structswig__type__info.html#a2e1f9087e639dd7c8c131fbc6e399194",
-"tclgen_8c.html#a10fd45e3bd5f34a7654cc6fdd79cc167",
-"tclgen_8h.html#ae6248649cb09d21514513b5d33bedc05"
+"classPLNamedMutex.html#acbf03b1fe516befb93fc6b239c802e8b",
+"classplplot.html#a3fbb9171d73f5670d2ebf52797775966",
+"classplplot_1_1core_1_1PLStream.html#a0bd1b46d3ca7426c84a138c9767d828b",
+"classplplot_1_1core_1_1plplotjavac.html#a7d9b3d28fcc84d93e8889c61b273752c",
+"classplplot_1_1core_1_1plplotjavacJNI.html#a6c3bc04d8eb036621189c5614059441b",
+"classplplotc_1_1PLGraphicsIn.html",
+"classwxPLDevice.html#a096e5f08aa45dd8ea7fc4b71f41b69d1",
+"disptab_8h.html#a6deaecb817eab46142ebb2eac119ff44",
+"globals_func_0x70.html",
+"interfaceplplot_1_1plbin.html#a6c68cffd9481d74c0a95e9750d5141a2",
+"interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform.html#a207be70365602666dba8474dbc468139",
+"namespacemakedocstrings.html",
+"pdfutils_8c.html#a8b2e2133ddc387df8b1e6c3ed882ad7c",
+"plbuf_8c.html#a6e3e586984481314f86de46295eea6f7",
+"plcore_8h.html#ad1deefa41120df540fc35a5f37877212",
+"plevent_8h.html#abd9540b5c13eeafacc4373a40c7c6f8a",
+"plimage_8c.html#a34468d6826e119f4cb5218452e9bbdf3",
+"plplotP_8h.html#a26b65cc5d4ef0a9184e846eae3d11cff",
+"plplot_8d.html#a42479faafba4397a48eb085714c715a8",
+"plplot_8h.html#a0b36e6a122fbc4a47ff8ad9964f8623e",
+"plplot_8h.html#a7bfcd88ba0586868b1e6a306416d9f64",
+"plplot_8h.html#aea8b2357c54cbeb5684fd5dc07969f81",
+"plplot__octaveOCTAVE__wrap_8cxx.html#a1761de57100c0d31a25fb0f2b1d89004",
+"plplot__octaveOCTAVE__wrap_8cxx.html#a70e41eebfacedae630ffb0f6830da98d",
+"plplot__octaveOCTAVE__wrap_8cxx.html#ad29fd467771471a5291b05fb9d38b53f",
+"plplotc_8py.html#a4b4963c66abfe6a3524bf1ce73a579a5",
+"plplotc_8py.html#afc6c6d9d92c1b411d0d578599666b51e",
+"plplotcmodulePYTHON__wrap_8c.html#a6fea38d61cc362fd7b67a9fa56b33307",
+"plplotcmodulePYTHON__wrap_8c.html#adccbcbf6df87e38c5a227a9b5c7f70e4",
+"plplotjavacJAVA__wrap_8c.html#a69e9e7083a1122604384a269911c2b28",
+"plplotjavacJAVA__wrap_8c.html#afff14b44f5960bb76a5936330a7238b9",
+"plplotluacLUA__wrap_8c.html#a96a75364a5f20fd525bb603440f698d3",
+"plplotter_8c.html#a8c15b9e762184f103dfb8db1e75e3bb9",
+"plstubs_8h.html#a2cded6c634e046be1bba801e854d4a6d",
+"pltime_8c_source.html",
+"sccont_8c.html#a16c148062c4da36976913095089a42e6",
+"structEscText.html",
+"structPLStream.html#a4b1ed19b6eaa67093322e029692b59b1",
+"structPLStrip.html#ae271e5c050c41c2e2f4458de756f99c0",
+"structTkDev.html#a5dd032b995b9dbc11f687137e8a789d1",
+"structht__bucket.html#a29f598025fca935a60c2720c004bd690",
+"structswig__octave__class.html#af6c5e0b035923e4489939936e82fa15c",
+"tclMatrix_8h.html#abf562e3a618ffccdb8f7064fd715ad7b",
+"tclgen_8h.html#abf4a7d6d0fac5730e81c1395635d845b"
 ];
 
 var navTreeSubIndices = new Array();
