@@ -87,6 +87,10 @@ var plplot_8d =
     [ "c_plline3", "plplot_8d.html#ab692a525dff33d0983d85e80d156c27c", null ],
     [ "c_pllsty", "plplot_8d.html#a618ea88b197ff40d2f4010eaeb9f0f1f", null ],
     [ "c_plmap", "plplot_8d.html#abbed1f0ce5c63859cd965fb705f3b76b", null ],
+    [ "c_plmapfill", "plplot_8d.html#a6e8894d848e822253ae7c7be0288822d", null ],
+    [ "c_plmapline", "plplot_8d.html#a45dfd021cee74defcf179d3e2afb1279", null ],
+    [ "c_plmapstring", "plplot_8d.html#a042a114f197ac7850ea6ddc47934609a", null ],
+    [ "c_plmaptex", "plplot_8d.html#a92bddec507cdd2028fee7b29a2637370", null ],
     [ "c_plmeridians", "plplot_8d.html#a5a770471e77b39477f7c99630c37bd42", null ],
     [ "c_plmesh", "plplot_8d.html#adaf1e9a7519889676ffcced8e5f2931f", null ],
     [ "c_plmeshc", "plplot_8d.html#aed89e08e72504dc67d86e6c73e2c9b62", null ],
@@ -233,6 +237,10 @@ var plplot_8d =
     [ "plline", "plplot_8d.html#ad5d3f049bd8961288ecf91205bc4976a", null ],
     [ "plline3", "plplot_8d.html#ad4604a276fb5c54f48a649567854a0db", null ],
     [ "plmap", "plplot_8d.html#a9927f928134f967d9830abc78d361199", null ],
+    [ "plmapfill", "plplot_8d.html#a890ea5d3b655546c41fa3ec8371b2310", null ],
+    [ "plmapline", "plplot_8d.html#a547b81f3ad2285393e73fcee988f3e40", null ],
+    [ "plmapstring", "plplot_8d.html#aec5de0c3c5663b6c7797ea1d28920e51", null ],
+    [ "plmaptex", "plplot_8d.html#a223f1ec44e835b3ce49f1d19354cf91c", null ],
     [ "plMergeOpts", "plplot_8d.html#ae5dbeb44b28005ff66ef0bb7a9191351", null ],
     [ "plmesh", "plplot_8d.html#a6abc40bbf2db54f712e7dea351754b39", null ],
     [ "plmeshc", "plplot_8d.html#a4a98e97ec18151452a4227290d3caecb", null ],
@@ -265,7 +273,6 @@ var plplot_8d =
     [ "plseopH", "plplot_8d.html#af141bfd63c48d0ec1d5429cfa24e211d", null ],
     [ "plsError", "plplot_8d.html#a5248d20a8e70740bf885d16f65b5103f", null ],
     [ "plsetopt", "plplot_8d.html#aa3d188c7f73a093b0d3eb6616eccc209", null ],
-    [ "plSetOpt", "plplot_8d.html#a8dae8f74b27e084d6459d536f876e93b", null ],
     [ "plSetUsage", "plplot_8d.html#aad8dfba8a001aec5a019f149280ac971", null ],
     [ "plsexit", "plplot_8d.html#a3ee8d5347a570039722892589c8f063a", null ],
     [ "plsfnam", "plplot_8d.html#ae12690df17e92a922f3e760915205344", null ],
