@@ -13,6 +13,7 @@ var plplot_8h =
     [ "PLBufferingCB", "structPLBufferingCB.html", "structPLBufferingCB" ],
     [ "PLLabelDefaults", "structPLLabelDefaults.html", "structPLLabelDefaults" ],
     [ "plf2ops_t", "structplf2ops__t.html", "structplf2ops__t" ],
+    [ "plbuffer", "structplbuffer.html", "structplbuffer" ],
     [ "BASE_CONT", "plplot_8h.html#a615d5bba089363ae37df2a6b33fac010", null ],
     [ "BRAINDEAD", "plplot_8h.html#a397833bd03deddc81a012b416c10bc8f", null ],
     [ "DRAW_LINEX", "plplot_8h.html#abc232a5d2bdcfe6d917d28b1d0113261", null ],
@@ -147,6 +148,7 @@ var plplot_8h =
     [ "plerrx", "plplot_8h.html#a1267f751a55fbf9af59a9f5cb66241c3", null ],
     [ "plerry", "plplot_8h.html#a07f65d6478ffa4353de099f7a250706b", null ],
     [ "PLESC_ALLOC_NCOL", "plplot_8h.html#ae87f50d83b1fa81c85e641ff1603b087", null ],
+    [ "PLESC_APPEND_BUFFER", "plplot_8h.html#a9f071fd6195ce50d251d76e9e19ebe1a", null ],
     [ "PLESC_ARC", "plplot_8h.html#ac183a5dea6e2d74c914fbfd683707851", null ],
     [ "PLESC_BEGIN_TEXT", "plplot_8h.html#ad60423577a77dfdc57cffefcb95fdcd8", null ],
     [ "PLESC_CLEAR", "plplot_8h.html#aa499059ba6f588b9034a61d071e9caa7", null ],
@@ -164,7 +166,9 @@ var plplot_8h =
     [ "PLESC_END_TEXT", "plplot_8h.html#a364fdd01ecc2c39ce6bf9068dcf55792", null ],
     [ "PLESC_EXPOSE", "plplot_8h.html#a04ed603d88adb3cd41dafeb07df6eabf", null ],
     [ "PLESC_FILL", "plplot_8h.html#ab9b25e6e06dd0d6808371db0ddc0122a", null ],
+    [ "PLESC_FIXASPECT", "plplot_8h.html#a12543c8963759e9e89f2aeb6443dafce", null ],
     [ "PLESC_FLUSH", "plplot_8h.html#a77b55167b45bce03588d2893c466c368", null ],
+    [ "PLESC_FLUSH_REMAINING_BUFFER", "plplot_8h.html#ae9b11f35267bde0d224413a306edce35", null ],
     [ "PLESC_GETBACKEND", "plplot_8h.html#ac4ab70a8f75aa95eba0de158d12f0d39", null ],
     [ "PLESC_GETC", "plplot_8h.html#a0b36e6a122fbc4a47ff8ad9964f8623e", null ],
     [ "PLESC_GRADIENT", "plplot_8h.html#a58e75b2debc5ab66b18e0657d5e8bec0", null ],
@@ -172,6 +176,7 @@ var plplot_8h =
     [ "PLESC_HAS_TEXT", "plplot_8h.html#a15ec6c98c5588c218820831631daed82", null ],
     [ "PLESC_IMAGE", "plplot_8h.html#a7e3519bc3357c32808f4a40040e609f2", null ],
     [ "PLESC_IMAGEOPS", "plplot_8h.html#ae89d843559d5d03418cb91d9b161334a", null ],
+    [ "PLESC_IMPORT_BUFFER", "plplot_8h.html#a14af57e7de42d1649bae2faed3b777c4", null ],
     [ "PLESC_MODEGET", "plplot_8h.html#a0e988a4161665369dd1e2e0973a0897d", null ],
     [ "PLESC_MODESET", "plplot_8h.html#ab82e66ba552dd95fd67c63a4ad8af76a", null ],
     [ "PLESC_PL2DEVCOL", "plplot_8h.html#a13460c5799a6e0d9f9d2374bcd304407", null ],
@@ -237,6 +242,10 @@ var plplot_8h =
     [ "plline3", "plplot_8h.html#ad3a891ae7d8092eef6afbdd75b775885", null ],
     [ "pllsty", "plplot_8h.html#a92c6f5898168b542f4dc9b0dee69832c", null ],
     [ "plmap", "plplot_8h.html#a0f8e566fd2a93bf828220f85ce8a0082", null ],
+    [ "plmapfill", "plplot_8h.html#a195d7a844dbb92a8f22001ec7c7af0d6", null ],
+    [ "plmapline", "plplot_8h.html#a3f35026b66694311152c960424c4262a", null ],
+    [ "plmapstring", "plplot_8h.html#a7f527daa07872e6b78010ea7d672e08c", null ],
+    [ "plmaptex", "plplot_8h.html#a1e772d703253ac38dd80acadcc6b9b6b", null ],
     [ "plmeridians", "plplot_8h.html#ac3173de283e0221191f9e2135799fc4a", null ],
     [ "plmesh", "plplot_8h.html#aefd07a6d456b4ba015defdcb92eec185", null ],
     [ "plmeshc", "plplot_8h.html#aa81ce26dbf38805a61dad659e74a03e5", null ],
@@ -426,7 +435,11 @@ var plplot_8h =
     [ "c_plline", "plplot_8h.html#a02f8dd9569ed70fca023e7a6dc9b5620", null ],
     [ "c_plline3", "plplot_8h.html#aaac706424e86b2f7e58afda2d5e41910", null ],
     [ "c_pllsty", "plplot_8h.html#a317c00e1dc4960ac3aa3181ffce231a6", null ],
-    [ "c_plmap", "plplot_8h.html#a64d8a861b78a32faaf466bd2812fafc2", null ],
+    [ "c_plmap", "plplot_8h.html#a9391038c1678595134892ff48cbb151e", null ],
+    [ "c_plmapfill", "plplot_8h.html#a38b398f721fea3e44a59a8fa6bb51e6f", null ],
+    [ "c_plmapline", "plplot_8h.html#aae0c48c339d13839fbbb9da7200a30cc", null ],
+    [ "c_plmapstring", "plplot_8h.html#a1dc91678b27b6a92e2c20053324025e6", null ],
+    [ "c_plmaptex", "plplot_8h.html#a0c62c3dab9c7d5e1d277a9ef116fa255", null ],
     [ "c_plmeridians", "plplot_8h.html#a6ada49386576a255cb1d7e27a152e111", null ],
     [ "c_plmesh", "plplot_8h.html#a618d08727a1d07ebccca591e3201181e", null ],
     [ "c_plmeshc", "plplot_8h.html#a2969d7142ae7ef0ec919382c5bd192c9", null ],
@@ -569,6 +582,7 @@ var plplot_8h =
     [ "plsabort", "plplot_8h.html#a6a12df023027d32b69d013754708ebf0", null ],
     [ "plsbopH", "plplot_8h.html#a88ee33a7618aff463079633ccb145e49", null ],
     [ "plsButtonEH", "plplot_8h.html#a361966768bbacf56a799abf06992f7d1", null ],
+    [ "plsdevdata", "plplot_8h.html#aac8ab1a019b61633c58c7f5fe9713357", null ],
     [ "plseopH", "plplot_8h.html#a6b6320904fa7f9a952a4c61bbadcf88a", null ],
     [ "plsError", "plplot_8h.html#a07b4540e3e0ceb45b5ce57ebe4f74fc1", null ],
     [ "plSetUsage", "plplot_8h.html#ac0b71244be8e595726b4edf79f8a5580", null ],
