@@ -174,6 +174,7 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "my_plmeshc", "plplot__octaveOCTAVE__wrap_8cxx.html#afafd115d0d22ee71b78d010e10b06907", null ],
     [ "my_plot3d", "plplot__octaveOCTAVE__wrap_8cxx.html#a3bd433fbef9620928be1239d6e336db7", null ],
     [ "my_plot3dc", "plplot__octaveOCTAVE__wrap_8cxx.html#a0fdf54045b5f534b6f1c6e6687bfebf2", null ],
+    [ "my_plot3dcl", "plplot__octaveOCTAVE__wrap_8cxx.html#a926158756d38e37c8ad3127127450dea", null ],
     [ "my_plshade", "plplot__octaveOCTAVE__wrap_8cxx.html#a74751aaf9648e124e4c18f8299cc9521", null ],
     [ "my_plshade1", "plplot__octaveOCTAVE__wrap_8cxx.html#adc1ee2e7cfe669412defcd120c18db1c", null ],
     [ "my_plshade2", "plplot__octaveOCTAVE__wrap_8cxx.html#aad280f1c356f1ba8b14a91a4c1200cca", null ],
@@ -183,6 +184,7 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "my_plshadesx", "plplot__octaveOCTAVE__wrap_8cxx.html#af0310d42321952432ed36fa39a25bc3a", null ],
     [ "my_plstripc", "plplot__octaveOCTAVE__wrap_8cxx.html#a8f79ac9b2518d5c26de0fdade9955231", null ],
     [ "my_plsurf3d", "plplot__octaveOCTAVE__wrap_8cxx.html#a00481e018b10fd666ab7590b46d61b88", null ],
+    [ "my_plsurf3dl", "plplot__octaveOCTAVE__wrap_8cxx.html#a25bb984a1821999f2eba97d9b98e42ee", null ],
     [ "my_plTranslateCursor", "plplot__octaveOCTAVE__wrap_8cxx.html#ae2c6c47ecc7535b19e73bb2df2dc2285", null ],
     [ "my_plvect", "plplot__octaveOCTAVE__wrap_8cxx.html#a6028faf7cc33c2bd903d432a6e826c13", null ],
     [ "my_plvect1", "plplot__octaveOCTAVE__wrap_8cxx.html#abfa806059bd7a31c788a248bd8d6ca40", null ],
@@ -220,34 +222,36 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a77a3f76cb1445325a013c2676f9c4581", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5734d9353408f1ae453b0385a02393e7", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ac3a0c15e37d0b3f465a844dee154db26", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5534c854fb5a7d9a4e877754e42eec51", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ace031230cad69cb693d5187dc987e5be", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5f11455ff62681657ca4c57d9d96863f", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a2b39f891ef522830a1cf19b32de8e89a", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a919017e3e2ca435ec52a256382f9ea70", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ab7cab09a28ea264190e821629c691d34", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae5b3d9cdaa7af65ea5be352d761ae3ab", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a9c9957014a1ff7e47b4c50025ffeb47c", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a4a6ffea400142fbbe5cb0886eb852ceb", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5270f119dd4d3c80721ae79f1e042a69", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a445853900bf3fa9e6138c5ad0d2b4db1", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a59aee5cd006afc514abb5e1599304615", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a73c5d8f7b13ac7413d92b87b6a079b5b", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a1d49d461b88283b93ec165d896356242", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a8d3fb3541f8b1eaa18887c8f5754ffee", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ada8de35086b729117ee1b08a09d92e78", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#af70b181b46076ea7d5f53b7202740115", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a64cc39d295e1164b99b6efb87cf22fd6", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a218c9805383da4ed12220301f14f27eb", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a650b8da70b4f517ced7d17b7ff747c94", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a71637d28b53dc083423bd586bfec7822", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a18365b92f8c83681159759b0ce163207", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a06472d4b7e3ec0c57dc9e705d0ef4ade", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#abcff8cd901eedb5192c484c3eccb8421", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#addc35e21a73364c0e426b888c5327fb9", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a6e3bcd29255120af19fb2c33a1768c08", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aba57b582a1c7d882bf7d933cdc6f7b8c", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5323a4f1e9cc02ee51c2585c43a00f62", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a3149b3bca7f590c0b2a3362ab4a2c2ec", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a647965de63f19cb1852c4aa05b614cd4", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a56eab964f5e45f34d41fa73ebb8d7a3a", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a67d0f26b324f1725d58517e6858cb776", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae88b00af8bcdd6a7d07f101252df2b3c", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aa097e4949925663e5ef3fb3a091f8ee2", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a037c166c948a9116964aca68e80892b2", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a2621da255e2907e1352ddc8187764e7c", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a9b420d3b542c4e80cb979d0bf45eff81", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a38e6a9fb52f8285b31a753cf75445b43", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ad602a393d6b522dc765cf70be7414f90", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a417605959ef9861ccee7d30dd625d2e8", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a97e1ee7b9c83043f6be2b915c69a5ef7", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a6a5d7eb27df775891398e6f4b4d785f2", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a56134d7b1cdd0a42d257d90ae8610711", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#adabf94e42ecd2cb74deb556bb7944e40", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a096e93af5dc22bd41def5f6ab0ef84c1", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#adabf88e931783bcb037b3a7b2a02b69f", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a80526bd463cf93db5afcb816f26ec11f", null ],
@@ -280,7 +284,7 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a86d56f3f1fb6effb71a5ad8cdd91f577", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a7874867fbba553f84c290815414ae03f", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aa8c88077d769deca3df9a66dfbf82627", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a68dcc675a249fb241628daf9d1796423", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a8f0956f662917bda8d40d514634ad211", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a7c3d4a414e9b6a4ae23be941012e940e", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a827576f0fe439ec4eabfd4a98c749fac", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a689526bf32fe5ae1d8e2a4d08397ed4c", null ],
@@ -288,8 +292,8 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a24138a17d4f4e0d10f5bcb5f1614ba0a", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ac5f06121c94ba745921fc00150400369", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a53ca21ecb7ee9f500ea2e2b5c7feb49f", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aeee0254cbf0926f58519d0e8ae4dce60", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#abb925aa6dc235f7566b612527f2d1f93", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#acb37c74216a6f329da88db4224e26d71", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a26f0ad281f898c59f3b21c3ca19e9191", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a6610b11ef8d369bbd6946dc359dd517e", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ad632aa81c10934a40f061e46892b771f", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a1feaef8cf5f9d182fedd14090a6e65a8", null ],
@@ -365,8 +369,8 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae9da335efb2b64c1fe2095a291721c54", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ac7f5bcfd24ccfbd051d53e95eaa69714", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a76e8c5ad06b7d0f5168d01f5684610eb", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a55e1e9a2fcf254cacd25fb45c20b77f7", null ],
-    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aed8b5cd4c248e691c146250054bea0c2", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a240cada24f1b6a4abc16c28f07176aa4", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a06318313fdca800b34451662afb92784", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae8d855a04f9d287a57db8c8718886bda", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a3f10c4a243c0303302473b0e1d0e8ab0", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae312d8a43892365fb372e4d1897f4c8d", null ],
@@ -422,6 +426,10 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a7fbe2055a28240472a78c503d2b4c13b", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a4af5c41720a6128ce7215a878180b99e", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#adad211784c1d5d6b490c3a3c23d58242", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a6f232a884088bcaaad9c23030bf4b91e", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a1cd8106ea5e2378845c7fa70b3381ac2", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5c3bda0713d4efc775e20749adb08bcb", null ],
+    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#af6f2f0baaa9a67b48090977e550275a0", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a4b71efa6d36bcc28ea9a2bc1868d6bf8", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a68b4099adb55460808178a0baa9dda0d", null ],
     [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a198bcd95151089c037a1787164218049", null ],
@@ -514,11 +522,16 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "_wrap_plbop_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ae5c0ac10e2630787663c19ee546f6bc5", null ],
     [ "_wrap_plbox3_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a03cfd966415718f4fffecb9193d53b41", null ],
     [ "_wrap_plbox_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ab853cfe7ce775d3882971390e4584627", null ],
+    [ "_wrap_plbtime_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a5b30d9dc4ea6486f01114cbc1de0126b", null ],
     [ "_wrap_plcalc_world_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a0a2c258f6dcd3cdf6513734422990176", null ],
     [ "_wrap_plclear_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ac5c6e7b86c86dc0737dac02df648b105", null ],
     [ "_wrap_plcol0_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a1761de57100c0d31a25fb0f2b1d89004", null ],
     [ "_wrap_plcol1_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aeec4aea06c98bb36d5625d3f903fe485", null ],
+    [ "_wrap_plcolorbar_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#afab0eefbdde0ae7077e59fc76995ac71", null ],
+    [ "_wrap_plconfigtime_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a7216a1ee562155fabc49e88fdd64746c", null ],
+    [ "_wrap_plcont_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aeb5e286e22dd49a5c53d06e3e0d49913", null ],
     [ "_wrap_plcpstrm_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a83a26a27ebfa2aba10d7710d34d5dbef", null ],
+    [ "_wrap_plctime_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aec230e51536ce9702385accbe5d43823", null ],
     [ "_wrap_plend1_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a37ce505d80c4ed872fcc4634362e344a", null ],
     [ "_wrap_plend_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a12b6a75136ddfbc0b72065f15381c86f", null ],
     [ "_wrap_plenv0_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a44c4b472eadb4005011215b1c2fee6dc", null ],
@@ -533,6 +546,7 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "_wrap_plfont_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad28e38730730fd3fdb27e7c360fed5a5", null ],
     [ "_wrap_plfontld_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a79d9f72aeda3ed9642cd42ccff4eadd8", null ],
     [ "_wrap_plgchr_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a4f2bcefca98606b5697148b740127ce6", null ],
+    [ "_wrap_plgcmap1_range_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a353b601cfe71ab0e29c3426679437ed3", null ],
     [ "_wrap_plgcol0_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a9356bc1d7e75b8b4e89eeed4e9837b06", null ],
     [ "_wrap_plgcol0a_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a33ff8a9ce80ad074a212665248b43359", null ],
     [ "_wrap_plgcolbg_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad59523ca68afcfbf0139250017683a37", null ],
@@ -550,6 +564,7 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "_wrap_plgpage_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a3cb56c1e02dd0a800320bb3ae92b95e0", null ],
     [ "_wrap_plgra_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ae9edd6bffb84c56c14b227b54cee149d", null ],
     [ "_wrap_plgradient_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#afc8bbf76f9aed0216a7dc7e73d2556d7", null ],
+    [ "_wrap_plgriddata_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ac0192a83fc06dbecaf696b811eba49c1", null ],
     [ "_wrap_plgspa_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad6c1830b23066ec1272e75a6da3e32e3", null ],
     [ "_wrap_plgstrm_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a7198af1b4b98936047474e5f9f9a85aa", null ],
     [ "_wrap_plgver_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a531eb694c170e1674dcaa9993e649de8", null ],
@@ -560,6 +575,7 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "_wrap_plgzax_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a730dc323aa59640537133acd57cff60d", null ],
     [ "_wrap_plhist_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aea461967543b0664b4f8e47740e9df46", null ],
     [ "_wrap_plhlsrgb_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aa236c6bec1399905d39e8576ee4d6916", null ],
+    [ "_wrap_plimagefr_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aced4dd5e41a58f1d126a0332d4179cef", null ],
     [ "_wrap_plinit_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a7975d40886664c1c53d41fdedf449100", null ],
     [ "_wrap_pljoin_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad07a9c4fcac378014e82375a664f6961", null ],
     [ "_wrap_pllab_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ab9cde54baf0c8d14ca631917658a63e2", null ],
@@ -569,10 +585,19 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "_wrap_plline_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a73ac1d462f6994ffbd1a6f29aeecea44", null ],
     [ "_wrap_pllsty_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a705e6d891cc869a85e78ae597f6304eb", null ],
     [ "_wrap_plmap_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a61485d75cd2c7bf96f766343011586a5", null ],
+    [ "_wrap_plmapfill_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a653c01bc6b35fb020c1db2c8aa85c223", null ],
+    [ "_wrap_plmapline_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a7c2b14e1e4bb6e5ec4faa64df9c4112b", null ],
+    [ "_wrap_plmapstring_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a47e9a99e16ac455df40cd578a3abdfa1", null ],
+    [ "_wrap_plmaptex_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#adb7310118f8750ab8cc0b6c73de0f209", null ],
     [ "_wrap_plmeridians_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a1a8b540981e35670894f9eda38d00967", null ],
+    [ "_wrap_plmesh_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a6387ee3c522f6fde37faac6ef9f67f9b", null ],
+    [ "_wrap_plmeshc_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a05986bd52600fc7e2d9896a1faa890a6", null ],
     [ "_wrap_plmkstrm_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a0c447aec75278270bc33c5b4af2f4546", null ],
     [ "_wrap_plmtex3_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aa53274e1db64febf0e9201f075116861", null ],
     [ "_wrap_plmtex_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a6132d587658e5f9b5d686120e71b569a", null ],
+    [ "_wrap_plot3d_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a608b9473b4442fcf49fd460d7f9179c4", null ],
+    [ "_wrap_plot3dc_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a20c13f074fc6d38461de38d80311afef", null ],
+    [ "_wrap_plot3dcl_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad4b812626f9f2fcbebd472fc2793c384", null ],
     [ "_wrap_plparseopts_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad50938b99012a96743156299e0bf21b8", null ],
     [ "_wrap_plpat_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad6de6f229517ee07ee9bc2f783db6f03", null ],
     [ "_wrap_plpath_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#accf0b523c4d903538d61bfd6edda9091", null ],
@@ -590,6 +615,7 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "_wrap_plscmap0_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a32e7f636b575d4a19d94cf97bc3fa16f", null ],
     [ "_wrap_plscmap0a_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aead5dc1d59867f1a441bafa41c05cc28", null ],
     [ "_wrap_plscmap0n_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a65f48f537cc71a859d911ce533414569", null ],
+    [ "_wrap_plscmap1_range_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#afea08d524a1f34fc96f67b61079b4bfb", null ],
     [ "_wrap_plscmap1_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a03cf65f0151e6b99793a43192b292470", null ],
     [ "_wrap_plscmap1a_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a8b6dc3c0af9c5fa2f654962909cd1d7e", null ],
     [ "_wrap_plscmap1l_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aad41a3e50d11416b50ffcb5cccc1582c", null ],
@@ -614,6 +640,9 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "_wrap_plsfci_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a4c3dcc40198bd902387211e9e20e62d7", null ],
     [ "_wrap_plsfnam_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a1f9dfda765c853242b80ce0b909bd171", null ],
     [ "_wrap_plsfont_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a9fd95438850d30290a2696b0772d0943", null ],
+    [ "_wrap_plshade1_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a56e6bbe3f1b66306773901d7a6a33901", null ],
+    [ "_wrap_plshade_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a758878c62155eddc4ed09be54c46e585", null ],
+    [ "_wrap_plshades_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a69ba285128deca5a9e650bb24066d5d6", null ],
     [ "_wrap_plslabelfunc_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a4bf96847a6ca31044b2aaf3d1fc73ed2", null ],
     [ "_wrap_plsmaj_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a26597a107bb38cbd32f14a1c046d4d52", null ],
     [ "_wrap_plsmin_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a98f1de558a442b07859ded8fa6e75326", null ],
@@ -631,8 +660,11 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "_wrap_plstring3_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a01915eb364f5a2a95916ca8119109fe8", null ],
     [ "_wrap_plstring_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#adc68738aa382c25d57692734b32a2b9f", null ],
     [ "_wrap_plstripa_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad36ed9784b616cd56c2ba9776ae43a1d", null ],
+    [ "_wrap_plstripc_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a5caf9bb5f1ed7b311d939b522a017110", null ],
     [ "_wrap_plstripd_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a504a917ad44d08564b5997a62de04a63", null ],
     [ "_wrap_plstyl_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a6a4cd8420161832b90cbdba4a3533fa2", null ],
+    [ "_wrap_plsurf3d_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a438a8ffdceab1a2e877ad3fb0615f84b", null ],
+    [ "_wrap_plsurf3dl_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a63c84c9795f5f74f3e4cb372d9cd5176", null ],
     [ "_wrap_plsvect_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#af878cbcf61bf72976099a3399ba9b3ed", null ],
     [ "_wrap_plsvpa_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a13530096b73487b7ce2c59c202c9e813", null ],
     [ "_wrap_plsxax_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aa501592638bfa257b89ecef6f6887068", null ],
@@ -642,6 +674,7 @@ var plplot__octaveOCTAVE__wrap_8cxx =
     [ "_wrap_pltext_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ab734671e68f7032000f6c7e4850f7702", null ],
     [ "_wrap_pltimefmt_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a121d640a5966d8f1aa6fd19ddc7c5f22", null ],
     [ "_wrap_plvasp_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ae2f058e059af4134c502a7184eb2a3c4", null ],
+    [ "_wrap_plvect_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a84f771c2d9c077a0eea911b1b1478a99", null ],
     [ "_wrap_plvpas_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a070f675ffbc42d40983ac0c3fb62af28", null ],
     [ "_wrap_plvpor_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a99d9ee043452c923b369ed08f16431e5", null ],
     [ "_wrap_plvsta_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a03917336709886d45c374df975694c86", null ],
