@@ -81,6 +81,10 @@ var plplotc_8py =
     [ "plline3", "plplotc_8py.html#a8fd9d69aa3170208205856d4064ca516", null ],
     [ "pllsty", "plplotc_8py.html#a7e9b987800e5277fbc195b56cd5f3f49", null ],
     [ "plmap", "plplotc_8py.html#a5b6affc993be756b21ece7816c404478", null ],
+    [ "plmapfill", "plplotc_8py.html#afcfb870505c6a81be260e877afb10e04", null ],
+    [ "plmapline", "plplotc_8py.html#a6ea9579f132977e03636ac5d85abc59a", null ],
+    [ "plmapstring", "plplotc_8py.html#aa0521b644a979a1db294bd2be252e94e", null ],
+    [ "plmaptex", "plplotc_8py.html#aa34e47b4fecf4a423514588598878816", null ],
     [ "plmeridians", "plplotc_8py.html#a5f2729d44d5402bb9f945420feee2d67", null ],
     [ "plmesh", "plplotc_8py.html#af3e6d0fdad8b6a67427930d147139206", null ],
     [ "plmeshc", "plplotc_8py.html#a0e79d559d9865a74922926294fa6dda5", null ],
@@ -292,11 +296,9 @@ var plplotc_8py =
     [ "PL_X_AXIS", "plplotc_8py.html#a8aa8ffa99953ead9bfb1f6325278ffac", null ],
     [ "PL_Y_AXIS", "plplotc_8py.html#aec4a4c625c8cbdface2c1502a4d54417", null ],
     [ "PL_Z_AXIS", "plplotc_8py.html#ab38e608332e8694686898c0e7384e1b3", null ],
-    [ "plbtime", "plplotc_8py.html#ac57c329377a8e187410217994835e3b7", null ],
     [ "plClearOpts", "plplotc_8py.html#a3b5a47229240d9a24ca61397dd0569c2", null ],
-    [ "plconfigtime", "plplotc_8py.html#a09a673e2b90ecab07ba2172cfb8e51a9", null ],
-    [ "plctime", "plplotc_8py.html#a85c5c9bb39768ce6a326b7f254d01106", null ],
     [ "PLESC_ALLOC_NCOL", "plplotc_8py.html#af5019f03e5604c1591d4d3ecef40417a", null ],
+    [ "PLESC_APPEND_BUFFER", "plplotc_8py.html#a3c1b5742671c7991e48b411268807b40", null ],
     [ "PLESC_ARC", "plplotc_8py.html#a88c9dd3a5c5c4ff2900db7a7ee815d69", null ],
     [ "PLESC_BEGIN_TEXT", "plplotc_8py.html#aafa90b4565f0f69e93351cba71598990", null ],
     [ "PLESC_CLEAR", "plplotc_8py.html#a876cf74842ce228ee028a8106c825cce", null ],
@@ -314,7 +316,9 @@ var plplotc_8py =
     [ "PLESC_END_TEXT", "plplotc_8py.html#a6029ac27c7ef2a0e783ca0cb5635e477", null ],
     [ "PLESC_EXPOSE", "plplotc_8py.html#ae38e7b767f85ab19c019a2c739cc7761", null ],
     [ "PLESC_FILL", "plplotc_8py.html#a0161658227f3be0036ce2be29b831977", null ],
+    [ "PLESC_FIXASPECT", "plplotc_8py.html#ab30919de5123e4ff1faeb71651cab801", null ],
     [ "PLESC_FLUSH", "plplotc_8py.html#aae31cc0d750e429823e7722a4c629edc", null ],
+    [ "PLESC_FLUSH_REMAINING_BUFFER", "plplotc_8py.html#aafb7d40ef560973c189bd1af7ea51cad", null ],
     [ "PLESC_GETBACKEND", "plplotc_8py.html#afe5bfb8be365234aef2097a735c35744", null ],
     [ "PLESC_GETC", "plplotc_8py.html#a19d4d2d2836911342deb0281d2e24059", null ],
     [ "PLESC_GRADIENT", "plplotc_8py.html#aacf6b5fe12c4d85313aa861dfa3b84e7", null ],
@@ -322,6 +326,7 @@ var plplotc_8py =
     [ "PLESC_HAS_TEXT", "plplotc_8py.html#af5c0c3836b5e1581d3be64ef852cb13f", null ],
     [ "PLESC_IMAGE", "plplotc_8py.html#a7b8b082fd76f82e745e7c0495a50879e", null ],
     [ "PLESC_IMAGEOPS", "plplotc_8py.html#aeda20276a961b9f1ce5534c3ce37245e", null ],
+    [ "PLESC_IMPORT_BUFFER", "plplotc_8py.html#aca0fe6617fc7fa33eef6df4f2a8eb530", null ],
     [ "PLESC_MODEGET", "plplotc_8py.html#a0319c9e155afcbb122d170f627848c1f", null ],
     [ "PLESC_MODESET", "plplotc_8py.html#a8b9fd0ad5393f5301a06f36b878f4b19", null ],
     [ "PLESC_PL2DEVCOL", "plplotc_8py.html#ab9198fb986a29a87c3eabd6e36e5ddab", null ],
@@ -336,16 +341,12 @@ var plplotc_8py =
     [ "PLESC_TEXT", "plplotc_8py.html#ab412042d6d3501a95aeb452b1bc34ffb", null ],
     [ "PLESC_TEXT_CHAR", "plplotc_8py.html#a78f3b4c904b70f3c49f9ccb9bf79083b", null ],
     [ "PLESC_XORMOD", "plplotc_8py.html#a32d1e35e35329b80334d9c61dc442f52", null ],
-    [ "plgcmap1_range", "plplotc_8py.html#a7c7c83333b23ed5dad0fcfa6d020df3b", null ],
     [ "plGetCursor", "plplotc_8py.html#a113311917620d161413e7706a83975da", null ],
     [ "PLGraphicsIn_swigregister", "plplotc_8py.html#a2ed140e1dae13d8870800c18255c50f5", null ],
     [ "plMinMax2dGrid", "plplotc_8py.html#a02d5cc5e9830406ed04d933dc91b5f34", null ],
     [ "plOptUsage", "plplotc_8py.html#a91a52af2917540a0f9fa00c3c55c2dd2", null ],
-    [ "plot3dcl", "plplotc_8py.html#a5c41a8a1fb515dfe029244bac2fc1bff", null ],
     [ "plResetOpts", "plplotc_8py.html#af38c58a760449cb53d7b41b76d19b27b", null ],
-    [ "plscmap1_range", "plplotc_8py.html#a7ebf98d098f310e799976f5c3fab2e28", null ],
     [ "plSetUsage", "plplotc_8py.html#a21768491ad01b676ba51c3fe07729727", null ],
-    [ "plsurf3dl", "plplotc_8py.html#abfd54fd861d5f19fbf6ce1b32cf6a0bb", null ],
     [ "PLSWIN_DEVICE", "plplotc_8py.html#a9546c5be25c4dee3cedf4d3531e0a271", null ],
     [ "PLSWIN_WORLD", "plplotc_8py.html#a068d68799b04f081e6647a74cc239049", null ],
     [ "plsxwin", "plplotc_8py.html#a334c3242c3767b8820e67016c523434f", null ],
