@@ -290,6 +290,10 @@ var plplotcmodulePYTHON__wrap_8c =
     [ "_wrap_plline3", "plplotcmodulePYTHON__wrap_8c.html#a89a070c6b6b522c95d8fa9006e920bf1", null ],
     [ "_wrap_pllsty", "plplotcmodulePYTHON__wrap_8c.html#aba9d692f444c206c4cdae297147c55a6", null ],
     [ "_wrap_plmap", "plplotcmodulePYTHON__wrap_8c.html#a5f10b5e080208c3718a9ec1a601d34fb", null ],
+    [ "_wrap_plmapfill", "plplotcmodulePYTHON__wrap_8c.html#a5871478c3ebcde368937901ce0daa2b2", null ],
+    [ "_wrap_plmapline", "plplotcmodulePYTHON__wrap_8c.html#ab88b604b872bf011a07222477c61962d", null ],
+    [ "_wrap_plmapstring", "plplotcmodulePYTHON__wrap_8c.html#aeda987ea974a9d8089e8a67fa8531ca6", null ],
+    [ "_wrap_plmaptex", "plplotcmodulePYTHON__wrap_8c.html#a608ce2a34b4ef08a694df51d00375f7d", null ],
     [ "_wrap_plmeridians", "plplotcmodulePYTHON__wrap_8c.html#abb6c8d5f3dc9ef39f5fef8a137df399a", null ],
     [ "_wrap_plmesh", "plplotcmodulePYTHON__wrap_8c.html#a8a9003ba25ee12ff8d44f7bbdb56bf24", null ],
     [ "_wrap_plmeshc", "plplotcmodulePYTHON__wrap_8c.html#a48f5c55480808a873284ec90b3f7887b", null ],
