@@ -168,6 +168,7 @@ var plplotjavacJAVA__wrap_8c =
     [ "Java_plplot_core_plplotjavacJNI_plerrx", "plplotjavacJAVA__wrap_8c.html#a9840854dc9c0e852efcae638f6396495", null ],
     [ "Java_plplot_core_plplotjavacJNI_plerry", "plplotjavacJAVA__wrap_8c.html#a4a75fe85fea5b783878504a01888f771", null ],
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1ALLOC_1NCOL_1get", "plplotjavacJAVA__wrap_8c.html#af1e939044298915799807e37ec2fc48a", null ],
+    [ "Java_plplot_core_plplotjavacJNI_PLESC_1APPEND_1BUFFER_1get", "plplotjavacJAVA__wrap_8c.html#a764fe756de4100ad9be581aa560e6c58", null ],
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1ARC_1get", "plplotjavacJAVA__wrap_8c.html#aabed52349ef35ce2d701d5215a2ca1c8", null ],
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1BEGIN_1TEXT_1get", "plplotjavacJAVA__wrap_8c.html#a96f244f98ebceb120fe9b143de29b1ee", null ],
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1CLEAR_1get", "plplotjavacJAVA__wrap_8c.html#af05798decef9c17f480fa391200538a0", null ],
@@ -185,7 +186,9 @@ var plplotjavacJAVA__wrap_8c =
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1END_1TEXT_1get", "plplotjavacJAVA__wrap_8c.html#a44b2370a838be16d65260ef7dbaeec50", null ],
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1EXPOSE_1get", "plplotjavacJAVA__wrap_8c.html#adfa07b111186b5c7e00fb2d3f849b41d", null ],
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1FILL_1get", "plplotjavacJAVA__wrap_8c.html#ae8c08eeb1f38f758ce11a4c6d3c02cde", null ],
+    [ "Java_plplot_core_plplotjavacJNI_PLESC_1FIXASPECT_1get", "plplotjavacJAVA__wrap_8c.html#ab080435c71b65d72dbc27fff22d67735", null ],
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1FLUSH_1get", "plplotjavacJAVA__wrap_8c.html#a24d39a359ee8050c170a48814dfd2f9b", null ],
+    [ "Java_plplot_core_plplotjavacJNI_PLESC_1FLUSH_1REMAINING_1BUFFER_1get", "plplotjavacJAVA__wrap_8c.html#a52fd705c9766547c8617c6df4ebcfffe", null ],
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1GETBACKEND_1get", "plplotjavacJAVA__wrap_8c.html#af85d39b5f313f282bd4af65ea3fdbbd7", null ],
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1GETC_1get", "plplotjavacJAVA__wrap_8c.html#aff3bde1c6d631def66a5ccec185fecf4", null ],
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1GRADIENT_1get", "plplotjavacJAVA__wrap_8c.html#ae85dc845b5922da2b8259cb268f3e8c2", null ],
@@ -193,6 +196,7 @@ var plplotjavacJAVA__wrap_8c =
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1HAS_1TEXT_1get", "plplotjavacJAVA__wrap_8c.html#ab36494ce8f917381e446fa5cf12388cc", null ],
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1IMAGE_1get", "plplotjavacJAVA__wrap_8c.html#a14b2fdc4815084a8ccb05f499fa66b35", null ],
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1IMAGEOPS_1get", "plplotjavacJAVA__wrap_8c.html#a36449dbb6e0db65fc65fb67430df54b1", null ],
+    [ "Java_plplot_core_plplotjavacJNI_PLESC_1IMPORT_1BUFFER_1get", "plplotjavacJAVA__wrap_8c.html#a1a3442ec0d744a4e3a5871a084f6159f", null ],
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1MODEGET_1get", "plplotjavacJAVA__wrap_8c.html#a4cc7abf65fbf5a25b59bfd7bf4d187a1", null ],
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1MODESET_1get", "plplotjavacJAVA__wrap_8c.html#a096d65477297e0cd06c2219dd17e76cf", null ],
     [ "Java_plplot_core_plplotjavacJNI_PLESC_1PL2DEVCOL_1get", "plplotjavacJAVA__wrap_8c.html#ae8603cc51a4dabf89d42e62c51265b64", null ],
@@ -279,6 +283,10 @@ var plplotjavacJAVA__wrap_8c =
     [ "Java_plplot_core_plplotjavacJNI_plline3", "plplotjavacJAVA__wrap_8c.html#aef6dd8db2de4ec2717b9c0261473426e", null ],
     [ "Java_plplot_core_plplotjavacJNI_pllsty", "plplotjavacJAVA__wrap_8c.html#a2ab116317ee6bfad7811215b82d735d3", null ],
     [ "Java_plplot_core_plplotjavacJNI_plmap", "plplotjavacJAVA__wrap_8c.html#a5a382f9a231f093ff8c0b81a4e9031b8", null ],
+    [ "Java_plplot_core_plplotjavacJNI_plmapfill", "plplotjavacJAVA__wrap_8c.html#a960648930da60a3ceb2c5ea187d02ced", null ],
+    [ "Java_plplot_core_plplotjavacJNI_plmapline", "plplotjavacJAVA__wrap_8c.html#a1b484c279f107edb48d073818f6b9d42", null ],
+    [ "Java_plplot_core_plplotjavacJNI_plmapstring", "plplotjavacJAVA__wrap_8c.html#a22b680a560a5ae5385092255e35e6aca", null ],
+    [ "Java_plplot_core_plplotjavacJNI_plmaptex", "plplotjavacJAVA__wrap_8c.html#afd3411e9d8eb93a413f913539a4f18b2", null ],
     [ "Java_plplot_core_plplotjavacJNI_plmeridians", "plplotjavacJAVA__wrap_8c.html#ae06f6b61c1d928bd8291fb80a48c086e", null ],
     [ "Java_plplot_core_plplotjavacJNI_plmesh", "plplotjavacJAVA__wrap_8c.html#a22461988e3976a9aec474b201bb727c3", null ],
     [ "Java_plplot_core_plplotjavacJNI_plmeshc", "plplotjavacJAVA__wrap_8c.html#a08e0e04b38cd041ee6c0fc2be9083185", null ],
@@ -380,7 +388,7 @@ var plplotjavacJAVA__wrap_8c =
     [ "Java_plplot_core_plplotjavacJNI_plvpor", "plplotjavacJAVA__wrap_8c.html#a48cc48baf7e9d5a341c4fd8268819b76", null ],
     [ "Java_plplot_core_plplotjavacJNI_plvsta", "plplotjavacJAVA__wrap_8c.html#aa2c86631075a89f58f21bfde945c545a", null ],
     [ "Java_plplot_core_plplotjavacJNI_plw3d", "plplotjavacJAVA__wrap_8c.html#ab570444bd97efc6102c7595f19526dae", null ],
-    [ "Java_plplot_core_plplotjavacJNI_plwidth", "plplotjavacJAVA__wrap_8c.html#a08dccc5337029a69938a73ed78f6c3d1", null ],
+    [ "Java_plplot_core_plplotjavacJNI_plwidth", "plplotjavacJAVA__wrap_8c.html#a5992a40216c22c599ee3c1f71fac7c3b", null ],
     [ "Java_plplot_core_plplotjavacJNI_plwind", "plplotjavacJAVA__wrap_8c.html#a61a640cea0971a16c0a12c48f5c36379", null ],
     [ "Java_plplot_core_plplotjavacJNI_plxormod", "plplotjavacJAVA__wrap_8c.html#a13ffa7368db75f7f381db576cb875af2", null ],
     [ "Java_plplot_core_plplotjavacJNI_SURF_1CONT_1get", "plplotjavacJAVA__wrap_8c.html#a320b2d94c05c16bef8f35241f19a9efb", null ],
