@@ -188,6 +188,10 @@ var plplotluacLUA__wrap_8c =
     [ "_wrap_line3", "plplotluacLUA__wrap_8c.html#a98085ca4ca86066c4b8eee25ccbd4bc8", null ],
     [ "_wrap_lsty", "plplotluacLUA__wrap_8c.html#ab3159c1edf08576a7cef1e00d1562e2e", null ],
     [ "_wrap_map", "plplotluacLUA__wrap_8c.html#a70f6fbe3b32794252cee4a9bbe01972e", null ],
+    [ "_wrap_mapfill", "plplotluacLUA__wrap_8c.html#a82635b58ada80aeee732178f9623e86e", null ],
+    [ "_wrap_mapline", "plplotluacLUA__wrap_8c.html#ab63d650c968d84167ad65199b231c86b", null ],
+    [ "_wrap_mapstring", "plplotluacLUA__wrap_8c.html#ad6ba2984c1ac54a5b84d5d383d474ec2", null ],
+    [ "_wrap_maptex", "plplotluacLUA__wrap_8c.html#af5eddf160051337c0dce926bf689951a", null ],
     [ "_wrap_meridians", "plplotluacLUA__wrap_8c.html#a201353c8f482b8960dec6f98ece9781d", null ],
     [ "_wrap_mesh", "plplotluacLUA__wrap_8c.html#a0ed87b1f9162641c692d0126a013ea31", null ],
     [ "_wrap_meshc", "plplotluacLUA__wrap_8c.html#aada58c84a8d35fc760881bb2798f1085", null ],
