@@ -5,5 +5,6 @@ var sc3d_8c =
     [ "PLOT3D", "sc3d_8c.html#a3b22c17a7a31c5f5a8d6ff113bcc7a3a", null ],
     [ "PLOT3DC", "sc3d_8c.html#a5f5190e259bcf65f4134aeb3aeabf385", null ],
     [ "PLOT3DC__", "sc3d_8c.html#a8187b432d933d935aae39948486f69d3", null ],
-    [ "PLSURF3D", "sc3d_8c.html#a455963e2f09dc62c8760023c0125d3eb", null ]
+    [ "PLSURF3D", "sc3d_8c.html#a455963e2f09dc62c8760023c0125d3eb", null ],
+    [ "PLSURF3DL", "sc3d_8c.html#a92cb3658e1566174edb0d4a422acfdfd", null ]
 ];
\ No newline at end of file
