@@ -14,12 +14,10 @@ var searchData=
   ['db',['db',['../structPLStream.html#a5b485e23de946ddaae43b13a71d120a2',1,'PLStream']]],
   ['dbug_5fenter',['dbug_enter',['../tclMatrix_8c.html#a6654afec69a24f13f463c90e1c62def5',1,'dbug_enter():&#160;tclMatrix.c'],['../pldebug_8h.html#a6654afec69a24f13f463c90e1c62def5',1,'dbug_enter():&#160;pldebug.h']]],
   ['dcast',['dcast',['../structswig__type__info.html#a07df4bedf85be77b23756b531b60e0dd',1,'swig_type_info']]],
-  ['dcgettext',['dcgettext',['../plplotcanvas-hacktext_8c.html#a115dd6a6dd9d7a249f6374a7c06deef5',1,'plplotcanvas-hacktext.c']]],
-  ['debug',['debug',['../structPLStream.html#a5083e76d7de0c5588dcb018bc2a82a37',1,'PLStream::debug()'],['../pdfutils_8c.html#ac3e1795766a80ec63b157951b4b9a7d4',1,'debug():&#160;pdfutils.c'],['../namespacePlframe.html#aea18aacc2b02182d559394b7a0e9a278',1,'Plframe.debug()'],['../plcore_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;plcore.c'],['../plctrl_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;plctrl.c'],['../plmap_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;plmap.c'],['../ps_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;ps.c'],['../tk_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;tk.c'],['../tkwin_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;tkwin.c'],['../xwin_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;xwin.c']]],
+  ['debug',['debug',['../structPLStream.html#a5083e76d7de0c5588dcb018bc2a82a37',1,'PLStream::debug()'],['../pdfutils_8c.html#ac3e1795766a80ec63b157951b4b9a7d4',1,'debug():&#160;pdfutils.c'],['../namespacePlframe.html#aea18aacc2b02182d559394b7a0e9a278',1,'Plframe.debug()'],['../plcore_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;plcore.c'],['../plctrl_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;plctrl.c'],['../plmap_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;plmap.c'],['../ps_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;ps.c'],['../tk_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;tk.c'],['../tkwin_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;tkwin.c'],['../wxwidgets__dev_8cpp.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;wxwidgets_dev.cpp'],['../xwin_8c.html#ad72dbcf6d0153db1b8d8a58001feed83',1,'DEBUG():&#160;xwin.c']]],
   ['debugx',['DEBUGx',['../plframe_8c.html#aa0e4d6a92f0c37ad99ae6f1053184ed5',1,'plframe.c']]],
   ['declare_5foctave_5fallocator',['DECLARE_OCTAVE_ALLOCATOR',['../classoctave__swig__ref.html#a72e925362835c43be262e4cfaf616dc1',1,'octave_swig_ref::DECLARE_OCTAVE_ALLOCATOR()'],['../classoctave__swig__packed.html#aa238bbb14ac6ff2139e300a78faa871b',1,'octave_swig_packed::DECLARE_OCTAVE_ALLOCATOR()']]],
   ['declare_5fov_5ftypeid_5ffunctions_5fand_5fdata',['DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA',['../classoctave__swig__ref.html#ab71cb80e748fd244ad22e1ca10173408',1,'octave_swig_ref::DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA()'],['../classoctave__swig__packed.html#ae34643b7178a4835df5f4e5af61dce9f',1,'octave_swig_packed::DECLARE_OV_TYPEID_FUNCTIONS_AND_DATA()']]],
-  ['declare_5fplapp',['DECLARE_PLAPP',['../wxwidgets_8h.html#a5eda1e630d912b7d19a2aa0358ae8e78',1,'wxwidgets.h']]],
   ['decref',['decref',['../classoctave__swig__type.html#a448579e13a4df84a340166bcf8d66acb',1,'octave_swig_type']]],
   ['deepblue',['DeepBlue',['../plstream_8h.html#af38a775b953a654b78d0f13cf899f38ba059f250df53b7e6ea4b8b11dd9543e61',1,'plstream.h']]],
   ['def_5fplframe_5fbg_5fcolor',['DEF_PLFRAME_BG_COLOR',['../plframe_8c.html#a93009e093b0641f30748d9d2c0e5b859',1,'DEF_PLFRAME_BG_COLOR():&#160;plframe.c'],['../plplotter_8c.html#a93009e093b0641f30748d9d2c0e5b859',1,'DEF_PLFRAME_BG_COLOR():&#160;plplotter.c']]],
@@ -48,8 +46,8 @@ var searchData=
   ['delaunay_5fdestroy',['delaunay_destroy',['../delaunay_8c.html#a9385b99c0c93a5bb3cd9432b42ccb464',1,'delaunay_destroy(delaunay *d):&#160;delaunay.c'],['../nn_8h.html#a9385b99c0c93a5bb3cd9432b42ccb464',1,'delaunay_destroy(delaunay *d):&#160;delaunay.c']]],
   ['delaunay_5fxytoi',['delaunay_xytoi',['../delaunay_8c.html#a74337be0f7cc8fa5de9c5642037519c0',1,'delaunay_xytoi(delaunay *d, point *p, int id):&#160;delaunay.c'],['../lpi_8c.html#ac85731ad69839b9afb78272dae4a71d7',1,'delaunay_xytoi(delaunay *d, point *p, int seed):&#160;delaunay.c'],['../nnpi_8c.html#ac85731ad69839b9afb78272dae4a71d7',1,'delaunay_xytoi(delaunay *d, point *p, int seed):&#160;delaunay.c']]],
   ['delete',['delete',['../classplplot_1_1core_1_1PLGraphicsIn.html#a514cff07dbad695a8015934d887b77ce',1,'plplot::core::PLGraphicsIn']]],
-  ['delete_5fevent',['delete_event',['../gcw-lib_8c.html#a2292ff432073c3885c2d6ee3101ccd52',1,'gcw-lib.c']]],
   ['delete_5fplgraphicsin',['delete_PLGraphicsIn',['../classplplot_1_1core_1_1plplotjavacJNI.html#a1d7be0b0c2e45eb328af3a0724d8a2b8',1,'plplot::core::plplotjavacJNI']]],
+  ['delete_5fplplotqt_5fsmoke',['delete_plplotqt_Smoke',['../plplotqt__smoke_8h.html#a61982820f42770dd268a2f1a8e09773e',1,'plplotqt_smoke.h']]],
   ['deletedata',['deleteData',['../structCommand.html#af5085ae0b6dca11a1b532731b2f54d7b',1,'Command']]],
   ['deletematrixcmd',['DeleteMatrixCmd',['../tclMatrix_8c.html#a847ca9aa013a7b23327afa8e513d39e5',1,'tclMatrix.c']]],
   ['deletematrixvar',['DeleteMatrixVar',['../tclMatrix_8c.html#a2627854222628cfcceffed0c995945e5',1,'DeleteMatrixVar(ClientData clientData, Tcl_Interp *interp, char *name1, char *name2, int flags):&#160;tclMatrix.c'],['../tclMatrix_8c.html#a7d4589c349b0241f669b74d702cca383',1,'DeleteMatrixVar(ClientData clientData, Tcl_Interp *PL_UNUSED(interp), char *PL_UNUSED(name1), char *PL_UNUSED(name2), int PL_UNUSED(flags)):&#160;tclMatrix.c']]],
@@ -59,8 +57,8 @@ var searchData=
   ['deltat_2eh',['deltaT.h',['../deltaT_8h.html',1,'']]],
   ['deltat_5ftest_2ec',['deltaT_test.c',['../deltaT__test_8c.html',1,'']]],
   ['depth',['depth',['../structTkwDisplay.html#a9426efee240bc4a860ee9331a1b2c537',1,'TkwDisplay::depth()'],['../structXwDisplay.html#a56193de1c93773eafd82499cd1b00717',1,'XwDisplay::depth()']]],
-  ['desc',['desc',['../structcdImageStruct.html#a0e1ec004c6a0169c15ae3e029db44a86',1,'cdImageStruct::desc()'],['../structplplot_1_1__N1.html#af0534204dc57ea02028dbd2b9060e591',1,'plplot::_N1::desc()'],['../structPLOptionTable.html#a911b32327a6078131c7810248c0f02cc',1,'PLOptionTable::desc()'],['../structPLOptionTable.html#a1995b25c4986689365c2be3041c6af7e',1,'PLOptionTable::desc()']]],
-  ['destroy',['destroy',['../structSwigPyClientData.html#a1c4e62712f23db599e85e24e14818d59',1,'SwigPyClientData::destroy()'],['../gcw-lib_8c.html#aeb938f6238d2b18776edf7169b1b303d',1,'destroy():&#160;gcw-lib.c']]],
+  ['desc',['desc',['../structcdImageStruct.html#a0e1ec004c6a0169c15ae3e029db44a86',1,'cdImageStruct::desc()'],['../structplplot_1_1__N1.html#af0534204dc57ea02028dbd2b9060e591',1,'plplot::_N1::desc()'],['../structPLOptionTable.html#a911b32327a6078131c7810248c0f02cc',1,'PLOptionTable::desc()']]],
+  ['destroy',['destroy',['../structSwigPyClientData.html#a1c4e62712f23db599e85e24e14818d59',1,'SwigPyClientData']]],
   ['destroyed',['destroyed',['../structoctave__swig__type_1_1cpp__ptr.html#aa26dc33d9fabfdafd2ff3fb988c4a21b',1,'octave_swig_type::cpp_ptr']]],
   ['destroyplframe',['DestroyPlFrame',['../plframe_8c.html#a9e40812ac6b589fcc9eb6aae31d8235e',1,'plframe.c']]],
   ['destroyplplotter',['DestroyPlPlotter',['../plplotter_8c.html#a5e501919508d1aabed0725d563446623',1,'plplotter.c']]],
@@ -68,10 +66,12 @@ var searchData=
   ['destroyxhairs',['DestroyXhairs',['../plframe_8c.html#a6e279cc9a9c417879fb220ac7d4d81d4',1,'DestroyXhairs(PlFrame *):&#160;plframe.c'],['../plplotter_8c.html#a6a4925ce3cc48bdde85bd7032a7c76b0',1,'DestroyXhairs(PlPlotter *):&#160;plplotter.c']]],
   ['destructor',['destructor',['../structswig__lua__class.html#ae7029d37913cf77df8f5c473c5cb43fe',1,'swig_lua_class::destructor()'],['../structswig__octave__class.html#a5e1ac4d7d832f631bc2001bfceeb374b',1,'swig_octave_class::destructor()']]],
   ['dev',['dev',['../structPLStream.html#abf8a6d71f35aeb854e3c75f5ed4f7679',1,'PLStream']]],
+  ['dev_5f2005_5fheader',['dev_2005_header',['../plmetafile_8c.html#a355ad03ff95e155e9ef4654d7e15bb65',1,'plmetafile.c']]],
   ['dev_5farc',['dev_arc',['../structPLStream.html#a263a03b7f7481ecf73b47b50821d3006',1,'PLStream']]],
   ['dev_5fclear',['dev_clear',['../structPLStream.html#a5ffd0f763c8d12a0912ebc4355377329',1,'PLStream']]],
   ['dev_5fcompression',['dev_compression',['../structPLStream.html#a0b1b2bd10b03c184910e90aac79dddce',1,'PLStream']]],
   ['dev_5fdash',['dev_dash',['../structPLStream.html#a537ff4fef08a7f0978ac8f285739b54d',1,'PLStream']]],
+  ['dev_5fdata',['dev_data',['../structPLStream.html#a64a27bd343528519bc7b9172ac9ae43b',1,'PLStream']]],
   ['dev_5fdi',['dev_di',['../structPLStream.html#ae84e24623a23d971c07e914557276808',1,'PLStream']]],
   ['dev_5fentry',['dev_entry',['../structdev__entry.html',1,'']]],
   ['dev_5feofill',['dev_eofill',['../structPLStream.html#ae43fbab5ba68a7c71f4cf5385178b2ff',1,'PLStream']]],
@@ -103,15 +103,12 @@ var searchData=
   ['dev_5fz',['dev_z',['../structPLStream.html#a9c5fe11361bfc214207b1bf769199780',1,'PLStream']]],
   ['dev_5fzmax',['dev_zmax',['../structPLStream.html#aa1ab99774297abc47e0ae0a29b1c62fd',1,'PLStream']]],
   ['dev_5fzmin',['dev_zmin',['../structPLStream.html#a6b267f89557ceef8790911bbb9062bb7',1,'PLStream']]],
-  ['devdesc',['devDesc',['../classwxPLDevBase.html#ad2e494bf6b6c520492cd4a39d50b4ee9',1,'wxPLDevBase::devDesc()'],['../structPlFrame.html#a409578178dbf1cd9bbdf2ce4279503c8',1,'PlFrame::devDesc()'],['../structPlPlotter.html#aaea02031eb53d6fa673b96f19a626a3c',1,'PlPlotter::devDesc()']]],
+  ['devdesc',['devDesc',['../structPlFrame.html#a409578178dbf1cd9bbdf2ce4279503c8',1,'PlFrame::devDesc()'],['../structPlPlotter.html#aaea02031eb53d6fa673b96f19a626a3c',1,'PlPlotter::devDesc()']]],
   ['device',['device',['../structPLStream.html#aba76488f65f93041f7448fee09966b49',1,'PLStream']]],
-  ['device_5fpixels_5fper_5fin',['DEVICE_PIXELS_PER_IN',['../wxwidgets_8h.html#ac27be500dbb52509acecc23bb0eb7c54',1,'DEVICE_PIXELS_PER_IN():&#160;wxwidgets.h'],['../gcw_8h.html#ac27be500dbb52509acecc23bb0eb7c54',1,'DEVICE_PIXELS_PER_IN():&#160;gcw.h']]],
-  ['device_5fpixels_5fper_5fmm',['DEVICE_PIXELS_PER_MM',['../wxwidgets_8h.html#a11f2550b698a4ded14be08a8412314e9',1,'DEVICE_PIXELS_PER_MM():&#160;wxwidgets.h'],['../gcw_8h.html#a11f2550b698a4ded14be08a8412314e9',1,'DEVICE_PIXELS_PER_MM():&#160;gcw.h']]],
+  ['device_5fheader',['device_header',['../struct__plm__version.html#a4c0e4696f49c6ea945f336f1906b3965',1,'_plm_version']]],
   ['devicechangedpage',['DeviceChangedPage',['../classMasterHandler.html#a116d7f4335e46e6e281fa546991983c9',1,'MasterHandler']]],
   ['deviceclosed',['DeviceClosed',['../classMasterHandler.html#a7777a99d4053d69e61bb2134ad730fbe',1,'MasterHandler']]],
-  ['devname',['DevName',['../structPLStream.html#aab9c4166d130ca8e402b0b1c5e2539fe',1,'PLStream::DevName()'],['../classwxPLDevBase.html#a54fd03da71b60477cf5dff160eb4361a',1,'wxPLDevBase::devName()'],['../structPlFrame.html#a6bd51c8ea7742c10c24bf57f19a37583',1,'PlFrame::devName()'],['../structPlPlotter.html#a91a6a822d164ae7622b16657567dc372',1,'PlPlotter::devName()']]],
-  ['dg300_2ec',['dg300.c',['../dg300_8c.html',1,'']]],
-  ['dgettext',['dgettext',['../plplotcanvas-hacktext_8c.html#ad24abc7110e1bdf384dc2ef2b63e5d07',1,'plplotcanvas-hacktext.c']]],
+  ['devname',['devName',['../structPlFrame.html#a6bd51c8ea7742c10c24bf57f19a37583',1,'PlFrame::devName()'],['../structPlPlotter.html#a91a6a822d164ae7622b16657567dc372',1,'PlPlotter::devName()'],['../structPLStream.html#aab9c4166d130ca8e402b0b1c5e2539fe',1,'PLStream::DevName()']]],
   ['diclpxma',['diclpxma',['../structPLStream.html#acc943d43125d39d5abdc7b66a53944a9',1,'PLStream']]],
   ['diclpxmi',['diclpxmi',['../structPLStream.html#aedabf7549e134fb86674e4456e3b3313',1,'PLStream']]],
   ['diclpyma',['diclpyma',['../structPLStream.html#a97be1e95c2579b1fc3ed24da73601574',1,'PLStream']]],
@@ -172,7 +169,6 @@ var searchData=
   ['dist2',['dist2',['../plgridd_8c.html#a427e9eaadf932ecdffbf94de43b0d8d1',1,'plgridd.c']]],
   ['distance',['distance',['../csa_8c.html#a35d71de6ce16c9812718704541edc013',1,'csa.c']]],
   ['div',['div',['../structplf2ops__t.html#adee8c7c790b5b49672909c53f505a5d4',1,'plf2ops_t']]],
-  ['dl_5fexport',['DL_EXPORT',['../cplplotcanvasmodule_8c.html#ab6c4387b175af38aba519ffab93c7e89',1,'cplplotcanvasmodule.c']]],
   ['do_5fct_5fcallback',['do_ct_callback',['../plplotcmodulePYTHON__wrap_8c.html#aa55de72b3611b0c8da14b06623b31d00',1,'plplotcmodulePYTHON_wrap.c']]],
   ['do_5ff2eval_5fcallback',['do_f2eval_callback',['../plplotcmodulePYTHON__wrap_8c.html#a186e3ee0d5d1fd3e9dcc77c8946d9607',1,'plplotcmodulePYTHON_wrap.c']]],
   ['do_5flabel_5fcallback',['do_label_callback',['../plplotcmodulePYTHON__wrap_8c.html#a5b0321ad235146d11e01257ddf5783e2',1,'plplotcmodulePYTHON_wrap.c']]],
@@ -201,25 +197,29 @@ var searchData=
   ['draw_5fliney_5fget',['DRAW_LINEY_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#a55620e6b0397d1833e69d4fe877cef5c',1,'plplot::core::plplotjavacJNI']]],
   ['draw_5fsides',['DRAW_SIDES',['../classplplot.html#a498074676eb148d19d7465505e44ae2c',1,'plplot::DRAW_SIDES()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a1045c9467abda926a1710b7103962e9b',1,'plplot.core.plplotjavacConstants.DRAW_SIDES()'],['../plplot_8h.html#a97f8c99c7977160450c93302222ff923',1,'DRAW_SIDES():&#160;plplot.h'],['../namespaceplplotc.html#a666c56f6d51ce51bd51c15bde0834f75',1,'plplotc.DRAW_SIDES()']]],
   ['draw_5fsides_5fget',['DRAW_SIDES_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#ae29a29a6dc31c02746e380652a402275',1,'plplot::core::plplotjavacJNI']]],
-  ['draw_5fxhair',['draw_xhair',['../classwxPLDevBase.html#ae250fd8cea147a1c3782102f5228274e',1,'wxPLDevBase']]],
   ['drawarc',['drawArc',['../classQtPLDriver.html#a5cf646c1903e03bcb412c89f300dcbd7',1,'QtPLDriver']]],
-  ['drawcrosshair',['DrawCrosshair',['../classwxPLplotWindow.html#a826060a0d14d9a2ecc97a3d6405159c1',1,'wxPLplotWindow']]],
   ['drawing',['DRAWING',['../plcore_8c.html#a06fc87d81c62e9abb8790b6e5713c55ba958d99ff23a05900a8e5cf1a56055098',1,'plcore.c']]],
   ['drawing_5frband',['drawing_rband',['../structPlFrame.html#adf4ddc0c44164d8a0d5bdfa3e0878aef',1,'PlFrame::drawing_rband()'],['../structPlPlotter.html#a153b99d69175b18f0691cc1d0d593c4e',1,'PlPlotter::drawing_rband()']]],
   ['drawing_5fxhairs',['drawing_xhairs',['../structPlFrame.html#a983f748494f81aecc7bd02ad139b168c',1,'PlFrame::drawing_xhairs()'],['../structPlPlotter.html#af10abb0cf0b1266ccdf1641e6551b2af',1,'PlPlotter::drawing_xhairs()'],['../structTkwDev.html#a3e454f604d96880ce717313096bc51c6',1,'TkwDev::drawing_xhairs()'],['../structXwDev.html#a9a6b2d42496aa00b41eac624b8b70101',1,'XwDev::drawing_xhairs()']]],
-  ['drawline',['DrawLine',['../classwxPLDevBase.html#a398d257d3f9e6ab194af82dfa5d0fb58',1,'wxPLDevBase::DrawLine()'],['../classwxPLDevDC.html#add018c6a682c831c6e7ff304a6fdf056',1,'wxPLDevDC::DrawLine()'],['../classQtPLDriver.html#a38b4f012ad0e81163a19b305c0bf8406',1,'QtPLDriver::drawLine()']]],
+  ['drawingobjectschanger',['DrawingObjectsChanger',['../classDrawingObjectsChanger.html',1,'DrawingObjectsChanger'],['../classDrawingObjectsChanger.html#aaf5fe3bbb3ebbec3cb8ff0f0c358c044',1,'DrawingObjectsChanger::DrawingObjectsChanger()']]],
+  ['drawline',['DrawLine',['../classwxPLDevice.html#a024a6ab0b2b388e6cf576f19eb570012',1,'wxPLDevice::DrawLine()'],['../classQtPLDriver.html#a38b4f012ad0e81163a19b305c0bf8406',1,'QtPLDriver::drawLine()']]],
+  ['drawmap',['drawmap',['../plmap_8c.html#a94b2114d27fff7fb57a6ff0265214d29',1,'plmap.c']]],
+  ['drawmapdata',['drawmapdata',['../plmap_8c.html#a6b5ddc18b28888ae7e6188e7a53a8416',1,'plmap.c']]],
   ['drawpolygon',['drawPolygon',['../classQtPLDriver.html#a9a8b786c8cbb7842e5afd1d0692c4748',1,'QtPLDriver']]],
-  ['drawpolyline',['DrawPolyline',['../classwxPLDevBase.html#a0dc4554d37d5bec568cba799055fca9a',1,'wxPLDevBase::DrawPolyline()'],['../classwxPLDevDC.html#ae3dc2d73d31b3596772960b3ad9d9bfb',1,'wxPLDevDC::DrawPolyline()'],['../classQtPLDriver.html#a48608fec3c86975f597e2741877b9a3d',1,'QtPLDriver::drawPolyline()']]],
+  ['drawpolyline',['DrawPolyline',['../classwxPLDevice.html#a01db4914fcf1edabcc2e4bb0ccbe4771',1,'wxPLDevice::DrawPolyline()'],['../classQtPLDriver.html#a48608fec3c86975f597e2741877b9a3d',1,'QtPLDriver::drawPolyline()']]],
   ['drawrband',['DrawRband',['../plframe_8c.html#a15a2da7baf33ee3bcf95a3fa301a4a78',1,'DrawRband(PlFrame *, int, int):&#160;plframe.c'],['../plplotter_8c.html#a34e94728a8cbb3f868617819d2e21f93',1,'DrawRband(PlPlotter *, int, int):&#160;plplotter.c']]],
   ['drawtext',['drawText',['../classQtPLDriver.html#ac2fa93d479f3c737375f933d9eff4e32',1,'QtPLDriver']]],
   ['drawtextinpicture',['drawTextInPicture',['../classQtPLDriver.html#ab60f69a6b11708230670c807f4cc5b4d',1,'QtPLDriver']]],
+  ['drawtextline',['DrawTextLine',['../classwxPLDevice.html#aed5eee301b35cddca3df03aed98831df',1,'wxPLDevice']]],
+  ['drawtextsection',['DrawTextSection',['../classwxPLDevice.html#a3467fe2089747cce63432170380719d6',1,'wxPLDevice']]],
   ['drawxhairs',['DrawXhairs',['../plframe_8c.html#ad0fc44bf75ba9c49e410b8758ab2e5a7',1,'DrawXhairs(PlFrame *, int, int):&#160;plframe.c'],['../plplotter_8c.html#a88797198c2fdfdb31fedd9f8201dc27a',1,'DrawXhairs(PlPlotter *, int, int):&#160;plplotter.c']]],
+  ['driver_5finterface',['DRIVER_INTERFACE',['../metadefs_8h.html#a69063a66eb5cc1673e7898be53e40bd5',1,'metadefs.h']]],
   ['drivers_2eh',['drivers.h',['../drivers_8h.html',1,'']]],
   ['drv_5fdir',['DRV_DIR',['../plplot__config_8h.html#a1aeab21c6fb43c1aa1c36717a7ad8855',1,'plplot_config.h']]],
-  ['drv_5fflt',['DRV_FLT',['../plplotP_8h.html#a61dadd085c1777f559549e05962b2c9ea003e5f646837605b279c4a3e21a9e55d',1,'plplotP.h']]],
-  ['drv_5fint',['DRV_INT',['../plplotP_8h.html#a61dadd085c1777f559549e05962b2c9eaa346c93ff529b2e76f26fff7dcb37c92',1,'plplotP.h']]],
+  ['drv_5fflt',['DRV_FLT',['../plplotP_8h.html#adc29c2ff13d900c2f185ee95427fb06ca003e5f646837605b279c4a3e21a9e55d',1,'plplotP.h']]],
+  ['drv_5fint',['DRV_INT',['../plplotP_8h.html#adc29c2ff13d900c2f185ee95427fb06caa346c93ff529b2e76f26fff7dcb37c92',1,'plplotP.h']]],
   ['drv_5fopt',['drv_opt',['../plargs_8c.html#ad42924d347ff680f9d8e7eb36415f079',1,'plargs.c']]],
-  ['drv_5fstr',['DRV_STR',['../plplotP_8h.html#a61dadd085c1777f559549e05962b2c9eac8cb0d9ed936be241f5a8d60e42056c2',1,'plplotP.h']]],
+  ['drv_5fstr',['DRV_STR',['../plplotP_8h.html#adc29c2ff13d900c2f185ee95427fb06cac8cb0d9ed936be241f5a8d60e42056c2',1,'plplotP.h']]],
   ['drvopt',['DrvOpt',['../structDrvOpt.html',1,'']]],
   ['drvoptcmd',['DrvOptCmd',['../structDrvOptCmd.html',1,'DrvOptCmd'],['../plargs_8c.html#a9f5d22d9bb9fd5fa8fa4c5e047003797',1,'DrvOptCmd():&#160;plargs.c']]],
   ['drvspec_5flen',['DRVSPEC_LEN',['../test-drv-info_8c.html#afbf160acae1f06ccb188f3c8cdf7f8d1',1,'test-drv-info.c']]],
@@ -235,10 +235,10 @@ var searchData=
   ['dum_5fuchar',['dum_uchar',['../plr_8c.html#ae41f387fd9b07755f1b68ea2b834786f',1,'plr.c']]],
   ['dum_5fushort',['dum_ushort',['../plr_8c.html#a7379e9a3346908d1d9c0eac320a065f4',1,'plr.c']]],
   ['dvalue',['dvalue',['../structswig__lua__const__info.html#ac50e848b2a6a628fa1eeb4924f608cee',1,'swig_lua_const_info::dvalue()'],['../structswig__const__info.html#a74e477f1dbf515bcb7e2ef07a1d34c35',1,'swig_const_info::dvalue()']]],
-  ['dx',['dx',['../structplplot__types_1_1plgraphicsin.html#abc57524390f4a7fc09af693f02beaece',1,'plplot_types::plgraphicsin::dx()'],['../structIMG__DT.html#a96c130e4360f7780f2d161c0a3f32108',1,'IMG_DT::dx()'],['../structplplot_1_1__N2.html#ac646480593d84982db2b8e860117d475',1,'plplot::_N2::dX()'],['../structPLGraphicsIn.html#ae15d582003fed123c0d48d422bffd144',1,'PLGraphicsIn::dX()'],['../namespacePlframe.html#a2def17e5a9cb1392e4f4fa30fd6de33e',1,'Plframe.dx()']]],
+  ['dx',['dx',['../structplplot__graphics_1_1plgraphicsin.html#ac3f083e4645ed568195d759a57fb6816',1,'plplot_graphics::plgraphicsin::dx()'],['../structIMG__DT.html#a96c130e4360f7780f2d161c0a3f32108',1,'IMG_DT::dx()'],['../structplplot_1_1__N2.html#ac646480593d84982db2b8e860117d475',1,'plplot::_N2::dX()'],['../structPLGraphicsIn.html#ae15d582003fed123c0d48d422bffd144',1,'PLGraphicsIn::dX()'],['../namespacePlframe.html#a2def17e5a9cb1392e4f4fa30fd6de33e',1,'Plframe.dx()']]],
   ['dxma',['dxma',['../structplplot_1_1__N3.html#a5fa61330c619cd69264439d602c5efd2',1,'plplot::_N3::dxma()'],['../structPLWindow.html#aa7846632259bd8ddb2cf695b4112232a',1,'PLWindow::dxma()']]],
   ['dxmi',['dxmi',['../structplplot_1_1__N3.html#aefe9237accf83fb06db55ab6a10e7ee8',1,'plplot::_N3::dxmi()'],['../structPLWindow.html#afa3570309e945c264e79ba2a3a566fec',1,'PLWindow::dxmi()']]],
-  ['dy',['dy',['../structplplot__types_1_1plgraphicsin.html#a12f70f731321a02c45ae6e30fa1eacda',1,'plplot_types::plgraphicsin::dy()'],['../structIMG__DT.html#a18206f1e64d54e345fcde39d067e6ad7',1,'IMG_DT::dy()'],['../structplplot_1_1__N2.html#ae6c62648845e3d0ba49ea02faabc4127',1,'plplot::_N2::dY()'],['../structPLGraphicsIn.html#a90a08dfcb5e486ac4ce34507a6004c11',1,'PLGraphicsIn::dY()'],['../namespacePlframe.html#a392c52a1b0b0b952bb2a7fada883e13a',1,'Plframe.dy()']]],
+  ['dy',['dy',['../structplplot__graphics_1_1plgraphicsin.html#ad029a91a4f2d101ea0c7d428762eae5e',1,'plplot_graphics::plgraphicsin::dy()'],['../structIMG__DT.html#a18206f1e64d54e345fcde39d067e6ad7',1,'IMG_DT::dy()'],['../structplplot_1_1__N2.html#ae6c62648845e3d0ba49ea02faabc4127',1,'plplot::_N2::dY()'],['../structPLGraphicsIn.html#a90a08dfcb5e486ac4ce34507a6004c11',1,'PLGraphicsIn::dY()'],['../namespacePlframe.html#a392c52a1b0b0b952bb2a7fada883e13a',1,'Plframe.dy()']]],
   ['dyma',['dyma',['../structplplot_1_1__N3.html#a8c0d51fd26029f65910eb9473627381c',1,'plplot::_N3::dyma()'],['../structPLWindow.html#a4d0b980695e01367e50079521e61fc24',1,'PLWindow::dyma()']]],
   ['dymi',['dymi',['../structplplot_1_1__N3.html#af0e5799d84888b318e2995e04ea8d1a8',1,'plplot::_N3::dymi()'],['../structPLWindow.html#ac5a88aaabbd32564239f8a3f62f8892b',1,'PLWindow::dymi()']]]
 ];
