@@ -2,7 +2,7 @@ var searchData=
 [
   ['g',['g',['../structplplot_1_1__N9.html#ac6f4b924e5b670191775937095230225',1,'plplot::_N9::g()'],['../structPLColor.html#ab71f4093766e02ce796389832582517a',1,'PLColor::g()']]],
   ['gbox',['gbox',['../plframe_8c.html#a9595025f37f8241c8998ed9bf0d981fd',1,'gbox(PLFLT *, PLFLT *, PLFLT *, PLFLT *, const char **):&#160;plframe.c'],['../plplotter_8c.html#a67b7f7268575a49cc5cd8eca75d0a44d',1,'gbox(PLFLT *, PLFLT *, PLFLT *, PLFLT *, CONST char **):&#160;plplotter.c']]],
-  ['gc',['gc',['../structTkwDev.html#a8166e22ee1368fcea258b52224ef1878',1,'TkwDev::gc()'],['../structGcwPLdev.html#a4845487cd0dab9a9d812c29b315c3a87',1,'GcwPLdev::gc()'],['../structXwDev.html#a5476a3dc986ba91f5491f7e9f63e3ae1',1,'XwDev::gc()']]],
+  ['gc',['gc',['../structTkwDev.html#a8166e22ee1368fcea258b52224ef1878',1,'TkwDev::gc()'],['../structXwDev.html#a5476a3dc986ba91f5491f7e9f63e3ae1',1,'XwDev::gc()']]],
   ['gchr',['gchr',['../classplstream.html#ae7efc7ade952636c6abe4aa0f7d4546a',1,'plstream::gchr()'],['../classplplot_1_1core_1_1PLStream.html#a4bfb77a59ac610be6b47f87d3329b2b5',1,'plplot.core.PLStream.gchr()']]],
   ['gcmap1_5frange',['gcmap1_range',['../classplstream.html#ad33d6f819a27a64e0f78458bcee80064',1,'plstream::gcmap1_range()'],['../classplplot_1_1core_1_1PLStream.html#a6daafb3432dd20452cc8d3bd3b09f97a',1,'plplot.core.PLStream.gcmap1_range()']]],
   ['gcol0',['gcol0',['../classplstream.html#aba4cd52aa9af674333751cfd4c3e1f0e',1,'plstream::gcol0()'],['../classplplot_1_1core_1_1PLStream.html#a69961b45a39665055719c5cd67a2a565',1,'plplot.core.PLStream.gcol0()']]],
@@ -10,26 +10,6 @@ var searchData=
   ['gcolbg',['gcolbg',['../classplstream.html#a3c25068052fb61248d1628384fd742ec',1,'plstream::gcolbg()'],['../classplplot_1_1core_1_1PLStream.html#a32b1419b108e303d4fbe493984480f5b',1,'plplot.core.PLStream.gcolbg()']]],
   ['gcolbga',['gcolbga',['../classplstream.html#a6f104110f4ec0c354ef1d936b0191cc7',1,'plstream::gcolbga()'],['../classplplot_1_1core_1_1PLStream.html#a6672c42db8403d0606f2ca1de5783987',1,'plplot.core.PLStream.gcolbga()']]],
   ['gcompression',['gcompression',['../classplstream.html#af31ea9050a284ecb3ee79f5a789008bf',1,'plstream::gcompression()'],['../classplplot_1_1core_1_1PLStream.html#adb1c2751d34bb50c58150a639035bf92',1,'plplot.core.PLStream.gcompression()']]],
-  ['gcw_2dlib_2ec',['gcw-lib.c',['../gcw-lib_8c.html',1,'']]],
-  ['gcw_2ec',['gcw.c',['../gcw_8c.html',1,'']]],
-  ['gcw_2eh',['gcw.h',['../gcw_8h.html',1,'']]],
-  ['gcw_5fclear_5fbackground',['gcw_clear_background',['../gcw-lib_8c.html#a607cd8f08ee849a03a8092dfaeaa3a87',1,'gcw_clear_background():&#160;gcw-lib.c'],['../gcw_8h.html#a87ee65a74bc4ba45dfe6b46973fa39d5',1,'gcw_clear_background():&#160;gcw-lib.c']]],
-  ['gcw_5fdebug',['gcw_debug',['../gcw-lib_8c.html#ad39ec66a9636dd9f466184c575861b53',1,'gcw_debug(char *msg):&#160;gcw-lib.c'],['../gcw_8h.html#ad39ec66a9636dd9f466184c575861b53',1,'gcw_debug(char *msg):&#160;gcw-lib.c']]],
-  ['gcw_5ffunctions',['gcw_functions',['../gcwmodule_8c.html#adc37fe5d00f49d5e7b925d2435148df2',1,'gcwmodule.c']]],
-  ['gcw_5finit_5fcanvas',['gcw_init_canvas',['../gcw-lib_8c.html#accef85ea44787dd16d49ad19b27bc942',1,'gcw_init_canvas(GnomeCanvas *canvas):&#160;gcw-lib.c'],['../gcw_8h.html#ad1e57f8ddcff25ce66e04ba8f6be85cb',1,'gcw_init_canvas(GnomeCanvas *canvas):&#160;gcw-lib.c']]],
-  ['gcw_5finstall_5fcanvas',['gcw_install_canvas',['../gcw-lib_8c.html#a280f038371d7aad0f03a2f4cefaa9aaf',1,'gcw_install_canvas(GnomeCanvas *canvas):&#160;gcw-lib.c'],['../gcw_8h.html#a53f1822dea6e5cf164d57474af795aba',1,'gcw_install_canvas(GnomeCanvas *canvas):&#160;gcw-lib.c']]],
-  ['gcw_5foptions',['gcw_options',['../gcw_8c.html#a49f10f7277173818e15335b87b9bbab1',1,'gcw.c']]],
-  ['gcw_5fregister_5fclasses',['gcw_register_classes',['../gcwmodule_8c.html#a4dd7191d2fbd953cfde013eaf2f32454',1,'gcwmodule.c']]],
-  ['gcw_5fset_5fcanvas_5fsize',['gcw_set_canvas_size',['../gcw-lib_8c.html#ab776eb630ffda47a6b98b1ea4f555f4c',1,'gcw_set_canvas_size(GnomeCanvas *canvas, PLINT width, PLINT height):&#160;gcw-lib.c'],['../gcw_8h.html#ab776eb630ffda47a6b98b1ea4f555f4c',1,'gcw_set_canvas_size(GnomeCanvas *canvas, PLINT width, PLINT height):&#160;gcw-lib.c']]],
-  ['gcw_5fset_5fcanvas_5fzoom',['gcw_set_canvas_zoom',['../gcw-lib_8c.html#ab456ff60259ea33a604e54a30ccf9c4c',1,'gcw_set_canvas_zoom(GnomeCanvas *canvas, PLFLT magnification):&#160;gcw-lib.c'],['../gcw_8h.html#ab456ff60259ea33a604e54a30ccf9c4c',1,'gcw_set_canvas_zoom(GnomeCanvas *canvas, PLFLT magnification):&#160;gcw-lib.c']]],
-  ['gcw_5fset_5fdevice_5fsize',['gcw_set_device_size',['../gcw-lib_8c.html#a1c2b0b7f4a59924cd178779fc2cf8df4',1,'gcw_set_device_size(PLINT width, PLINT height):&#160;gcw-lib.c'],['../gcw_8h.html#ae2e7afb3f3fb32dffd05eecb47783b87',1,'gcw_set_device_size(PLINT width, PLINT height):&#160;gcw-lib.c']]],
-  ['gcw_5fset_5fgdk_5fcolor',['gcw_set_gdk_color',['../gcw-lib_8c.html#af2fdeacf915c9320c8ff4f13bcd69164',1,'gcw_set_gdk_color():&#160;gcw-lib.c'],['../gcw_8h.html#a31da38accaa2e63fbbdb66a3dcb7984c',1,'gcw_set_gdk_color():&#160;gcw-lib.c']]],
-  ['gcw_5fuse_5fhrshsym',['gcw_use_hrshsym',['../gcw-lib_8c.html#a3d0872f6a4e56ed10c5601d7c55b03e1',1,'gcw_use_hrshsym(PLINT use_hrshsym):&#160;gcw-lib.c'],['../gcw_8h.html#a3d0872f6a4e56ed10c5601d7c55b03e1',1,'gcw_use_hrshsym(PLINT use_hrshsym):&#160;gcw-lib.c']]],
-  ['gcw_5fuse_5fpersistence',['gcw_use_persistence',['../gcw-lib_8c.html#a6532316b33b32ff7a29e1baab6adf9c0',1,'gcw_use_persistence(PLINT use_persistence):&#160;gcw-lib.c'],['../gcw_8h.html#a6532316b33b32ff7a29e1baab6adf9c0',1,'gcw_use_persistence(PLINT use_persistence):&#160;gcw-lib.c']]],
-  ['gcw_5fuse_5fpixmap',['gcw_use_pixmap',['../gcw-lib_8c.html#ae26424052a208739cbdcdb6cd960cee5',1,'gcw_use_pixmap(PLINT use_pixmap):&#160;gcw-lib.c'],['../gcw_8h.html#ae26424052a208739cbdcdb6cd960cee5',1,'gcw_use_pixmap(PLINT use_pixmap):&#160;gcw-lib.c']]],
-  ['gcw_5fuse_5ftext',['gcw_use_text',['../gcw-lib_8c.html#a9f0950531fc3b618a889523dc43a42f5',1,'gcw_use_text(PLINT use_text):&#160;gcw-lib.c'],['../gcw_8h.html#a9f0950531fc3b618a889523dc43a42f5',1,'gcw_use_text(PLINT use_text):&#160;gcw-lib.c']]],
-  ['gcwmodule_2ec',['gcwmodule.c',['../gcwmodule_8c.html',1,'']]],
-  ['gcwpldev',['GcwPLdev',['../structGcwPLdev.html',1,'']]],
   ['gcxor',['gcXor',['../structTkwDisplay.html#a31baa71129de5785caaa7f5dbd2fc2bb',1,'TkwDisplay::gcXor()'],['../structXwDisplay.html#ad215e4872240e5a3464a7591aa608ac1',1,'XwDisplay::gcXor()']]],
   ['gd_2ec',['gd.c',['../gd_8c.html',1,'']]],
   ['gdev',['gdev',['../classplstream.html#a85190181cec5e69ef8c45a50d6b0cbf0',1,'plstream::gdev()'],['../classplplot_1_1core_1_1PLStream.html#afe3f94325662c413d7f21bf2d8f7f867',1,'plplot.core.PLStream.gdev()']]],
@@ -50,7 +30,6 @@ var searchData=
   ['gesc',['gesc',['../classplstream.html#a4cdd16f2533213fef5cd5d18358af469',1,'plstream']]],
   ['get',['get',['../structtclMatrix.html#a33d2abf4f0d6e86fcfdf32a333265b12',1,'tclMatrix::get()'],['../structplf2ops__t.html#a5e06163958c53e58712d8a76d6918b40',1,'plf2ops_t::get()'],['../structswig__lua__var__info.html#a56fb0b689f37015e340b35c6d7ee0b99',1,'swig_lua_var_info::get()']]],
   ['get_5fattr',['get_attr',['../structswig__globalvar.html#a051e346d0cd7608bf99e96726022e88c',1,'swig_globalvar']]],
-  ['get_5fbounds',['get_bounds',['../plplotcanvas-hacktext_8c.html#a34e0e357c3f575aec6c6ce8339275721',1,'plplotcanvas-hacktext.c']]],
   ['get_5fcharacter_5for_5fsymbol_5fheight',['get_character_or_symbol_height',['../pllegend_8c.html#aec07c6350dac714def00998097602825',1,'pllegend.c']]],
   ['get_5fcursor',['get_cursor',['../aqt_8c.html#a283273d4ad67a6e5f6d701232243fde8',1,'aqt.c']]],
   ['get_5fline_5fproperties',['get_line_properties',['../cairo_8c.html#a6fd98a3dd9c44e539ca2bcaf5fe15e8a',1,'cairo.c']]],
@@ -63,22 +42,20 @@ var searchData=
   ['get_5fptr',['get_ptr',['../classoctave__swig__ref.html#a09c386829786d99a3e98a302907a4af2',1,'octave_swig_ref']]],
   ['get_5fstring_5flength',['get_string_length',['../structPLStream.html#a97ec49d30120b332e4f9246019bc9800',1,'PLStream']]],
   ['get_5fsubpage_5fper_5fmm',['get_subpage_per_mm',['../pllegend_8c.html#a0b06baad6dbba8da07252a12887eb264',1,'pllegend.c']]],
-  ['getadvanceflag',['GetAdvanceFlag',['../classwxPLplotApp.html#aaedff24bc8f4e873ed3fd257b66db578',1,'wxPLplotApp']]],
-  ['getbackend',['getBackend',['../classwxPLplotwindow.html#ae9a82cff24e31cb47898d051d1c03186',1,'wxPLplotwindow']]],
+  ['getbuffer',['getBuffer',['../classPLMemoryMap.html#ade883f13245aa2793a4944d2091e531a',1,'PLMemoryMap']]],
   ['getbutton',['getButton',['../classplplot_1_1core_1_1PLGraphicsIn.html#a91ed84a353f20e16d9a3ac3df50d8575',1,'plplot::core::PLGraphicsIn']]],
   ['getcdfepoch',['getCDFepoch',['../qsastime__extra_8c.html#ad5ae2c0c56aea86ccae7450878bc57ff',1,'getCDFepoch(MJDtime *MJD):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#af357f4ded572e4f8648b5b92b17b67b1',1,'getCDFepoch(MJDtime *MJD):&#160;qsastime_extra.c']]],
+  ['getclipregion',['GetClipRegion',['../classwxPLDevice.html#a2de09de3f0472d8305ece1b8cd2f123c',1,'wxPLDevice']]],
   ['getcptr',['getCPtr',['../classplplot_1_1core_1_1PLGraphicsIn.html#a3a240ccda2c9bafe14201261bb525101',1,'plplot::core::PLGraphicsIn']]],
   ['getcursor',['GetCursor',['../classplstream.html#a104328c6040682458a7b86c10d8122b2',1,'plstream::GetCursor()'],['../classplplot_1_1core_1_1PLStream.html#acaded01bf23dca6ea6df399a0def56e8',1,'plplot.core.PLStream.getCursor()']]],
-  ['getcursorcmd',['GetCursorCmd',['../wxwidgets_8cpp.html#a11cd2efb6cd172caab999e2b6a72f1a7',1,'wxwidgets.cpp']]],
   ['getdayofweek',['getDayOfWeek',['../qsastime_8c.html#ac81cf24972f4842215d9c908116699f5',1,'getDayOfWeek(const MJDtime *MJD):&#160;qsastime.c'],['../qsastimeP_8h.html#ab428dd925e265c31755d572c9b79f867',1,'getDayOfWeek(const MJDtime *MJD):&#160;qsastime.c']]],
   ['getdiffdays',['getDiffDays',['../qsastime__extra_8c.html#a3a2386ce303e6e23bc9874357c63b661',1,'getDiffDays(MJDtime *MJD1, MJDtime *MJD2):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#a0d34b04119c9aea514bc2ca4ddcc3c19',1,'getDiffDays(MJDtime *MJD1, MJDtime *MJD2):&#160;qsastime_extra.c']]],
   ['getdiffsecs',['getDiffSecs',['../qsastime__extra_8c.html#a88513dd1ed5052962e2673c7bb1d795b',1,'getDiffSecs(MJDtime *MJD1, MJDtime *MJD2):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#aebe42446e2eccd74de3642bff4d7b598',1,'getDiffSecs(MJDtime *MJD1, MJDtime *MJD2):&#160;qsastime_extra.c']]],
   ['getdx',['getDX',['../classplplot_1_1core_1_1PLGraphicsIn.html#adf50dd99881d17b4593b5547235a074e',1,'plplot::core::PLGraphicsIn']]],
   ['getdy',['getDY',['../classplplot_1_1core_1_1PLGraphicsIn.html#ac1d406c624bf39a4b098be925ab4bef6',1,'plplot::core::PLGraphicsIn']]],
-  ['getexitflag',['GetExitFlag',['../classwxPLplotApp.html#a2f953cfac0e0420711ff47f35b10372c',1,'wxPLplotApp']]],
+  ['getentries',['GetEntries',['../tclAPI_8c.html#ac277fc1a34456aa0621c7692d08163b9',1,'tclAPI.c']]],
   ['getflt',['GetFlt',['../classplstream.html#a54d547e04f4085121c578812f1d08d73',1,'plstream']]],
-  ['getfont',['getFont',['../classQtPLDriver.html#af6aa0701912852005242921dc1442692',1,'QtPLDriver']]],
-  ['getheight',['getHeight',['../classwxGetSizeDialog.html#af802561a516c980efc3c03141568f18b',1,'wxGetSizeDialog']]],
+  ['getfont',['GetFont',['../classFontGrabber.html#a39399bc3dfdc51ce99e7534c40780e1c',1,'FontGrabber::GetFont()'],['../classQtPLDriver.html#af6aa0701912852005242921dc1442692',1,'QtPLDriver::getFont()']]],
   ['getint',['GetInt',['../classplstream.html#a4209524d70561e0054aa26e5b72ec015',1,'plstream']]],
   ['getisostring',['getISOString',['../qsastime__extra_8c.html#a18f69f8819a7d88656b4282b836e5661',1,'getISOString(MJDtime *MJD, int delim, int forceJulian):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#afc7d4c59c22310fd34e4abf593397d41',1,'getISOString(MJDtime *MJD, int delim, int forceJulian):&#160;qsastime_extra.c']]],
   ['getjd',['getJD',['../qsastime__extra_8c.html#a9f4ba0f2368287c745120b6b203404da',1,'getJD(MJDtime *MJD):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#ab7aa2822452eccd54460687c944c0d39',1,'getJD(MJDtime *MJD):&#160;qsastime_extra.c']]],
@@ -92,16 +69,15 @@ var searchData=
   ['getoptarg',['GetOptarg',['../plargs_8c.html#ad208253368ead3e25fbf096283a59af4',1,'plargs.c']]],
   ['getpx',['getPX',['../classplplot_1_1core_1_1PLGraphicsIn.html#a1a3ca1f5c22f1da9e531a9fcbb9cbe26',1,'plplot::core::PLGraphicsIn']]],
   ['getpy',['getPY',['../classplplot_1_1core_1_1PLGraphicsIn.html#a446ebdf3d478d1992a93bc94456cb075',1,'plplot::core::PLGraphicsIn']]],
-  ['getrefreshflag',['GetRefreshFlag',['../classwxPLplotWindow.html#a521bb73d967f12ac374c1b2202081c06',1,'wxPLplotWindow::GetRefreshFlag()'],['../classwxPLplotFrame.html#a240907e852dfba488f2cb33f16e232e8',1,'wxPLplotFrame::GetRefreshFlag()']]],
+  ['getsize',['getSize',['../classPLMemoryMap.html#a63d96bc4208678d6b9f0289140fbce50',1,'PLMemoryMap']]],
   ['getsquares',['getsquares',['../csa_8c.html#af7faa5d6360bdf5ae2fee6a9febd4ea3',1,'csa.c']]],
   ['getstate',['getState',['../classplplot_1_1core_1_1PLGraphicsIn.html#af88944718816bd005a96c9f4b154119c',1,'plplot::core::PLGraphicsIn']]],
-  ['getstream',['GetStream',['../classwxPLplotwindow.html#ab99de1a42d8a395c11c46cd553bb4478',1,'wxPLplotwindow']]],
+  ['getstream',['GetStream',['../classwxPLplotwindow.html#ad9d61ecc3ec9276be73cc89ce7a1b1aa',1,'wxPLplotwindow']]],
   ['getstring',['getString',['../classplplot_1_1core_1_1PLGraphicsIn.html#aa085f2095bbe86e3f7c3786b4d9efc5e',1,'plplot::core::PLGraphicsIn']]],
   ['getsubwindow',['getSubwindow',['../classplplot_1_1core_1_1PLGraphicsIn.html#ac2a5a5cd3e9197aaff4ddb64c54046be',1,'plplot::core::PLGraphicsIn']]],
-  ['gettext',['gettext',['../plplotcanvas-hacktext_8c.html#a83b8be0887dede025766d25e2bb884c6',1,'plplotcanvas-hacktext.c']]],
+  ['gettextoffset',['getTextOffset',['../wxwidgets__dev_8cpp.html#a94a325646f3a09b69897ed5d34b505ee',1,'wxwidgets_dev.cpp']]],
   ['gettextpicture',['getTextPicture',['../classQtPLDriver.html#a6ba3d708c1155e63468b51c010466d12',1,'QtPLDriver']]],
   ['gettype',['getType',['../classplplot_1_1core_1_1PLGraphicsIn.html#a51bee997cac2163a8dacde306ae72d3c',1,'plplot::core::PLGraphicsIn']]],
-  ['getwidth',['getWidth',['../classwxGetSizeDialog.html#a57d35795d8574d2bdb73a3537b42c422',1,'wxGetSizeDialog']]],
   ['getwx',['getWX',['../classplplot_1_1core_1_1PLGraphicsIn.html#aea495076ad3ac6d214fd580c855a194a',1,'plplot::core::PLGraphicsIn']]],
   ['getwy',['getWY',['../classplplot_1_1core_1_1PLGraphicsIn.html#a5c6f0afbdcaa42a6b0c72ce386d0c693',1,'plplot::core::PLGraphicsIn']]],
   ['getyad',['getYAD',['../qsastime_8c.html#a3b5af20594b02a640ef7f8422ad29b12',1,'getYAD(int *year, int *ifleapyear, int *doy, const MJDtime *MJD, int forceJulian):&#160;qsastime.c'],['../qsastimeP_8h.html#a5e4bad0354598a5b258808c41b2d8d59',1,'getYAD(int *year, int *ifleapyear, int *doy, const MJDtime *MJD, int forceJulian):&#160;qsastime.c']]],
@@ -111,9 +87,8 @@ var searchData=
   ['gfiledevs',['gFileDevs',['../classplstream.html#a7b9ec1864a7a454798b2d0e994882669',1,'plstream']]],
   ['gfnam',['gfnam',['../classplstream.html#a420b0cbe7c028e24a8508b839ce4f2d0',1,'plstream::gfnam()'],['../classplplot_1_1core_1_1PLStream.html#a388141d5795711129a987c7d5bcd6550',1,'plplot.core.PLStream.gfnam()']]],
   ['gfont',['gfont',['../classplstream.html#a3d928d926a52599f434642f294961a39',1,'plstream::gfont()'],['../classplplot_1_1core_1_1PLStream.html#a8a9b1dff2032f3f14bb785f424698e18',1,'plplot.core.PLStream.gfont()']]],
-  ['gin',['gin',['../classwxPLDevBase.html#a9771d5071d232737f8deeb925628b924',1,'wxPLDevBase::gin()'],['../structTkDev.html#a5dd032b995b9dbc11f687137e8a789d1',1,'TkDev::gin()'],['../structTkwDev.html#af1b4162860b1d4ba0850ae4ee3a5b583',1,'TkwDev::gin()'],['../structXwDev.html#ad563957b570e07fb4ff157e1082ad7f6',1,'XwDev::gin()']]],
+  ['gin',['gin',['../structTkDev.html#a5dd032b995b9dbc11f687137e8a789d1',1,'TkDev::gin()'],['../structTkwDev.html#af1b4162860b1d4ba0850ae4ee3a5b583',1,'TkwDev::gin()'],['../structXwDev.html#ad563957b570e07fb4ff157e1082ad7f6',1,'XwDev::gin()']]],
   ['glevel',['glevel',['../classplstream.html#ac6f30d556bf27fc3a4f572808cad2535',1,'plstream::glevel()'],['../classplplot_1_1core_1_1PLStream.html#acc6f871a5663e9c87609514875e8c765',1,'plplot.core.PLStream.glevel()']]],
-  ['glyphlist',['glyphlist',['../struct__PlplotCanvasHacktextPriv.html#af8c534b7810b4b744a0e365e7a7b59f1',1,'_PlplotCanvasHacktextPriv']]],
   ['gpage',['gpage',['../classplstream.html#af818bf6334ccc57869c1c5f73a416b23',1,'plstream::gpage()'],['../classplplot_1_1core_1_1PLStream.html#abf5d6bc4e66ebeed37c3dc65add5b497',1,'plplot.core.PLStream.gpage()']]],
   ['gra',['gra',['../classplstream.html#a4551fd19d5f4d061bf82a1444ba5c4f4',1,'plstream::gra()'],['../classplplot_1_1core_1_1PLStream.html#a5f31c5e82b57f08c1ff72b465d0a9855',1,'plplot.core.PLStream.gra()']]],
   ['gradient',['gradient',['../classplstream.html#a5c09f493eec498254acb351baab2ef4a',1,'plstream::gradient()'],['../classplplot_1_1core_1_1PLStream.html#a1532aa155d282337b21c2dddafb3cb68',1,'plplot.core.PLStream.gradient()'],['../cairo_8c.html#a38b79c8a32ba49b454f9d69ecd0b31b2',1,'gradient(PLStream *pls, short *xa, short *ya, PLINT npts):&#160;cairo.c'],['../svg_8c.html#ad222a60fa169028ba99ca1475ece14b6',1,'gradient(PLStream *, short *, short *, PLINT):&#160;svg.c']]],
@@ -121,6 +96,7 @@ var searchData=
   ['gradient_5findex',['gradient_index',['../structSVG.html#a1478ed065a8ac15a5ac5c7f3c03ce991',1,'SVG']]],
   ['graphics_5fanti_5faliasing',['graphics_anti_aliasing',['../structPLCairo.html#aaea63861125bfc78fd2d8e2f00d5fab4',1,'PLCairo::graphics_anti_aliasing()'],['../cairo_8c.html#a34b1934fb70098cfce56e45d2a44ea0e',1,'graphics_anti_aliasing():&#160;cairo.c']]],
   ['graphics_5fmode',['GRAPHICS_MODE',['../plplotP_8h.html#a44b886efaaef4628af9bdc4afc66568e',1,'plplotP.h']]],
+  ['graphicsin',['graphicsIn',['../structMemoryMapHeader.html#ae4905de4351f1c48da7b902a5cca0920',1,'MemoryMapHeader']]],
   ['graphx',['graphx',['../structPLStream.html#ac97c1d9507b3b316c557f166eca17430',1,'PLStream']]],
   ['grdashline',['grdashline',['../plline_8c.html#abfcbb055d30afb94ba28d601d3472d47',1,'plline.c']]],
   ['green',['green',['../structcdImageStruct.html#afdfee0cfe98ddb62dd049d97c6285695',1,'cdImageStruct::green()'],['../plstream_8h.html#af38a775b953a654b78d0f13cf899f38bad0784a3f969fe736e8b271a5a161d106',1,'Green():&#160;plstream.h']]],
@@ -128,24 +104,21 @@ var searchData=
   ['grfill',['grfill',['../plcore_8c.html#a859a0f4ec99bc066171dda65bbd7172c',1,'grfill(short *x, short *y, PLINT npts):&#160;plcore.c'],['../plcore_8h.html#a77d9cf615432469a524b7bc2dd14aeef',1,'grfill(short *, short *, PLINT):&#160;plcore.h']]],
   ['grgradient',['grgradient',['../plcore_8c.html#a7498b6e873f50e540504be66a4e8dde0',1,'grgradient(short *x, short *y, PLINT npts):&#160;plcore.c'],['../plcore_8h.html#a56859b60f4eb1d9be698cfd7e1b02941',1,'grgradient(short *, short *, PLINT):&#160;plcore.h']]],
   ['grid_5fbox',['grid_box',['../plbox_8c.html#a27d1408978a6c2d2c31a236b5f1263d2',1,'plbox.c']]],
-  ['grid_5fcsa',['GRID_CSA',['../classplplot.html#ac7e8d796ea6f9dd2556a6212cdf0dba7',1,'plplot::GRID_CSA()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#ae64ff93e7451043c87595b1f57578dc6',1,'plplot.core.plplotjavacConstants.GRID_CSA()'],['../plplot_8h.html#a5fbcfaa3170cb529bf1635ff609a78fa',1,'GRID_CSA():&#160;plplot.h'],['../plplot__octave_8h.html#a5fbcfaa3170cb529bf1635ff609a78fa',1,'GRID_CSA():&#160;plplot_octave.h'],['../namespaceplplotc.html#a637c93aafb8a043eafe6e45e4c8fe7fe',1,'plplotc.GRID_CSA()']]],
+  ['grid_5fcsa',['GRID_CSA',['../classplplot.html#ac7e8d796ea6f9dd2556a6212cdf0dba7',1,'plplot::GRID_CSA()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#ae64ff93e7451043c87595b1f57578dc6',1,'plplot.core.plplotjavacConstants.GRID_CSA()'],['../plplot_8h.html#a5fbcfaa3170cb529bf1635ff609a78fa',1,'GRID_CSA():&#160;plplot.h'],['../namespaceplplotc.html#a637c93aafb8a043eafe6e45e4c8fe7fe',1,'plplotc.GRID_CSA()']]],
   ['grid_5fcsa_5fget',['GRID_CSA_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#a075a349b95ac00cd02f9e4d3cbd4d76b',1,'plplot::core::plplotjavacJNI']]],
-  ['grid_5fdtli',['GRID_DTLI',['../classplplot.html#a69350e251c909eb5d9dc20469b532bcb',1,'plplot::GRID_DTLI()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a34b6315c9ae7a36da1290ccadd7202f3',1,'plplot.core.plplotjavacConstants.GRID_DTLI()'],['../plplot_8h.html#abeff949898412780654cf7cca55561b2',1,'GRID_DTLI():&#160;plplot.h'],['../plplot__octave_8h.html#abeff949898412780654cf7cca55561b2',1,'GRID_DTLI():&#160;plplot_octave.h'],['../namespaceplplotc.html#a9c46b3ae31f7775cc68888dfe0dd5009',1,'plplotc.GRID_DTLI()']]],
+  ['grid_5fdtli',['GRID_DTLI',['../classplplot.html#a69350e251c909eb5d9dc20469b532bcb',1,'plplot::GRID_DTLI()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a34b6315c9ae7a36da1290ccadd7202f3',1,'plplot.core.plplotjavacConstants.GRID_DTLI()'],['../plplot_8h.html#abeff949898412780654cf7cca55561b2',1,'GRID_DTLI():&#160;plplot.h'],['../namespaceplplotc.html#a9c46b3ae31f7775cc68888dfe0dd5009',1,'plplotc.GRID_DTLI()']]],
   ['grid_5fdtli_5fget',['GRID_DTLI_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#a3646d4566edf7e885a1b697284ba53e8',1,'plplot::core::plplotjavacJNI']]],
-  ['grid_5fnnaidw',['GRID_NNAIDW',['../classplplot.html#a14854e59f92a3552380e29a55d06622f',1,'plplot::GRID_NNAIDW()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#aa1b79f0206722f1c4a13c357ab3d2e35',1,'plplot.core.plplotjavacConstants.GRID_NNAIDW()'],['../plgridd_8c.html#a13e069567116362d04a63e64c36dbfe9',1,'grid_nnaidw(const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts, const PLFLT *xg, int nptsx, const PLFLT *yg, int nptsy, PLF2OPS zops, PLPointer zgp):&#160;plgridd.c'],['../plplot_8h.html#ac863b08f442af857a166e36ad4721058',1,'GRID_NNAIDW():&#160;plplot.h'],['../plplot__octave_8h.html#ac863b08f442af857a166e36ad4721058',1,'GRID_NNAIDW():&#160;plplot_octave.h'],['../namespaceplplotc.html#a41083538b2b79e26bb68ceb7f1bd7220',1,'plplotc.GRID_NNAIDW()']]],
+  ['grid_5fnnaidw',['GRID_NNAIDW',['../classplplot.html#a14854e59f92a3552380e29a55d06622f',1,'plplot::GRID_NNAIDW()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#aa1b79f0206722f1c4a13c357ab3d2e35',1,'plplot.core.plplotjavacConstants.GRID_NNAIDW()'],['../plgridd_8c.html#a13e069567116362d04a63e64c36dbfe9',1,'grid_nnaidw(const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts, const PLFLT *xg, int nptsx, const PLFLT *yg, int nptsy, PLF2OPS zops, PLPointer zgp):&#160;plgridd.c'],['../plplot_8h.html#ac863b08f442af857a166e36ad4721058',1,'GRID_NNAIDW():&#160;plplot.h'],['../namespaceplplotc.html#a41083538b2b79e26bb68ceb7f1bd7220',1,'plplotc.GRID_NNAIDW()']]],
   ['grid_5fnnaidw_5fget',['GRID_NNAIDW_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#aaa257cd0910eb57607a236bdf3590516',1,'plplot::core::plplotjavacJNI']]],
-  ['grid_5fnni',['GRID_NNI',['../classplplot.html#aae7efb1735fa85ed208db2d57f2d0b48',1,'plplot::GRID_NNI()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a971b5a9980787f3b5aa39318ed8f4349',1,'plplot.core.plplotjavacConstants.GRID_NNI()'],['../plplot_8h.html#a52d6e7517c3ffac5a0e8a71bdfbc261c',1,'GRID_NNI():&#160;plplot.h'],['../plplot__octave_8h.html#a52d6e7517c3ffac5a0e8a71bdfbc261c',1,'GRID_NNI():&#160;plplot_octave.h'],['../namespaceplplotc.html#a3017ccbfedf84973d1eb6c1def54bdc1',1,'plplotc.GRID_NNI()']]],
+  ['grid_5fnni',['GRID_NNI',['../classplplot.html#aae7efb1735fa85ed208db2d57f2d0b48',1,'plplot::GRID_NNI()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a971b5a9980787f3b5aa39318ed8f4349',1,'plplot.core.plplotjavacConstants.GRID_NNI()'],['../plplot_8h.html#a52d6e7517c3ffac5a0e8a71bdfbc261c',1,'GRID_NNI():&#160;plplot.h'],['../namespaceplplotc.html#a3017ccbfedf84973d1eb6c1def54bdc1',1,'plplotc.GRID_NNI()']]],
   ['grid_5fnni_5fget',['GRID_NNI_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#ab613a7bca3b3db99d3b356dc0fc3a402',1,'plplot::core::plplotjavacJNI']]],
-  ['grid_5fnnidw',['GRID_NNIDW',['../classplplot.html#a1acbbb4c8a1b2da431aafe9b0383a8d1',1,'plplot::GRID_NNIDW()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#ab98f0ef378fda8360117e1f55df273ec',1,'plplot.core.plplotjavacConstants.GRID_NNIDW()'],['../plgridd_8c.html#a9e2bef2061ceb6932e6a9638385683f0',1,'grid_nnidw(const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts, const PLFLT *xg, int nptsx, const PLFLT *yg, int nptsy, PLF2OPS zops, PLPointer zgp, int knn_order):&#160;plgridd.c'],['../plplot_8h.html#aea4b4b399c7eff90105f16be688f869d',1,'GRID_NNIDW():&#160;plplot.h'],['../plplot__octave_8h.html#aea4b4b399c7eff90105f16be688f869d',1,'GRID_NNIDW():&#160;plplot_octave.h'],['../namespaceplplotc.html#a9dadd7e9c8534b465792964bd952766c',1,'plplotc.GRID_NNIDW()']]],
+  ['grid_5fnnidw',['GRID_NNIDW',['../classplplot.html#a1acbbb4c8a1b2da431aafe9b0383a8d1',1,'plplot::GRID_NNIDW()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#ab98f0ef378fda8360117e1f55df273ec',1,'plplot.core.plplotjavacConstants.GRID_NNIDW()'],['../plgridd_8c.html#a9e2bef2061ceb6932e6a9638385683f0',1,'grid_nnidw(const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts, const PLFLT *xg, int nptsx, const PLFLT *yg, int nptsy, PLF2OPS zops, PLPointer zgp, int knn_order):&#160;plgridd.c'],['../plplot_8h.html#aea4b4b399c7eff90105f16be688f869d',1,'GRID_NNIDW():&#160;plplot.h'],['../namespaceplplotc.html#a9dadd7e9c8534b465792964bd952766c',1,'plplotc.GRID_NNIDW()']]],
   ['grid_5fnnidw_5fget',['GRID_NNIDW_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#a910e5c1df356ac42be6a9c455a20aab5',1,'plplot::core::plplotjavacJNI']]],
-  ['grid_5fnnli',['GRID_NNLI',['../classplplot.html#ae46f869cff5269e5ddac49fbf11f8ff5',1,'plplot::GRID_NNLI()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a3eae2031bbcb11d266efd99b44adcce1',1,'plplot.core.plplotjavacConstants.GRID_NNLI()'],['../plgridd_8c.html#aa45506c7342fdd71af2f5ee4fe614582',1,'grid_nnli(const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts, const PLFLT *xg, int nptsx, const PLFLT *yg, int nptsy, PLF2OPS zops, PLPointer zgp, PLFLT threshold):&#160;plgridd.c'],['../plplot_8h.html#adb70a2b8a3cc84206d433e80e79162f2',1,'GRID_NNLI():&#160;plplot.h'],['../plplot__octave_8h.html#adb70a2b8a3cc84206d433e80e79162f2',1,'GRID_NNLI():&#160;plplot_octave.h'],['../namespaceplplotc.html#aed82e9f2bf7583a3528d1eeb494423af',1,'plplotc.GRID_NNLI()']]],
+  ['grid_5fnnli',['GRID_NNLI',['../classplplot.html#ae46f869cff5269e5ddac49fbf11f8ff5',1,'plplot::GRID_NNLI()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a3eae2031bbcb11d266efd99b44adcce1',1,'plplot.core.plplotjavacConstants.GRID_NNLI()'],['../plgridd_8c.html#aa45506c7342fdd71af2f5ee4fe614582',1,'grid_nnli(const PLFLT *x, const PLFLT *y, const PLFLT *z, int npts, const PLFLT *xg, int nptsx, const PLFLT *yg, int nptsy, PLF2OPS zops, PLPointer zgp, PLFLT threshold):&#160;plgridd.c'],['../plplot_8h.html#adb70a2b8a3cc84206d433e80e79162f2',1,'GRID_NNLI():&#160;plplot.h'],['../namespaceplplotc.html#aed82e9f2bf7583a3528d1eeb494423af',1,'plplotc.GRID_NNLI()']]],
   ['grid_5fnnli_5fget',['GRID_NNLI_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#a7b043f71b7c0a8d5514304062d393f5e',1,'plplot::core::plplotjavacJNI']]],
   ['griddata',['griddata',['../classplstream.html#a2463e096bfd2fe60b6dd319ef864ffe3',1,'plstream::griddata()'],['../classplplot_1_1core_1_1PLStream.html#a2137f728a9645fd8bf5788c3622db47a',1,'plplot.core.PLStream.griddata()']]],
   ['grimage',['grimage',['../plimage_8c.html#a3bb953b941f306756707370648093b64',1,'grimage(short *x, short *y, unsigned short *z, PLINT nx, PLINT ny):&#160;plimage.c'],['../plplotP_8h.html#a3bb953b941f306756707370648093b64',1,'grimage(short *x, short *y, unsigned short *z, PLINT nx, PLINT ny):&#160;plimage.c']]],
   ['grline',['grline',['../plcore_8c.html#a05047fa1f14551c0664c4d5192eb4b1a',1,'grline(short *x, short *y, PLINT PL_UNUSED(npts)):&#160;plcore.c'],['../plcore_8h.html#a04aa64064f4f9a6a73a3f357c802f88f',1,'grline(short *, short *, PLINT):&#160;plcore.h']]],
-  ['group_5fhidden',['group_hidden',['../structGcwPLdev.html#aa1f8274a8e0dbcc26639afb4df64291c',1,'GcwPLdev']]],
-  ['group_5fpersistent',['group_persistent',['../structGcwPLdev.html#a15333e47086100fa09de829eae5e56f1',1,'GcwPLdev']]],
-  ['group_5fvisible',['group_visible',['../structGcwPLdev.html#a306dbd9ad448821312f3b25e6c85aa02',1,'GcwPLdev']]],
   ['grpolyline',['grpolyline',['../plcore_8c.html#a1dd1a3d65c1c7e9912c5da15e82f1ba6',1,'grpolyline(short *x, short *y, PLINT npts):&#160;plcore.c'],['../plcore_8h.html#ae519b27a5fc4ac160aef3b40276c689f',1,'grpolyline(short *, short *, PLINT):&#160;plcore.h']]],
   ['gspa',['gspa',['../classplstream.html#a39425564833b970cfb7987060afd94b8',1,'plstream::gspa()'],['../classplplot_1_1core_1_1PLStream.html#a733962fd2e1a45ab3a6f0e342468c888',1,'plplot.core.PLStream.gspa()']]],
   ['gver',['gver',['../classplstream.html#ade99a4b58c7604335b8baeda1b523c8e',1,'plstream::gver()'],['../classplplot_1_1core_1_1PLStream.html#a09191fb8b9647fde7eab73a7fb9094ee',1,'plplot.core.PLStream.gver()']]],
