@@ -4,10 +4,9 @@ var searchData=
   ['k_5fdef',['K_DEF',['../csa_8c.html#a68a71d9d184fe8d5cac56694c2c85db5',1,'csa.c']]],
   ['key',['key',['../structht__bucket.html#a29f598025fca935a60c2720c004bd690',1,'ht_bucket']]],
   ['key_5ffilter',['key_filter',['../namespacePlframe.html#aa3f14208dd6bcce103d5f52387c536f8',1,'Plframe']]],
-  ['key_5frelease',['key_release',['../gcw-lib_8c.html#a9a4893c7d9d58d9e32c882b972475859',1,'gcw-lib.c']]],
   ['keyeh',['KeyEH',['../structPLStream.html#a855b9cd8ab925cccacad4ea057c12f8f',1,'PLStream']]],
   ['keyeh_5fdata',['KeyEH_data',['../structPLStream.html#af33021308e7252fc444851616dda077c',1,'PLStream']]],
-  ['keysym',['keysym',['../structplplot_1_1__N2.html#abccb2986a94be486bb0fb8b2f83506bc',1,'plplot::_N2::keysym()'],['../structplplot__types_1_1plgraphicsin.html#a65b8226749d6f02edd84861014c618c9',1,'plplot_types::plgraphicsin::keysym()'],['../structPLGraphicsIn.html#ad70616982f7224261873697c93e48ee4',1,'PLGraphicsIn::keysym()']]],
+  ['keysym',['keysym',['../structplplot_1_1__N2.html#abccb2986a94be486bb0fb8b2f83506bc',1,'plplot::_N2::keysym()'],['../structplplot__graphics_1_1plgraphicsin.html#abd078589a26b68b5a000f2e7a7ec1cb6',1,'plplot_graphics::plgraphicsin::keysym()'],['../structPLGraphicsIn.html#ad70616982f7224261873697c93e48ee4',1,'PLGraphicsIn::keysym()']]],
   ['klass',['klass',['../structSwigPyClientData.html#a482d64908147c310a56d1541476079dc',1,'SwigPyClientData']]],
   ['knn_5fmax_5forder',['KNN_MAX_ORDER',['../plgridd_8c.html#ae761896c526e93fe9313bc2fd0270118',1,'plgridd.c']]]
 ];
