@@ -1,9 +1,9 @@
 var searchData=
 [
-  ['canvas',['Canvas',['../classplplotcanvas_1_1Canvas.html',1,'plplotcanvas']]],
   ['cdimagestruct',['cdImageStruct',['../structcdImageStruct.html',1,'']]],
   ['cdpointstruct',['cdPointStruct',['../structcdPointStruct.html',1,'']]],
   ['circle',['circle',['../structcircle.html',1,'']]],
+  ['clipper',['Clipper',['../classClipper.html',1,'']]],
   ['cmdinfo',['CmdInfo',['../structCmdInfo.html',1,'']]],
   ['command',['Command',['../structCommand.html',1,'']]],
   ['config',['config',['../classplplot_1_1core_1_1config.html',1,'plplot::core']]],
