@@ -5,6 +5,8 @@ var searchData=
   ['pladv',['pladv',['../interfaceplplot_1_1pladv.html',1,'plplot']]],
   ['plbin',['plbin',['../interfaceplplot_1_1plbin.html',1,'plplot']]],
   ['plbop',['plbop',['../interfaceplplot_1_1plbop.html',1,'plplot']]],
+  ['plbtime',['plbtime',['../interfaceplplot_1_1plbtime.html',1,'plplot']]],
+  ['plbuffer',['plbuffer',['../structplbuffer.html',1,'']]],
   ['plbufferingcb',['PLBufferingCB',['../structPLBufferingCB.html',1,'']]],
   ['plcairo',['PLCairo',['../structPLCairo.html',1,'']]],
   ['plcalc_5fworld',['plcalc_world',['../interfaceplplot_1_1plcalc__world.html',1,'plplot']]],
@@ -20,13 +22,14 @@ var searchData=
   ['plcol1',['plcol1',['../interfaceplplot_1_1plcol1.html',1,'plplot']]],
   ['plcolor',['PLColor',['../structPLColor.html',1,'']]],
   ['plcolorbar',['plcolorbar',['../interfaceplplot_1_1plcolorbar.html',1,'plplot']]],
+  ['plconfigtime',['plconfigtime',['../interfaceplplot_1_1plconfigtime.html',1,'plplot']]],
   ['plcont',['plcont',['../interfaceplplotp_1_1plcont.html',1,'plplotp']]],
   ['plcontrolpt',['PLControlPt',['../structPLControlPt.html',1,'']]],
   ['plcpstrm',['plcpstrm',['../interfaceplplot_1_1plcpstrm.html',1,'plplot']]],
+  ['plctime',['plctime',['../interfaceplplot_1_1plctime.html',1,'plplot']]],
   ['pldev',['PLDev',['../structPLDev.html',1,'']]],
   ['pldispatchtable',['PLDispatchTable',['../structPLDispatchTable.html',1,'']]],
   ['pldisplay',['PLDisplay',['../structPLDisplay.html',1,'']]],
-  ['plend',['plend',['../interfaceplplot_1_1plend.html',1,'plplot']]],
   ['plend1',['plend1',['../interfaceplplot_1_1plend1.html',1,'plplot']]],
   ['plenv',['plenv',['../interfaceplplot_1_1plenv.html',1,'plplot']]],
   ['pleop',['pleop',['../interfaceplplot_1_1pleop.html',1,'plplot']]],
@@ -61,10 +64,10 @@ var searchData=
   ['plgpage',['plgpage',['../interfaceplplot_1_1plgpage.html',1,'plplot']]],
   ['plgra',['plgra',['../interfaceplplot_1_1plgra.html',1,'plplot']]],
   ['plgradient',['plgradient',['../interfaceplplot_1_1plgradient.html',1,'plplot']]],
+  ['plgraphicsin',['PLGraphicsIn',['../classplplot_1_1core_1_1PLGraphicsIn.html',1,'plplot::core']]],
+  ['plgraphicsin',['plgraphicsin',['../structplplot__graphics_1_1plgraphicsin.html',1,'plplot_graphics']]],
   ['plgraphicsin',['PLGraphicsIn',['../classplplotc_1_1PLGraphicsIn.html',1,'plplotc']]],
   ['plgraphicsin',['PLGraphicsIn',['../structPLGraphicsIn.html',1,'']]],
-  ['plgraphicsin',['plgraphicsin',['../structplplot__types_1_1plgraphicsin.html',1,'plplot_types']]],
-  ['plgraphicsin',['PLGraphicsIn',['../classplplot_1_1core_1_1PLGraphicsIn.html',1,'plplot::core']]],
   ['plgriddata',['plgriddata',['../interfaceplplot_1_1plgriddata.html',1,'plplot']]],
   ['plgspa',['plgspa',['../interfaceplplot_1_1plgspa.html',1,'plplot']]],
   ['plgstrm',['plgstrm',['../interfaceplplot_1_1plgstrm.html',1,'plplot']]],
@@ -87,10 +90,19 @@ var searchData=
   ['plline3',['plline3',['../interfaceplplot_1_1plline3.html',1,'plplot']]],
   ['pllsty',['pllsty',['../interfaceplplot_1_1pllsty.html',1,'plplot']]],
   ['plmap',['plmap',['../interfaceplplot_1_1plmap.html',1,'plplot']]],
+  ['plmapfill',['plmapfill',['../interfaceplplot_1_1plmapfill.html',1,'plplot']]],
+  ['plmapline',['plmapline',['../interfaceplplot_1_1plmapline.html',1,'plplot']]],
+  ['plmapstring',['plmapstring',['../interfaceplplot_1_1plmapstring.html',1,'plplot']]],
+  ['plmaptex',['plmaptex',['../interfaceplplot_1_1plmaptex.html',1,'plplot']]],
+  ['plmdev',['PLmDev',['../structPLmDev.html',1,'']]],
+  ['plmemorymap',['PLMemoryMap',['../classPLMemoryMap.html',1,'']]],
   ['plmeridians',['plmeridians',['../interfaceplplot_1_1plmeridians.html',1,'plplot']]],
   ['plmesh',['plmesh',['../interfaceplplot_1_1plmesh.html',1,'plplot']]],
   ['plmeshc',['plmeshc',['../interfaceplplot_1_1plmeshc.html',1,'plplot']]],
+  ['plmindex',['PLmIndex',['../structPLmIndex.html',1,'']]],
   ['plmkstrm',['plmkstrm',['../interfaceplplot_1_1plmkstrm.html',1,'plplot']]],
+  ['plnamedmutex',['PLNamedMutex',['../classPLNamedMutex.html',1,'']]],
+  ['plnamedmutexlocker',['PLNamedMutexLocker',['../classPLNamedMutexLocker.html',1,'']]],
   ['ploptioninfo',['PLOptionInfo',['../structPLOptionInfo.html',1,'']]],
   ['ploptiontable',['PLOptionTable',['../structPLOptionTable.html',1,'']]],
   ['plot3d',['plot3d',['../interfaceplplot_1_1plot3d.html',1,'plplot']]],
@@ -98,7 +110,7 @@ var searchData=
   ['plpat',['plpat',['../interfaceplplot_1_1plpat.html',1,'plplot']]],
   ['plpath',['plpath',['../interfaceplplot_1_1plpath.html',1,'plplot']]],
   ['plplot',['plplot',['../classplplot.html',1,'']]],
-  ['plplot_5fflt',['plplot_flt',['../classplplot__flt.html',1,'']]],
+  ['plplot_5fgraphics',['plplot_graphics',['../classplplot__graphics.html',1,'']]],
   ['plplot_5fstr',['plplot_str',['../classplplot__str.html',1,'']]],
   ['plplot_5fstrutils',['plplot_strutils',['../classplplot__strutils.html',1,'']]],
   ['plplot_5ftypes',['plplot_types',['../classplplot__types.html',1,'']]],
@@ -158,14 +170,15 @@ var searchData=
   ['plssym',['plssym',['../interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plssym.html',1,'plplot::plsetmapformc::plslabelfunc']]],
   ['plstar',['plstar',['../interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstar.html',1,'plplot::plsetmapformc::plslabelfunc']]],
   ['plstransform',['plstransform',['../interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform.html',1,'plplot::plsetmapformc::plslabelfunc']]],
+  ['plstream',['PLStream',['../structPLStream.html',1,'PLStream'],['../classplstream.html',1,'plstream']]],
   ['plstream',['PLStream',['../classplplot_1_1core_1_1PLStream.html',1,'plplot::core']]],
-  ['plstream',['plstream',['../classplstream.html',1,'plstream'],['../structPLStream.html',1,'PLStream']]],
   ['plstrip',['PLStrip',['../structPLStrip.html',1,'']]],
   ['plstripa',['plstripa',['../interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripa.html',1,'plplot::plsetmapformc::plslabelfunc::plstransform']]],
   ['plstripc',['plstripc',['../interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripc.html',1,'plplot::plsetmapformc::plslabelfunc::plstransform']]],
   ['plstripd',['plstripd',['../interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripd.html',1,'plplot::plsetmapformc::plslabelfunc::plstransform']]],
   ['plstyl',['plstyl',['../interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstyl.html',1,'plplot::plsetmapformc::plslabelfunc::plstransform']]],
   ['plsurf3d',['plsurf3d',['../interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsurf3d.html',1,'plplot::plsetmapformc::plslabelfunc::plstransform']]],
+  ['plsurf3dl',['plsurf3dl',['../interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsurf3dl.html',1,'plplot::plsetmapformc::plslabelfunc::plstransform']]],
   ['plsvect',['plsvect',['../interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvect.html',1,'plplot::plsetmapformc::plslabelfunc::plstransform']]],
   ['plsvpa',['plsvpa',['../interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvpa.html',1,'plplot::plsetmapformc::plslabelfunc::plstransform']]],
   ['plsxax',['plsxax',['../interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsxax.html',1,'plplot::plsetmapformc::plslabelfunc::plstransform']]],
