@@ -3,6 +3,8 @@ var searchData=
   ['tai_5futc',['TAI_UTC',['../structTAI__UTC.html',1,'']]],
   ['tclmatrix',['tclMatrix',['../structtclMatrix.html',1,'']]],
   ['tclmatrixxtnsndescr',['tclMatrixXtnsnDescr',['../structtclMatrixXtnsnDescr.html',1,'']]],
+  ['textobjectschanger',['TextObjectsChanger',['../classTextObjectsChanger.html',1,'']]],
+  ['textsizeinfo',['TextSizeInfo',['../structTextSizeInfo.html',1,'']]],
   ['tkdev',['TkDev',['../structTkDev.html',1,'']]],
   ['tkwdev',['TkwDev',['../structTkwDev.html',1,'']]],
   ['tkwdisplay',['TkwDisplay',['../structTkwDisplay.html',1,'']]],
