@@ -1,7 +1,5 @@
 var searchData=
 [
-  ['_5f',['_',['../plplotcanvas-hacktext_8c.html#a32a3cf3d9dd914f5aeeca5423c157934',1,'plplotcanvas-hacktext.c']]],
-  ['_5f_5fgnome_5fprint_5fi18n_5fh_5f_5f',['__GNOME_PRINT_I18N_H__',['../plplotcanvas-hacktext_8c.html#a3fd09350421edb68b623e9b1bddb5c6c',1,'plplotcanvas-hacktext.c']]],
   ['_5f_5fplsym_5fh_5f_5f',['__PLSYM_H__',['../plsym_8c.html#a7f50a5a39848b5f55a2f7527a807cbe9',1,'plsym.c']]],
   ['_5fpoint_5fstruct',['_POINT_STRUCT',['../csa_8h.html#a4ef1d97b275f78d61bc5a9910f73b1e0',1,'_POINT_STRUCT():&#160;csa.h'],['../nn_8h.html#a4ef1d97b275f78d61bc5a9910f73b1e0',1,'_POINT_STRUCT():&#160;nn.h']]],
   ['_5fs_5firead',['_S_IREAD',['../plstdio_8c.html#afb08a987a2331273d8a5d55b5ec0c7c7',1,'plstdio.c']]],
