@@ -1,12 +1,17 @@
 var searchData=
 [
   ['scale',['SCALE',['../plmap_8c.html#a0cbea62f1ce2043dd08108e65ed8de1d',1,'SCALE():&#160;plmap.c'],['../aqt_8c.html#a0cbea62f1ce2043dd08108e65ed8de1d',1,'SCALE():&#160;aqt.c']]],
+  ['setsub',['SETSUB',['../metadefs_8h.html#a5b0117b6132f309a8d5c393433acd3cc',1,'metadefs.h']]],
+  ['shpt_5farc',['SHPT_ARC',['../plmap_8c.html#a3ca5e794a3b30cba2010f298ba900269',1,'plmap.c']]],
+  ['shpt_5fpoint',['SHPT_POINT',['../plmap_8c.html#abf879a68955d665565122f20549a2a3a',1,'plmap.c']]],
+  ['shpt_5fpolygon',['SHPT_POLYGON',['../plmap_8c.html#a556463e3133ebb0f2f9ba3ec048a5336',1,'plmap.c']]],
   ['sign',['SIGN',['../plplotP_8h.html#a8c4a9e5e4622948245de4ec0b5d38329',1,'plplotP.h']]],
   ['sizeof',['SIZEOF',['../cd_8h.html#ab4e7a10b0e2cf79aa0978d3bbe1e1268',1,'cd.h']]],
   ['snprintf',['snprintf',['../plplotP_8h.html#aa367b75c5aed883fef5befbdf04835a4',1,'plplotP.h']]],
   ['snscanf',['snscanf',['../plplotP_8h.html#a690e5d3e324df4a0bcc627f25545943b',1,'plplotP.h']]],
   ['source_5fdir',['SOURCE_DIR',['../plplot__config_8h.html#a9343e0f8dda9d377d1b08b9f7d072d3f',1,'plplot_config.h']]],
   ['ssqr',['SSQR',['../plplotP_8h.html#a527cd260524e42ed5b6c2ba9d638385a',1,'plplotP.h']]],
+  ['ssub',['SSUB',['../metadefs_8h.html#ace6b57f62d946947c2de4e67f75fc9bf',1,'metadefs.h']]],
   ['stack_5fninc',['STACK_NINC',['../istack_8c.html#af5988b0fe7080430731e197ab470edac',1,'istack.c']]],
   ['stack_5fnstart',['STACK_NSTART',['../istack_8c.html#aece9764da80b282e99080e969d75d1b0',1,'istack.c']]],
   ['stdc_5fheaders',['STDC_HEADERS',['../plplot__config_8h.html#a550e5c272cc3cf3814651721167dcd23',1,'plplot_config.h']]],
@@ -63,7 +68,7 @@ var searchData=
   ['swig_5fdeltmpmask',['SWIG_DelTmpMask',['../plplotluacLUA__wrap_8c.html#ac08b44ea4ae9f73b19d915969f301a5d',1,'SWIG_DelTmpMask():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ac08b44ea4ae9f73b19d915969f301a5d',1,'SWIG_DelTmpMask():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#ac08b44ea4ae9f73b19d915969f301a5d',1,'SWIG_DelTmpMask():&#160;plplotcmodulePYTHON_wrap.c']]],
   ['swig_5fdivisionbyzero',['SWIG_DivisionByZero',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae4cc0f5599402526dd5c2fdb80d87517',1,'SWIG_DivisionByZero():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#ae4cc0f5599402526dd5c2fdb80d87517',1,'SWIG_DivisionByZero():&#160;plplotcmodulePYTHON_wrap.c']]],
   ['swig_5fdostring_5ffail',['SWIG_DOSTRING_FAIL',['../plplotluacLUA__wrap_8c.html#a054a85a15c821ad190018e106214a1ac',1,'plplotluacLUA_wrap.c']]],
-  ['swig_5ferror',['SWIG_ERROR',['../plplotluacLUA__wrap_8c.html#acfa11a770d66f9ca6ba170b173c56c94',1,'SWIG_ERROR():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#acfa11a770d66f9ca6ba170b173c56c94',1,'SWIG_ERROR():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#acfa11a770d66f9ca6ba170b173c56c94',1,'SWIG_ERROR():&#160;plplotcmodulePYTHON_wrap.c'],['../plplotcmodulePYTHON__wrap_8c.html#a01b485cfacae7d870729eea43fb17cb0',1,'SWIG_Error():&#160;plplotcmodulePYTHON_wrap.c']]],
+  ['swig_5ferror',['SWIG_Error',['../plplotcmodulePYTHON__wrap_8c.html#a01b485cfacae7d870729eea43fb17cb0',1,'SWIG_Error():&#160;plplotcmodulePYTHON_wrap.c'],['../plplotluacLUA__wrap_8c.html#acfa11a770d66f9ca6ba170b173c56c94',1,'SWIG_ERROR():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#acfa11a770d66f9ca6ba170b173c56c94',1,'SWIG_ERROR():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#acfa11a770d66f9ca6ba170b173c56c94',1,'SWIG_ERROR():&#160;plplotcmodulePYTHON_wrap.c']]],
   ['swig_5ferrortype',['SWIG_ErrorType',['../plplotcmodulePYTHON__wrap_8c.html#a21d4e75f4bb2519f73467e922c7b51d7',1,'plplotcmodulePYTHON_wrap.c']]],
   ['swig_5fexception_5ffail',['SWIG_exception_fail',['../plplot__octaveOCTAVE__wrap_8cxx.html#a567b84b185b0f14620c063787f998109',1,'SWIG_exception_fail():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#a567b84b185b0f14620c063787f998109',1,'SWIG_exception_fail():&#160;plplotcmodulePYTHON_wrap.c']]],
   ['swig_5ffail',['SWIG_fail',['../plplotluacLUA__wrap_8c.html#ababf56889b69e7a569556eb38cd4f157',1,'SWIG_fail():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ababf56889b69e7a569556eb38cd4f157',1,'SWIG_fail():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcmodulePYTHON__wrap_8c.html#ababf56889b69e7a569556eb38cd4f157',1,'SWIG_fail():&#160;plplotcmodulePYTHON_wrap.c']]],
