@@ -12,8 +12,6 @@ var searchData=
   ['cgm_2ec',['cgm.c',['../cgm_8c.html',1,'']]],
   ['color16_2ec',['color16.c',['../color16_8c.html',1,'']]],
   ['config_2ejava',['config.java',['../config_8java.html',1,'']]],
-  ['configurable_2ef90',['configurable.f90',['../configurable_8f90.html',1,'']]],
-  ['cplplotcanvasmodule_2ec',['cplplotcanvasmodule.c',['../cplplotcanvasmodule_8c.html',1,'']]],
   ['csa_2ec',['csa.c',['../csa_8c.html',1,'']]],
   ['csa_2eh',['csa.h',['../csa_8h.html',1,'']]],
   ['csadll_2eh',['csadll.h',['../csadll_8h.html',1,'']]],
