@@ -3,12 +3,10 @@ var searchData=
   ['wingcc_2ec',['wingcc.c',['../wingcc_8c.html',1,'']]],
   ['wxplplotstream_2ecpp',['wxPLplotstream.cpp',['../wxPLplotstream_8cpp.html',1,'']]],
   ['wxplplotstream_2eh',['wxPLplotstream.h',['../wxPLplotstream_8h.html',1,'']]],
-  ['wxplplotwindow_2ecpp',['wxPLplotwindow.cpp',['../wxPLplotwindow_8cpp.html',1,'']]],
   ['wxplplotwindow_2eh',['wxPLplotwindow.h',['../wxPLplotwindow_8h.html',1,'']]],
   ['wxwidgets_2ecpp',['wxwidgets.cpp',['../wxwidgets_8cpp.html',1,'']]],
   ['wxwidgets_2eh',['wxwidgets.h',['../wxwidgets_8h.html',1,'']]],
-  ['wxwidgets_5fagg_2ecpp',['wxwidgets_agg.cpp',['../wxwidgets__agg_8cpp.html',1,'']]],
-  ['wxwidgets_5fapp_2ecpp',['wxwidgets_app.cpp',['../wxwidgets__app_8cpp.html',1,'']]],
-  ['wxwidgets_5fdc_2ecpp',['wxwidgets_dc.cpp',['../wxwidgets__dc_8cpp.html',1,'']]],
-  ['wxwidgets_5fgc_2ecpp',['wxwidgets_gc.cpp',['../wxwidgets__gc_8cpp.html',1,'']]]
+  ['wxwidgets_5fcomms_2ecpp',['wxwidgets_comms.cpp',['../wxwidgets__comms_8cpp.html',1,'']]],
+  ['wxwidgets_5fcomms_2eh',['wxwidgets_comms.h',['../wxwidgets__comms_8h.html',1,'']]],
+  ['wxwidgets_5fdev_2ecpp',['wxwidgets_dev.cpp',['../wxwidgets__dev_8cpp.html',1,'']]]
 ];
