@@ -8,19 +8,6 @@ var searchData=
   ['gcolbg',['gcolbg',['../classplstream.html#a3c25068052fb61248d1628384fd742ec',1,'plstream::gcolbg()'],['../classplplot_1_1core_1_1PLStream.html#a32b1419b108e303d4fbe493984480f5b',1,'plplot.core.PLStream.gcolbg()']]],
   ['gcolbga',['gcolbga',['../classplstream.html#a6f104110f4ec0c354ef1d936b0191cc7',1,'plstream::gcolbga()'],['../classplplot_1_1core_1_1PLStream.html#a6672c42db8403d0606f2ca1de5783987',1,'plplot.core.PLStream.gcolbga()']]],
   ['gcompression',['gcompression',['../classplstream.html#af31ea9050a284ecb3ee79f5a789008bf',1,'plstream::gcompression()'],['../classplplot_1_1core_1_1PLStream.html#adb1c2751d34bb50c58150a639035bf92',1,'plplot.core.PLStream.gcompression()']]],
-  ['gcw_5fclear_5fbackground',['gcw_clear_background',['../gcw-lib_8c.html#a607cd8f08ee849a03a8092dfaeaa3a87',1,'gcw_clear_background():&#160;gcw-lib.c'],['../gcw_8h.html#a87ee65a74bc4ba45dfe6b46973fa39d5',1,'gcw_clear_background():&#160;gcw-lib.c']]],
-  ['gcw_5fdebug',['gcw_debug',['../gcw-lib_8c.html#ad39ec66a9636dd9f466184c575861b53',1,'gcw_debug(char *msg):&#160;gcw-lib.c'],['../gcw_8h.html#ad39ec66a9636dd9f466184c575861b53',1,'gcw_debug(char *msg):&#160;gcw-lib.c']]],
-  ['gcw_5finit_5fcanvas',['gcw_init_canvas',['../gcw-lib_8c.html#accef85ea44787dd16d49ad19b27bc942',1,'gcw_init_canvas(GnomeCanvas *canvas):&#160;gcw-lib.c'],['../gcw_8h.html#ad1e57f8ddcff25ce66e04ba8f6be85cb',1,'gcw_init_canvas(GnomeCanvas *canvas):&#160;gcw-lib.c']]],
-  ['gcw_5finstall_5fcanvas',['gcw_install_canvas',['../gcw-lib_8c.html#a280f038371d7aad0f03a2f4cefaa9aaf',1,'gcw_install_canvas(GnomeCanvas *canvas):&#160;gcw-lib.c'],['../gcw_8h.html#a53f1822dea6e5cf164d57474af795aba',1,'gcw_install_canvas(GnomeCanvas *canvas):&#160;gcw-lib.c']]],
-  ['gcw_5fregister_5fclasses',['gcw_register_classes',['../gcwmodule_8c.html#a4dd7191d2fbd953cfde013eaf2f32454',1,'gcwmodule.c']]],
-  ['gcw_5fset_5fcanvas_5fsize',['gcw_set_canvas_size',['../gcw-lib_8c.html#ab776eb630ffda47a6b98b1ea4f555f4c',1,'gcw_set_canvas_size(GnomeCanvas *canvas, PLINT width, PLINT height):&#160;gcw-lib.c'],['../gcw_8h.html#ab776eb630ffda47a6b98b1ea4f555f4c',1,'gcw_set_canvas_size(GnomeCanvas *canvas, PLINT width, PLINT height):&#160;gcw-lib.c']]],
-  ['gcw_5fset_5fcanvas_5fzoom',['gcw_set_canvas_zoom',['../gcw-lib_8c.html#ab456ff60259ea33a604e54a30ccf9c4c',1,'gcw_set_canvas_zoom(GnomeCanvas *canvas, PLFLT magnification):&#160;gcw-lib.c'],['../gcw_8h.html#ab456ff60259ea33a604e54a30ccf9c4c',1,'gcw_set_canvas_zoom(GnomeCanvas *canvas, PLFLT magnification):&#160;gcw-lib.c']]],
-  ['gcw_5fset_5fdevice_5fsize',['gcw_set_device_size',['../gcw-lib_8c.html#a1c2b0b7f4a59924cd178779fc2cf8df4',1,'gcw_set_device_size(PLINT width, PLINT height):&#160;gcw-lib.c'],['../gcw_8h.html#ae2e7afb3f3fb32dffd05eecb47783b87',1,'gcw_set_device_size(PLINT width, PLINT height):&#160;gcw-lib.c']]],
-  ['gcw_5fset_5fgdk_5fcolor',['gcw_set_gdk_color',['../gcw-lib_8c.html#af2fdeacf915c9320c8ff4f13bcd69164',1,'gcw_set_gdk_color():&#160;gcw-lib.c'],['../gcw_8h.html#a31da38accaa2e63fbbdb66a3dcb7984c',1,'gcw_set_gdk_color():&#160;gcw-lib.c']]],
-  ['gcw_5fuse_5fhrshsym',['gcw_use_hrshsym',['../gcw-lib_8c.html#a3d0872f6a4e56ed10c5601d7c55b03e1',1,'gcw_use_hrshsym(PLINT use_hrshsym):&#160;gcw-lib.c'],['../gcw_8h.html#a3d0872f6a4e56ed10c5601d7c55b03e1',1,'gcw_use_hrshsym(PLINT use_hrshsym):&#160;gcw-lib.c']]],
-  ['gcw_5fuse_5fpersistence',['gcw_use_persistence',['../gcw-lib_8c.html#a6532316b33b32ff7a29e1baab6adf9c0',1,'gcw_use_persistence(PLINT use_persistence):&#160;gcw-lib.c'],['../gcw_8h.html#a6532316b33b32ff7a29e1baab6adf9c0',1,'gcw_use_persistence(PLINT use_persistence):&#160;gcw-lib.c']]],
-  ['gcw_5fuse_5fpixmap',['gcw_use_pixmap',['../gcw-lib_8c.html#ae26424052a208739cbdcdb6cd960cee5',1,'gcw_use_pixmap(PLINT use_pixmap):&#160;gcw-lib.c'],['../gcw_8h.html#ae26424052a208739cbdcdb6cd960cee5',1,'gcw_use_pixmap(PLINT use_pixmap):&#160;gcw-lib.c']]],
-  ['gcw_5fuse_5ftext',['gcw_use_text',['../gcw-lib_8c.html#a9f0950531fc3b618a889523dc43a42f5',1,'gcw_use_text(PLINT use_text):&#160;gcw-lib.c'],['../gcw_8h.html#a9f0950531fc3b618a889523dc43a42f5',1,'gcw_use_text(PLINT use_text):&#160;gcw-lib.c']]],
   ['gdev',['gdev',['../classplstream.html#a85190181cec5e69ef8c45a50d6b0cbf0',1,'plstream::gdev()'],['../classplplot_1_1core_1_1PLStream.html#afe3f94325662c413d7f21bf2d8f7f867',1,'plplot.core.PLStream.gdev()']]],
   ['gdidev',['gdidev',['../classplstream.html#a97bd87e7d140e103e6788c5469e7c429',1,'plstream::gdidev()'],['../classplplot_1_1core_1_1PLStream.html#a337cf65763658b068e0e770d8eb71349',1,'plplot.core.PLStream.gdidev()']]],
   ['gdiori',['gdiori',['../classplstream.html#a33846a59b77a7ec421632667fb4a6077',1,'plstream::gdiori()'],['../classplplot_1_1core_1_1PLStream.html#a058adda37ef5a6abc5718ac325f188a4',1,'plplot.core.PLStream.gdiori()']]],
@@ -36,7 +23,6 @@ var searchData=
   ['genrand_5freal3',['genrand_real3',['../mt19937ar_8c.html#ab1a90aa68ebfcd712cb05ed9061ecf44',1,'genrand_real3(void):&#160;mt19937ar.c'],['../mt19937ar_8h.html#ab1a90aa68ebfcd712cb05ed9061ecf44',1,'genrand_real3(void):&#160;mt19937ar.c']]],
   ['genrand_5fres53',['genrand_res53',['../mt19937ar_8c.html#ac821d41970276e53e85bde08b24536b8',1,'genrand_res53(void):&#160;mt19937ar.c'],['../mt19937ar_8h.html#ac821d41970276e53e85bde08b24536b8',1,'genrand_res53(void):&#160;mt19937ar.c']]],
   ['gesc',['gesc',['../classplstream.html#a4cdd16f2533213fef5cd5d18358af469',1,'plstream']]],
-  ['get_5fbounds',['get_bounds',['../plplotcanvas-hacktext_8c.html#a34e0e357c3f575aec6c6ce8339275721',1,'plplotcanvas-hacktext.c']]],
   ['get_5fcharacter_5for_5fsymbol_5fheight',['get_character_or_symbol_height',['../pllegend_8c.html#aec07c6350dac714def00998097602825',1,'pllegend.c']]],
   ['get_5fcursor',['get_cursor',['../aqt_8c.html#a283273d4ad67a6e5f6d701232243fde8',1,'aqt.c']]],
   ['get_5fline_5fproperties',['get_line_properties',['../cairo_8c.html#a6fd98a3dd9c44e539ca2bcaf5fe15e8a',1,'cairo.c']]],
@@ -47,22 +33,20 @@ var searchData=
   ['get_5fncoords',['get_ncoords',['../plr_8c.html#ae58b9982d2450cb06989402afaaefac9',1,'plr.c']]],
   ['get_5fptr',['get_ptr',['../classoctave__swig__ref.html#a09c386829786d99a3e98a302907a4af2',1,'octave_swig_ref']]],
   ['get_5fsubpage_5fper_5fmm',['get_subpage_per_mm',['../pllegend_8c.html#a0b06baad6dbba8da07252a12887eb264',1,'pllegend.c']]],
-  ['getadvanceflag',['GetAdvanceFlag',['../classwxPLplotApp.html#aaedff24bc8f4e873ed3fd257b66db578',1,'wxPLplotApp']]],
-  ['getbackend',['getBackend',['../classwxPLplotwindow.html#ae9a82cff24e31cb47898d051d1c03186',1,'wxPLplotwindow']]],
+  ['getbuffer',['getBuffer',['../classPLMemoryMap.html#ade883f13245aa2793a4944d2091e531a',1,'PLMemoryMap']]],
   ['getbutton',['getButton',['../classplplot_1_1core_1_1PLGraphicsIn.html#a91ed84a353f20e16d9a3ac3df50d8575',1,'plplot::core::PLGraphicsIn']]],
   ['getcdfepoch',['getCDFepoch',['../qsastime__extra_8c.html#ad5ae2c0c56aea86ccae7450878bc57ff',1,'getCDFepoch(MJDtime *MJD):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#af357f4ded572e4f8648b5b92b17b67b1',1,'getCDFepoch(MJDtime *MJD):&#160;qsastime_extra.c']]],
+  ['getclipregion',['GetClipRegion',['../classwxPLDevice.html#a2de09de3f0472d8305ece1b8cd2f123c',1,'wxPLDevice']]],
   ['getcptr',['getCPtr',['../classplplot_1_1core_1_1PLGraphicsIn.html#a3a240ccda2c9bafe14201261bb525101',1,'plplot::core::PLGraphicsIn']]],
   ['getcursor',['GetCursor',['../classplstream.html#a104328c6040682458a7b86c10d8122b2',1,'plstream::GetCursor()'],['../classplplot_1_1core_1_1PLStream.html#acaded01bf23dca6ea6df399a0def56e8',1,'plplot.core.PLStream.getCursor()']]],
-  ['getcursorcmd',['GetCursorCmd',['../wxwidgets_8cpp.html#a11cd2efb6cd172caab999e2b6a72f1a7',1,'wxwidgets.cpp']]],
   ['getdayofweek',['getDayOfWeek',['../qsastime_8c.html#ac81cf24972f4842215d9c908116699f5',1,'getDayOfWeek(const MJDtime *MJD):&#160;qsastime.c'],['../qsastimeP_8h.html#ab428dd925e265c31755d572c9b79f867',1,'getDayOfWeek(const MJDtime *MJD):&#160;qsastime.c']]],
   ['getdiffdays',['getDiffDays',['../qsastime__extra_8c.html#a3a2386ce303e6e23bc9874357c63b661',1,'getDiffDays(MJDtime *MJD1, MJDtime *MJD2):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#a0d34b04119c9aea514bc2ca4ddcc3c19',1,'getDiffDays(MJDtime *MJD1, MJDtime *MJD2):&#160;qsastime_extra.c']]],
   ['getdiffsecs',['getDiffSecs',['../qsastime__extra_8c.html#a88513dd1ed5052962e2673c7bb1d795b',1,'getDiffSecs(MJDtime *MJD1, MJDtime *MJD2):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#aebe42446e2eccd74de3642bff4d7b598',1,'getDiffSecs(MJDtime *MJD1, MJDtime *MJD2):&#160;qsastime_extra.c']]],
   ['getdx',['getDX',['../classplplot_1_1core_1_1PLGraphicsIn.html#adf50dd99881d17b4593b5547235a074e',1,'plplot::core::PLGraphicsIn']]],
   ['getdy',['getDY',['../classplplot_1_1core_1_1PLGraphicsIn.html#ac1d406c624bf39a4b098be925ab4bef6',1,'plplot::core::PLGraphicsIn']]],
-  ['getexitflag',['GetExitFlag',['../classwxPLplotApp.html#a2f953cfac0e0420711ff47f35b10372c',1,'wxPLplotApp']]],
+  ['getentries',['GetEntries',['../tclAPI_8c.html#ac277fc1a34456aa0621c7692d08163b9',1,'tclAPI.c']]],
   ['getflt',['GetFlt',['../classplstream.html#a54d547e04f4085121c578812f1d08d73',1,'plstream']]],
-  ['getfont',['getFont',['../classQtPLDriver.html#af6aa0701912852005242921dc1442692',1,'QtPLDriver']]],
-  ['getheight',['getHeight',['../classwxGetSizeDialog.html#af802561a516c980efc3c03141568f18b',1,'wxGetSizeDialog']]],
+  ['getfont',['GetFont',['../classFontGrabber.html#a39399bc3dfdc51ce99e7534c40780e1c',1,'FontGrabber::GetFont()'],['../classQtPLDriver.html#af6aa0701912852005242921dc1442692',1,'QtPLDriver::getFont()']]],
   ['getint',['GetInt',['../classplstream.html#a4209524d70561e0054aa26e5b72ec015',1,'plstream']]],
   ['getisostring',['getISOString',['../qsastime__extra_8c.html#a18f69f8819a7d88656b4282b836e5661',1,'getISOString(MJDtime *MJD, int delim, int forceJulian):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#afc7d4c59c22310fd34e4abf593397d41',1,'getISOString(MJDtime *MJD, int delim, int forceJulian):&#160;qsastime_extra.c']]],
   ['getjd',['getJD',['../qsastime__extra_8c.html#a9f4ba0f2368287c745120b6b203404da',1,'getJD(MJDtime *MJD):&#160;qsastime_extra.c'],['../qsastime__extra_8h.html#ab7aa2822452eccd54460687c944c0d39',1,'getJD(MJDtime *MJD):&#160;qsastime_extra.c']]],
@@ -75,15 +59,15 @@ var searchData=
   ['getoptarg',['GetOptarg',['../plargs_8c.html#ad208253368ead3e25fbf096283a59af4',1,'plargs.c']]],
   ['getpx',['getPX',['../classplplot_1_1core_1_1PLGraphicsIn.html#a1a3ca1f5c22f1da9e531a9fcbb9cbe26',1,'plplot::core::PLGraphicsIn']]],
   ['getpy',['getPY',['../classplplot_1_1core_1_1PLGraphicsIn.html#a446ebdf3d478d1992a93bc94456cb075',1,'plplot::core::PLGraphicsIn']]],
-  ['getrefreshflag',['GetRefreshFlag',['../classwxPLplotWindow.html#a521bb73d967f12ac374c1b2202081c06',1,'wxPLplotWindow::GetRefreshFlag()'],['../classwxPLplotFrame.html#a240907e852dfba488f2cb33f16e232e8',1,'wxPLplotFrame::GetRefreshFlag()']]],
+  ['getsize',['getSize',['../classPLMemoryMap.html#a63d96bc4208678d6b9f0289140fbce50',1,'PLMemoryMap']]],
   ['getsquares',['getsquares',['../csa_8c.html#af7faa5d6360bdf5ae2fee6a9febd4ea3',1,'csa.c']]],
   ['getstate',['getState',['../classplplot_1_1core_1_1PLGraphicsIn.html#af88944718816bd005a96c9f4b154119c',1,'plplot::core::PLGraphicsIn']]],
-  ['getstream',['GetStream',['../classwxPLplotwindow.html#ab99de1a42d8a395c11c46cd553bb4478',1,'wxPLplotwindow']]],
+  ['getstream',['GetStream',['../classwxPLplotwindow.html#ad9d61ecc3ec9276be73cc89ce7a1b1aa',1,'wxPLplotwindow']]],
   ['getstring',['getString',['../classplplot_1_1core_1_1PLGraphicsIn.html#aa085f2095bbe86e3f7c3786b4d9efc5e',1,'plplot::core::PLGraphicsIn']]],
   ['getsubwindow',['getSubwindow',['../classplplot_1_1core_1_1PLGraphicsIn.html#ac2a5a5cd3e9197aaff4ddb64c54046be',1,'plplot::core::PLGraphicsIn']]],
+  ['gettextoffset',['getTextOffset',['../wxwidgets__dev_8cpp.html#a94a325646f3a09b69897ed5d34b505ee',1,'wxwidgets_dev.cpp']]],
   ['gettextpicture',['getTextPicture',['../classQtPLDriver.html#a6ba3d708c1155e63468b51c010466d12',1,'QtPLDriver']]],
   ['gettype',['getType',['../classplplot_1_1core_1_1PLGraphicsIn.html#a51bee997cac2163a8dacde306ae72d3c',1,'plplot::core::PLGraphicsIn']]],
-  ['getwidth',['getWidth',['../classwxGetSizeDialog.html#a57d35795d8574d2bdb73a3537b42c422',1,'wxGetSizeDialog']]],
   ['getwx',['getWX',['../classplplot_1_1core_1_1PLGraphicsIn.html#aea495076ad3ac6d214fd580c855a194a',1,'plplot::core::PLGraphicsIn']]],
   ['getwy',['getWY',['../classplplot_1_1core_1_1PLGraphicsIn.html#a5c6f0afbdcaa42a6b0c72ce386d0c693',1,'plplot::core::PLGraphicsIn']]],
   ['getyad',['getYAD',['../qsastime_8c.html#a3b5af20594b02a640ef7f8422ad29b12',1,'getYAD(int *year, int *ifleapyear, int *doy, const MJDtime *MJD, int forceJulian):&#160;qsastime.c'],['../qsastimeP_8h.html#a5e4bad0354598a5b258808c41b2d8d59',1,'getYAD(int *year, int *ifleapyear, int *doy, const MJDtime *MJD, int forceJulian):&#160;qsastime.c']]],
