@@ -6,26 +6,20 @@ var searchData=
   ['octave_5fswig_5ftype',['octave_swig_type',['../classoctave__swig__type.html#a0f52916c2d5f9d56f96fe3d7b2c5fb3b',1,'octave_swig_type::octave_swig_type(const octave_swig_type &amp;x)'],['../classoctave__swig__type.html#a66c9d24f4c10cf5f1ba4375467fb4b69',1,'octave_swig_type::octave_swig_type(void *_ptr=0, const swig_type_info *_type=0, int _own=0, bool _always_static=false)']]],
   ['octave_5fvalue_5fref',['octave_value_ref',['../structoctave__value__ref.html#ab8bd77f03124b6ff2dce4d814c69f933',1,'octave_value_ref']]],
   ['on_5fright_5fside',['on_right_side',['../delaunay_8c.html#a0fd0f63831b1479599a0dd82bdfede8e',1,'delaunay.c']]],
-  ['onchar',['OnChar',['../classwxPLplotWindow.html#a0a7e8868d9de525dd501907074e9cd17',1,'wxPLplotWindow']]],
-  ['onclose',['OnClose',['../classwxPLplotFrame.html#ad6bc45c851075b8e4061a56c249b63f9',1,'wxPLplotFrame']]],
-  ['onerase',['OnErase',['../classwxPLplotWindow.html#a77407a16c38b192aa60fe0e5a6d0b673',1,'wxPLplotWindow::OnErase()'],['../classwxPLplotwindow.html#a481f124fa96bdfceac88ffbb455b9ff0',1,'wxPLplotwindow::OnErase()']]],
+  ['oncreate',['OnCreate',['../classwxPLplotwindow.html#a09fe8cf92d3ccae0e58f1dd92051d684',1,'wxPLplotwindow']]],
+  ['onerase',['OnErase',['../classwxPLplotwindow.html#ad184b76db6081d2e4bdde5f6854eca7c',1,'wxPLplotwindow']]],
   ['onew2b_5fget',['ONEW2B_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#a48108b997959f8917ea9405eeba4a127',1,'plplot::core::plplotjavacJNI']]],
   ['onew2d_5fget',['ONEW2D_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#ac60c7e39ad16613ba0a03163d40943c7',1,'plplot::core::plplotjavacJNI']]],
-  ['onidle',['OnIdle',['../classwxPLplotApp.html#ad2f08db8718d94707b4b1c1198b777d4',1,'wxPLplotApp::OnIdle()'],['../classwxPLplotWindow.html#a50c1014d63709edaf5832bfd6a7e52a2',1,'wxPLplotWindow::OnIdle()']]],
-  ['oninit',['OnInit',['../classwxPLplotApp.html#aa8e27849156269cc916a2e415d6b790d',1,'wxPLplotApp']]],
-  ['onmaximize',['OnMaximize',['../classwxPLplotWindow.html#aac447d45cd53951525537a953357e06e',1,'wxPLplotWindow']]],
-  ['onmenu',['OnMenu',['../classwxPLplotFrame.html#afdedcd147f481667c7f07c38c97f7b2a',1,'wxPLplotFrame']]],
-  ['onmouse',['OnMouse',['../classwxPLplotWindow.html#aea7dc40de6b885d573c28ef49ae13073',1,'wxPLplotWindow']]],
-  ['onpaint',['OnPaint',['../classwxPLplotWindow.html#aaebb712bd591d38d83cb08c082c06c53',1,'wxPLplotWindow::OnPaint()'],['../classwxPLplotwindow.html#a261855525177621733df0d7dba749e72',1,'wxPLplotwindow::OnPaint()']]],
-  ['onsize',['OnSize',['../classwxPLplotWindow.html#a0fc045f71564a46324ec6a0297c2d548',1,'wxPLplotWindow::OnSize()'],['../classwxPLplotwindow.html#ac4e6d56f04ac6cd1edee0485777acd2c',1,'wxPLplotwindow::OnSize()']]],
+  ['onpaint',['OnPaint',['../classwxPLplotwindow.html#a53f657e3771b953d80ad077e7add1594',1,'wxPLplotwindow']]],
+  ['onsize',['OnSize',['../classwxPLplotwindow.html#aa4b386e34069cb93a2c47d9e986eb8bb',1,'wxPLplotwindow']]],
   ['open_5fspan_5ftag',['open_span_tag',['../cairo_8c.html#a867093342214820735c9ba2639a61163',1,'cairo.c']]],
   ['opendir',['opendir',['../dirent__msvc_8h.html#a56af8d3cfb4a2b2f44e20b276db71f2a',1,'dirent_msvc.h']]],
   ['openlib',['openlib',['../classplplot_1_1core_1_1PLStream.html#ab60146b9e58139fa4042edc86d25b5c0',1,'plplot::core::PLStream']]],
   ['openlink',['Openlink',['../plframe_8c.html#aeebefaec04e51ed012f1a228da6fcad0',1,'Openlink(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#a5d5a15109cfd92b30de260d8859c4659',1,'Openlink(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c'],['../plplotter_8c.html#a7005483db95c285a3bde1d0f83afca38',1,'Openlink(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#a3b7649b3ec8d467411ab7b7594d82523',1,'Openlink(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv):&#160;plplotter.c']]],
   ['operator_20octave_5fvalue',['operator octave_value',['../structoctave__value__ref.html#ab201e4e88c3cdab9759a151e8ab0bf55',1,'octave_value_ref']]],
-  ['operator_28_29',['operator()',['../classContourable__Data.html#a9b3d26312fbe5f9052f150f10f4e0041',1,'Contourable_Data::operator()()'],['../classCoord__2d.html#ac7363a2e45f0a6ab1f82371fb3beb9d9',1,'Coord_2d::operator()()']]],
+  ['operator_28_29',['operator()',['../classRand.html#af26fbf390a6ee90604189e59ec910757',1,'Rand::operator()()'],['../classContourable__Data.html#a9b3d26312fbe5f9052f150f10f4e0041',1,'Contourable_Data::operator()()'],['../classCoord__2d.html#ac7363a2e45f0a6ab1f82371fb3beb9d9',1,'Coord_2d::operator()()']]],
   ['operator_2a',['operator*',['../structoctave__value__ref.html#aab197384a2c36352f58c2749fd253c13',1,'octave_value_ref']]],
-  ['operator_3d',['operator=',['../classplstream.html#a2dbfc7548479908d27dab94893aacae1',1,'plstream::operator=()'],['../classoctave__swig__type.html#ab6d91d397ec8158313e7fcca46343a95',1,'octave_swig_type::operator=()']]],
+  ['operator_3d',['operator=',['../classPLNamedMutexLocker.html#ae51462bb922767382a097b88b399ea7a',1,'PLNamedMutexLocker::operator=()'],['../classplstream.html#a2dbfc7548479908d27dab94893aacae1',1,'plstream::operator=()'],['../classoctave__swig__type.html#ab6d91d397ec8158313e7fcca46343a95',1,'octave_swig_type::operator=()']]],
   ['opt_5fa',['opt_a',['../plargs_8c.html#a22b9e603df78ad9759048b0b5aa97b97',1,'opt_a(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a031c7b3bf488e965d3f02edee2e6d4d0',1,'opt_a(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
   ['opt_5fauto_5fpath',['opt_auto_path',['../plargs_8c.html#a433d97e5b433721cc4f750dcce602723',1,'opt_auto_path(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a6d9a246989841e6394804a3b5b0085fd',1,'opt_auto_path(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
   ['opt_5fbg',['opt_bg',['../plargs_8c.html#aea3d7fbcbd122cd689a9ee129db5285a',1,'opt_bg(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a3801db071a1f029778ba3acfd1d171b0',1,'opt_bg(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
@@ -52,6 +46,8 @@ var searchData=
   ['opt_5fjy',['opt_jy',['../plargs_8c.html#a4876a664990d0d54e7cc5d566fb7de2e',1,'opt_jy(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a1af2968fc47ea2cbbd3221c43bbd00b5',1,'opt_jy(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
   ['opt_5flocale',['opt_locale',['../plargs_8c.html#a7d8a254eab4dc3049103dd6542590b1f',1,'opt_locale(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a77c4a1eb559afa8db5d54ad2eff43fc7',1,'opt_locale(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
   ['opt_5fmar',['opt_mar',['../plargs_8c.html#ada02ad1a23de63a8f29be293c7f81916',1,'opt_mar(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a6c3dd40f998e3542bb07aaa1101445b2',1,'opt_mar(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
+  ['opt_5fmfi',['opt_mfi',['../plargs_8c.html#a0691712e0b1f0e6bce154e73384870b8',1,'opt_mfi(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#aac929d3bf383d5ed8684770d833da22e',1,'opt_mfi(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
+  ['opt_5fmfo',['opt_mfo',['../plargs_8c.html#ac7a8dc3bdb60db4292bafe73e79257a3',1,'opt_mfo(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#aa4b29828c54f889d442ad57608d25680',1,'opt_mfo(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
   ['opt_5fncol0',['opt_ncol0',['../plargs_8c.html#ab448ff3aa598dadd225c9138cb870ec4',1,'opt_ncol0(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a83d65ee7aa9945a738d50ddda2a5fe20',1,'opt_ncol0(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
   ['opt_5fncol1',['opt_ncol1',['../plargs_8c.html#a471313fd89e67969eb0c637a2c8c416b',1,'opt_ncol1(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a7073df66d085f663f7138106acf939e9',1,'opt_ncol1(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
   ['opt_5fnopixmap',['opt_nopixmap',['../plargs_8c.html#afe5f63dfc95f2ac3f0cb43d218dbba2b',1,'opt_nopixmap(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#ade3fdc68c8d6d754a29a552dcad80b86',1,'opt_nopixmap(const char *PL_UNUSED(opt), const char *PL_UNUSED(opt_arg), void *PL_UNUSED(client_data)):&#160;plargs.c']]],
@@ -70,5 +66,6 @@ var searchData=
   ['opt_5fwidth',['opt_width',['../plargs_8c.html#a61236c7e1a1f8b03fdb8dfbf60e412a0',1,'opt_width(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a65cf6211752a80054157629f5abf25b8',1,'opt_width(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
   ['opt_5fwplt',['opt_wplt',['../plargs_8c.html#a799666480897f06b9362fec1c6e6bc3b',1,'opt_wplt(const char *, const char *, void *):&#160;plargs.c'],['../plargs_8c.html#a4051f4ef06cfab9d71881a9a89977e9f',1,'opt_wplt(const char *PL_UNUSED(opt), const char *opt_arg, void *PL_UNUSED(client_data)):&#160;plargs.c']]],
   ['optusage',['OptUsage',['../classplstream.html#af54356617be65cdf161918e3430321df',1,'plstream::OptUsage()'],['../classplplot_1_1core_1_1PLStream.html#af6dd6dd9be106f386255eafc03d5c5fa',1,'plplot.core.PLStream.OptUsage()']]],
-  ['orient',['orient',['../namespacePlframe.html#a82eaf9961ca3b88bf86e7c98651cdfaa',1,'Plframe.orient()'],['../plframe_8c.html#a2c41613105823b4f75157ad917403a10',1,'Orient(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#abfec6bcd9be71987ed497b7539fda236',1,'Orient(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c'],['../plplotter_8c.html#a6e0a64c115acc82e8c89c2b776f1c407',1,'Orient(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#af8841f8e4aaafd7f8f958211c7cb5788',1,'Orient(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv):&#160;plplotter.c']]]
+  ['orient',['orient',['../namespacePlframe.html#a82eaf9961ca3b88bf86e7c98651cdfaa',1,'Plframe.orient()'],['../plframe_8c.html#a2c41613105823b4f75157ad917403a10',1,'Orient(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#abfec6bcd9be71987ed497b7539fda236',1,'Orient(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c'],['../plplotter_8c.html#a6e0a64c115acc82e8c89c2b776f1c407',1,'Orient(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#af8841f8e4aaafd7f8f958211c7cb5788',1,'Orient(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **argv):&#160;plplotter.c']]],
+  ['originchanger',['OriginChanger',['../classOriginChanger.html#aa86ed32c05b1252ec0829eaf59fa77cf',1,'OriginChanger']]]
 ];
