@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['xform',['xform',['../classCoord__Xformer.html#abd478464102004b5f9a486d816ad525f',1,'Coord_Xformer::xform()'],['../classcxx__pltr2.html#ac7a061b153de8157c25a36f0a8f4f1a5',1,'cxx_pltr2::xform()'],['../plplot__octave_8h.html#acf5309370447410efcc2382acbb597cc',1,'xform(PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer pltr_data):&#160;plplot_octave.h'],['../plplot__octaveOCTAVE__wrap_8cxx.html#acf5309370447410efcc2382acbb597cc',1,'xform(PLFLT x, PLFLT y, PLFLT *tx, PLFLT *ty, PLPointer pltr_data):&#160;plplot_octaveOCTAVE_wrap.cxx']]],
+  ['xform',['xform',['../classCoord__Xformer.html#abd478464102004b5f9a486d816ad525f',1,'Coord_Xformer::xform()'],['../classcxx__pltr2.html#ac7a061b153de8157c25a36f0a8f4f1a5',1,'cxx_pltr2::xform()'],['../plplot__octaveOCTAVE__wrap_8cxx.html#acf5309370447410efcc2382acbb597cc',1,'xform():&#160;plplot_octaveOCTAVE_wrap.cxx']]],
   ['xormod',['xormod',['../classplstream.html#ab338a30331e3e8fb4254e8599ec9fe42',1,'plstream::xormod(bool mode, bool *status)'],['../classplstream.html#a2a66abc85c097f2a59d3902aaf336a8f',1,'plstream::xormod(PLINT mode, PLINT *status)'],['../classplplot_1_1core_1_1PLStream.html#ae492899fa93e15c29a853ae786fdee79',1,'plplot.core.PLStream.xormod(boolean mode, boolean[] status)'],['../classplplot_1_1core_1_1PLStream.html#ac1693421b67dc976d17a3ff4e78ecbe0',1,'plplot.core.PLStream.xormod(int mode, int[] status)']]],
   ['xscroll',['xScroll',['../plframe_8c.html#a37350a7efd8cc99ca2626407194e7440',1,'xScroll(Tcl_Interp *, PlFrame *, int, const char **):&#160;plframe.c'],['../plframe_8c.html#a2ac14936d04f7c26dc57ff21c7581e1b',1,'xScroll(Tcl_Interp *interp, register PlFrame *plFramePtr, int argc, const char **argv):&#160;plframe.c']]]
 ];
