@@ -2,16 +2,12 @@ var searchData=
 [
   ['zerow2b_5fget',['ZEROW2B_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#ab56ccb082d5c932a01997af206fd8e10',1,'plplot::core::plplotjavacJNI']]],
   ['zerow2d_5fget',['ZEROW2D_get',['../classplplot_1_1core_1_1plplotjavacJNI.html#aaee003ed49acbc14f6cad4854ebc1a9a',1,'plplot::core::plplotjavacJNI']]],
-  ['zoom',['zoom',['../gcw-lib_8c.html#a971c21e8a4e0785da9b323b65613b817',1,'gcw-lib.c']]],
-  ['zoom_5f100',['zoom_100',['../gcw-lib_8c.html#afd4b0a229e4472dfc39f7bf744ec2d30',1,'gcw-lib.c']]],
   ['zoom_5fback',['zoom_back',['../namespacePlframe.html#a2e410bd99fe2fdd847822c00f2de84eb',1,'Plframe']]],
   ['zoom_5fcoords',['zoom_coords',['../namespacePlframe.html#a946d0bf3c1c688957317af7cadca405b',1,'Plframe']]],
   ['zoom_5fenter',['zoom_enter',['../namespacePlframe.html#a4f18d95202bc5cb0f5cfd458962c13ad',1,'Plframe']]],
   ['zoom_5fforward',['zoom_forward',['../namespacePlframe.html#a27514f126a26733be679a4477f158081',1,'Plframe']]],
-  ['zoom_5fin',['zoom_in',['../gcw-lib_8c.html#ac95db1024e0328942fcf749c0ac9d776',1,'gcw-lib.c']]],
   ['zoom_5fmouse_5fdraw',['zoom_mouse_draw',['../namespacePlframe.html#ad161d617381fc9c21959c30b7c442630',1,'Plframe']]],
   ['zoom_5fmouse_5fend',['zoom_mouse_end',['../namespacePlframe.html#aaba97d995fc0ffd75295be30f7985942',1,'Plframe']]],
-  ['zoom_5fout',['zoom_out',['../gcw-lib_8c.html#a0aca93d480e91932f6a18d2750d747a9',1,'gcw-lib.c']]],
   ['zoom_5freset',['zoom_reset',['../namespacePlframe.html#ad231586193b58aa4e36a25a282fbcaec',1,'Plframe']]],
   ['zoom_5fselect',['zoom_select',['../namespacePlframe.html#a77523d2419824163c3bb56ec853945b6',1,'Plframe']]],
   ['zoom_5fstart',['zoom_start',['../namespacePlframe.html#ae9948a4c7a922bb2654f57a0fa073c32',1,'Plframe']]]
