@@ -1,8 +1,8 @@
 var searchData=
 [
   ['core',['core',['../namespaceplplot_1_1core.html',1,'plplot']]],
+  ['plcallback',['plcallback',['../namespaceplcallback.html',1,'']]],
   ['plframe',['Plframe',['../namespacePlframe.html',1,'']]],
   ['plplot',['plplot',['../namespaceplplot.html',1,'']]],
-  ['plplotc',['plplotc',['../namespaceplplotc.html',1,'']]],
-  ['plplotcanvas',['plplotcanvas',['../namespaceplplotcanvas.html',1,'']]]
+  ['plplotc',['plplotc',['../namespaceplplotc.html',1,'']]]
 ];
