@@ -49,11 +49,16 @@ var searchData=
   ['_5fwrap_5fplbop_5ftexinfo',['_wrap_plbop_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae5c0ac10e2630787663c19ee546f6bc5',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplbox3_5ftexinfo',['_wrap_plbox3_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a03cfd966415718f4fffecb9193d53b41',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplbox_5ftexinfo',['_wrap_plbox_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ab853cfe7ce775d3882971390e4584627',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplbtime_5ftexinfo',['_wrap_plbtime_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a5b30d9dc4ea6486f01114cbc1de0126b',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplcalc_5fworld_5ftexinfo',['_wrap_plcalc_world_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a0a2c258f6dcd3cdf6513734422990176',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplclear_5ftexinfo',['_wrap_plclear_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ac5c6e7b86c86dc0737dac02df648b105',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplcol0_5ftexinfo',['_wrap_plcol0_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a1761de57100c0d31a25fb0f2b1d89004',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplcol1_5ftexinfo',['_wrap_plcol1_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aeec4aea06c98bb36d5625d3f903fe485',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplcolorbar_5ftexinfo',['_wrap_plcolorbar_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#afab0eefbdde0ae7077e59fc76995ac71',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplconfigtime_5ftexinfo',['_wrap_plconfigtime_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a7216a1ee562155fabc49e88fdd64746c',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplcont_5ftexinfo',['_wrap_plcont_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aeb5e286e22dd49a5c53d06e3e0d49913',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplcpstrm_5ftexinfo',['_wrap_plcpstrm_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a83a26a27ebfa2aba10d7710d34d5dbef',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplctime_5ftexinfo',['_wrap_plctime_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aec230e51536ce9702385accbe5d43823',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplend1_5ftexinfo',['_wrap_plend1_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a37ce505d80c4ed872fcc4634362e344a',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplend_5ftexinfo',['_wrap_plend_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a12b6a75136ddfbc0b72065f15381c86f',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplenv0_5ftexinfo',['_wrap_plenv0_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a44c4b472eadb4005011215b1c2fee6dc',1,'plplot_octaveOCTAVE_wrap.cxx']]],
@@ -68,6 +73,7 @@ var searchData=
   ['_5fwrap_5fplfont_5ftexinfo',['_wrap_plfont_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad28e38730730fd3fdb27e7c360fed5a5',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplfontld_5ftexinfo',['_wrap_plfontld_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a79d9f72aeda3ed9642cd42ccff4eadd8',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplgchr_5ftexinfo',['_wrap_plgchr_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a4f2bcefca98606b5697148b740127ce6',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplgcmap1_5frange_5ftexinfo',['_wrap_plgcmap1_range_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a353b601cfe71ab0e29c3426679437ed3',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplgcol0_5ftexinfo',['_wrap_plgcol0_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a9356bc1d7e75b8b4e89eeed4e9837b06',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplgcol0a_5ftexinfo',['_wrap_plgcol0a_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a33ff8a9ce80ad074a212665248b43359',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplgcolbg_5ftexinfo',['_wrap_plgcolbg_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad59523ca68afcfbf0139250017683a37',1,'plplot_octaveOCTAVE_wrap.cxx']]],
@@ -85,6 +91,7 @@ var searchData=
   ['_5fwrap_5fplgpage_5ftexinfo',['_wrap_plgpage_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a3cb56c1e02dd0a800320bb3ae92b95e0',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplgra_5ftexinfo',['_wrap_plgra_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae9edd6bffb84c56c14b227b54cee149d',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplgradient_5ftexinfo',['_wrap_plgradient_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#afc8bbf76f9aed0216a7dc7e73d2556d7',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplgriddata_5ftexinfo',['_wrap_plgriddata_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ac0192a83fc06dbecaf696b811eba49c1',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplgspa_5ftexinfo',['_wrap_plgspa_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad6c1830b23066ec1272e75a6da3e32e3',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplgstrm_5ftexinfo',['_wrap_plgstrm_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a7198af1b4b98936047474e5f9f9a85aa',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplgver_5ftexinfo',['_wrap_plgver_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a531eb694c170e1674dcaa9993e649de8',1,'plplot_octaveOCTAVE_wrap.cxx']]],
@@ -95,6 +102,7 @@ var searchData=
   ['_5fwrap_5fplgzax_5ftexinfo',['_wrap_plgzax_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a730dc323aa59640537133acd57cff60d',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplhist_5ftexinfo',['_wrap_plhist_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aea461967543b0664b4f8e47740e9df46',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplhlsrgb_5ftexinfo',['_wrap_plhlsrgb_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aa236c6bec1399905d39e8576ee4d6916',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplimagefr_5ftexinfo',['_wrap_plimagefr_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aced4dd5e41a58f1d126a0332d4179cef',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplinit_5ftexinfo',['_wrap_plinit_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a7975d40886664c1c53d41fdedf449100',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fpljoin_5ftexinfo',['_wrap_pljoin_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad07a9c4fcac378014e82375a664f6961',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fpllab_5ftexinfo',['_wrap_pllab_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ab9cde54baf0c8d14ca631917658a63e2',1,'plplot_octaveOCTAVE_wrap.cxx']]],
@@ -104,10 +112,19 @@ var searchData=
   ['_5fwrap_5fplline_5ftexinfo',['_wrap_plline_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a73ac1d462f6994ffbd1a6f29aeecea44',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fpllsty_5ftexinfo',['_wrap_pllsty_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a705e6d891cc869a85e78ae597f6304eb',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplmap_5ftexinfo',['_wrap_plmap_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a61485d75cd2c7bf96f766343011586a5',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplmapfill_5ftexinfo',['_wrap_plmapfill_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a653c01bc6b35fb020c1db2c8aa85c223',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplmapline_5ftexinfo',['_wrap_plmapline_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a7c2b14e1e4bb6e5ec4faa64df9c4112b',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplmapstring_5ftexinfo',['_wrap_plmapstring_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a47e9a99e16ac455df40cd578a3abdfa1',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplmaptex_5ftexinfo',['_wrap_plmaptex_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#adb7310118f8750ab8cc0b6c73de0f209',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplmeridians_5ftexinfo',['_wrap_plmeridians_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a1a8b540981e35670894f9eda38d00967',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplmesh_5ftexinfo',['_wrap_plmesh_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a6387ee3c522f6fde37faac6ef9f67f9b',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplmeshc_5ftexinfo',['_wrap_plmeshc_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a05986bd52600fc7e2d9896a1faa890a6',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplmkstrm_5ftexinfo',['_wrap_plmkstrm_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a0c447aec75278270bc33c5b4af2f4546',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplmtex3_5ftexinfo',['_wrap_plmtex3_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aa53274e1db64febf0e9201f075116861',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplmtex_5ftexinfo',['_wrap_plmtex_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a6132d587658e5f9b5d686120e71b569a',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplot3d_5ftexinfo',['_wrap_plot3d_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a608b9473b4442fcf49fd460d7f9179c4',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplot3dc_5ftexinfo',['_wrap_plot3dc_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a20c13f074fc6d38461de38d80311afef',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplot3dcl_5ftexinfo',['_wrap_plot3dcl_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad4b812626f9f2fcbebd472fc2793c384',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplparseopts_5ftexinfo',['_wrap_plparseopts_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad50938b99012a96743156299e0bf21b8',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplpat_5ftexinfo',['_wrap_plpat_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad6de6f229517ee07ee9bc2f783db6f03',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplpath_5ftexinfo',['_wrap_plpath_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#accf0b523c4d903538d61bfd6edda9091',1,'plplot_octaveOCTAVE_wrap.cxx']]],
@@ -125,6 +142,7 @@ var searchData=
   ['_5fwrap_5fplscmap0_5ftexinfo',['_wrap_plscmap0_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a32e7f636b575d4a19d94cf97bc3fa16f',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplscmap0a_5ftexinfo',['_wrap_plscmap0a_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aead5dc1d59867f1a441bafa41c05cc28',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplscmap0n_5ftexinfo',['_wrap_plscmap0n_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a65f48f537cc71a859d911ce533414569',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplscmap1_5frange_5ftexinfo',['_wrap_plscmap1_range_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#afea08d524a1f34fc96f67b61079b4bfb',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplscmap1_5ftexinfo',['_wrap_plscmap1_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a03cf65f0151e6b99793a43192b292470',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplscmap1a_5ftexinfo',['_wrap_plscmap1a_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a8b6dc3c0af9c5fa2f654962909cd1d7e',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplscmap1l_5ftexinfo',['_wrap_plscmap1l_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aad41a3e50d11416b50ffcb5cccc1582c',1,'plplot_octaveOCTAVE_wrap.cxx']]],
@@ -149,6 +167,9 @@ var searchData=
   ['_5fwrap_5fplsfci_5ftexinfo',['_wrap_plsfci_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a4c3dcc40198bd902387211e9e20e62d7',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplsfnam_5ftexinfo',['_wrap_plsfnam_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a1f9dfda765c853242b80ce0b909bd171',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplsfont_5ftexinfo',['_wrap_plsfont_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a9fd95438850d30290a2696b0772d0943',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplshade1_5ftexinfo',['_wrap_plshade1_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a56e6bbe3f1b66306773901d7a6a33901',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplshade_5ftexinfo',['_wrap_plshade_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a758878c62155eddc4ed09be54c46e585',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplshades_5ftexinfo',['_wrap_plshades_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a69ba285128deca5a9e650bb24066d5d6',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplslabelfunc_5ftexinfo',['_wrap_plslabelfunc_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a4bf96847a6ca31044b2aaf3d1fc73ed2',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplsmaj_5ftexinfo',['_wrap_plsmaj_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a26597a107bb38cbd32f14a1c046d4d52',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplsmin_5ftexinfo',['_wrap_plsmin_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a98f1de558a442b07859ded8fa6e75326',1,'plplot_octaveOCTAVE_wrap.cxx']]],
@@ -166,8 +187,11 @@ var searchData=
   ['_5fwrap_5fplstring3_5ftexinfo',['_wrap_plstring3_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a01915eb364f5a2a95916ca8119109fe8',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplstring_5ftexinfo',['_wrap_plstring_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#adc68738aa382c25d57692734b32a2b9f',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplstripa_5ftexinfo',['_wrap_plstripa_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad36ed9784b616cd56c2ba9776ae43a1d',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplstripc_5ftexinfo',['_wrap_plstripc_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a5caf9bb5f1ed7b311d939b522a017110',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplstripd_5ftexinfo',['_wrap_plstripd_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a504a917ad44d08564b5997a62de04a63',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplstyl_5ftexinfo',['_wrap_plstyl_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a6a4cd8420161832b90cbdba4a3533fa2',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplsurf3d_5ftexinfo',['_wrap_plsurf3d_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a438a8ffdceab1a2e877ad3fb0615f84b',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplsurf3dl_5ftexinfo',['_wrap_plsurf3dl_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a63c84c9795f5f74f3e4cb372d9cd5176',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplsvect_5ftexinfo',['_wrap_plsvect_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#af878cbcf61bf72976099a3399ba9b3ed',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplsvpa_5ftexinfo',['_wrap_plsvpa_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a13530096b73487b7ce2c59c202c9e813',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplsxax_5ftexinfo',['_wrap_plsxax_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#aa501592638bfa257b89ecef6f6887068',1,'plplot_octaveOCTAVE_wrap.cxx']]],
@@ -177,6 +201,7 @@ var searchData=
   ['_5fwrap_5fpltext_5ftexinfo',['_wrap_pltext_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ab734671e68f7032000f6c7e4850f7702',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fpltimefmt_5ftexinfo',['_wrap_pltimefmt_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a121d640a5966d8f1aa6fd19ddc7c5f22',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplvasp_5ftexinfo',['_wrap_plvasp_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae2f058e059af4134c502a7184eb2a3c4',1,'plplot_octaveOCTAVE_wrap.cxx']]],
+  ['_5fwrap_5fplvect_5ftexinfo',['_wrap_plvect_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a84f771c2d9c077a0eea911b1b1478a99',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplvpas_5ftexinfo',['_wrap_plvpas_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a070f675ffbc42d40983ac0c3fb62af28',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplvpor_5ftexinfo',['_wrap_plvpor_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a99d9ee043452c923b369ed08f16431e5',1,'plplot_octaveOCTAVE_wrap.cxx']]],
   ['_5fwrap_5fplvsta_5ftexinfo',['_wrap_plvsta_texinfo',['../plplot__octaveOCTAVE__wrap_8cxx.html#a03917336709886d45c374df975694c86',1,'plplot_octaveOCTAVE_wrap.cxx']]],
