@@ -15,15 +15,17 @@ var searchData=
   ['deleteproc',['deleteProc',['../structCommand.html#a8a2efb8447e4e31c6272bd7a53aa4b99',1,'Command']]],
   ['delta',['delta',['../structPLStream.html#aab6220efc877149ddaad3b45ea6cc9f7',1,'PLStream']]],
   ['depth',['depth',['../structTkwDisplay.html#a9426efee240bc4a860ee9331a1b2c537',1,'TkwDisplay::depth()'],['../structXwDisplay.html#a56193de1c93773eafd82499cd1b00717',1,'XwDisplay::depth()']]],
-  ['desc',['desc',['../structcdImageStruct.html#a0e1ec004c6a0169c15ae3e029db44a86',1,'cdImageStruct::desc()'],['../structplplot_1_1__N1.html#af0534204dc57ea02028dbd2b9060e591',1,'plplot::_N1::desc()'],['../structPLOptionTable.html#a911b32327a6078131c7810248c0f02cc',1,'PLOptionTable::desc()'],['../structPLOptionTable.html#a1995b25c4986689365c2be3041c6af7e',1,'PLOptionTable::desc()']]],
+  ['desc',['desc',['../structcdImageStruct.html#a0e1ec004c6a0169c15ae3e029db44a86',1,'cdImageStruct::desc()'],['../structplplot_1_1__N1.html#af0534204dc57ea02028dbd2b9060e591',1,'plplot::_N1::desc()'],['../structPLOptionTable.html#a911b32327a6078131c7810248c0f02cc',1,'PLOptionTable::desc()']]],
   ['destroy',['destroy',['../structSwigPyClientData.html#a1c4e62712f23db599e85e24e14818d59',1,'SwigPyClientData']]],
   ['destroyed',['destroyed',['../structoctave__swig__type_1_1cpp__ptr.html#aa26dc33d9fabfdafd2ff3fb988c4a21b',1,'octave_swig_type::cpp_ptr']]],
   ['destructor',['destructor',['../structswig__lua__class.html#ae7029d37913cf77df8f5c473c5cb43fe',1,'swig_lua_class::destructor()'],['../structswig__octave__class.html#a5e1ac4d7d832f631bc2001bfceeb374b',1,'swig_octave_class::destructor()']]],
   ['dev',['dev',['../structPLStream.html#abf8a6d71f35aeb854e3c75f5ed4f7679',1,'PLStream']]],
+  ['dev_5f2005_5fheader',['dev_2005_header',['../plmetafile_8c.html#a355ad03ff95e155e9ef4654d7e15bb65',1,'plmetafile.c']]],
   ['dev_5farc',['dev_arc',['../structPLStream.html#a263a03b7f7481ecf73b47b50821d3006',1,'PLStream']]],
   ['dev_5fclear',['dev_clear',['../structPLStream.html#a5ffd0f763c8d12a0912ebc4355377329',1,'PLStream']]],
   ['dev_5fcompression',['dev_compression',['../structPLStream.html#a0b1b2bd10b03c184910e90aac79dddce',1,'PLStream']]],
   ['dev_5fdash',['dev_dash',['../structPLStream.html#a537ff4fef08a7f0978ac8f285739b54d',1,'PLStream']]],
+  ['dev_5fdata',['dev_data',['../structPLStream.html#a64a27bd343528519bc7b9172ac9ae43b',1,'PLStream']]],
   ['dev_5fdi',['dev_di',['../structPLStream.html#ae84e24623a23d971c07e914557276808',1,'PLStream']]],
   ['dev_5feofill',['dev_eofill',['../structPLStream.html#ae43fbab5ba68a7c71f4cf5385178b2ff',1,'PLStream']]],
   ['dev_5ffastimg',['dev_fastimg',['../structPLStream.html#a7055c5f16dfa3de7f6c70fe69f846360',1,'PLStream']]],
@@ -54,9 +56,10 @@ var searchData=
   ['dev_5fz',['dev_z',['../structPLStream.html#a9c5fe11361bfc214207b1bf769199780',1,'PLStream']]],
   ['dev_5fzmax',['dev_zmax',['../structPLStream.html#aa1ab99774297abc47e0ae0a29b1c62fd',1,'PLStream']]],
   ['dev_5fzmin',['dev_zmin',['../structPLStream.html#a6b267f89557ceef8790911bbb9062bb7',1,'PLStream']]],
-  ['devdesc',['devDesc',['../classwxPLDevBase.html#ad2e494bf6b6c520492cd4a39d50b4ee9',1,'wxPLDevBase::devDesc()'],['../structPlFrame.html#a409578178dbf1cd9bbdf2ce4279503c8',1,'PlFrame::devDesc()'],['../structPlPlotter.html#aaea02031eb53d6fa673b96f19a626a3c',1,'PlPlotter::devDesc()']]],
+  ['devdesc',['devDesc',['../structPlFrame.html#a409578178dbf1cd9bbdf2ce4279503c8',1,'PlFrame::devDesc()'],['../structPlPlotter.html#aaea02031eb53d6fa673b96f19a626a3c',1,'PlPlotter::devDesc()']]],
   ['device',['device',['../structPLStream.html#aba76488f65f93041f7448fee09966b49',1,'PLStream']]],
-  ['devname',['DevName',['../structPLStream.html#aab9c4166d130ca8e402b0b1c5e2539fe',1,'PLStream::DevName()'],['../classwxPLDevBase.html#a54fd03da71b60477cf5dff160eb4361a',1,'wxPLDevBase::devName()'],['../structPlFrame.html#a6bd51c8ea7742c10c24bf57f19a37583',1,'PlFrame::devName()'],['../structPlPlotter.html#a91a6a822d164ae7622b16657567dc372',1,'PlPlotter::devName()']]],
+  ['device_5fheader',['device_header',['../struct__plm__version.html#a4c0e4696f49c6ea945f336f1906b3965',1,'_plm_version']]],
+  ['devname',['devName',['../structPlFrame.html#a6bd51c8ea7742c10c24bf57f19a37583',1,'PlFrame::devName()'],['../structPlPlotter.html#a91a6a822d164ae7622b16657567dc372',1,'PlPlotter::devName()'],['../structPLStream.html#aab9c4166d130ca8e402b0b1c5e2539fe',1,'PLStream::DevName()']]],
   ['diclpxma',['diclpxma',['../structPLStream.html#acc943d43125d39d5abdc7b66a53944a9',1,'PLStream']]],
   ['diclpxmi',['diclpxmi',['../structPLStream.html#aedabf7549e134fb86674e4456e3b3313',1,'PLStream']]],
   ['diclpyma',['diclpyma',['../structPLStream.html#a97be1e95c2579b1fc3ed24da73601574',1,'PLStream']]],
@@ -111,17 +114,16 @@ var searchData=
   ['draw_5flinexy',['DRAW_LINEXY',['../classplplot.html#ab4fc454297b7b4df3c1f73fe9dae4cbe',1,'plplot::DRAW_LINEXY()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a6b221b57c0b722bcca7d18195666d5fb',1,'plplot.core.plplotjavacConstants.DRAW_LINEXY()'],['../namespaceplplotc.html#ac51a99e6a9f091db6f2996d97f675fd6',1,'plplotc.DRAW_LINEXY()']]],
   ['draw_5fliney',['DRAW_LINEY',['../classplplot.html#aa566c9a8b5967e071359585fbbe5975e',1,'plplot::DRAW_LINEY()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a57935553f9eed159d7071c06cdf27e18',1,'plplot.core.plplotjavacConstants.DRAW_LINEY()'],['../namespaceplplotc.html#ae85623e8a7f98f87cf65876928d75951',1,'plplotc.DRAW_LINEY()']]],
   ['draw_5fsides',['DRAW_SIDES',['../classplplot.html#a498074676eb148d19d7465505e44ae2c',1,'plplot::DRAW_SIDES()'],['../interfaceplplot_1_1core_1_1plplotjavacConstants.html#a1045c9467abda926a1710b7103962e9b',1,'plplot.core.plplotjavacConstants.DRAW_SIDES()'],['../namespaceplplotc.html#a666c56f6d51ce51bd51c15bde0834f75',1,'plplotc.DRAW_SIDES()']]],
-  ['draw_5fxhair',['draw_xhair',['../classwxPLDevBase.html#ae250fd8cea147a1c3782102f5228274e',1,'wxPLDevBase']]],
   ['drawing_5frband',['drawing_rband',['../structPlFrame.html#adf4ddc0c44164d8a0d5bdfa3e0878aef',1,'PlFrame::drawing_rband()'],['../structPlPlotter.html#a153b99d69175b18f0691cc1d0d593c4e',1,'PlPlotter::drawing_rband()']]],
   ['drawing_5fxhairs',['drawing_xhairs',['../structPlFrame.html#a983f748494f81aecc7bd02ad139b168c',1,'PlFrame::drawing_xhairs()'],['../structPlPlotter.html#af10abb0cf0b1266ccdf1641e6551b2af',1,'PlPlotter::drawing_xhairs()'],['../structTkwDev.html#a3e454f604d96880ce717313096bc51c6',1,'TkwDev::drawing_xhairs()'],['../structXwDev.html#a9a6b2d42496aa00b41eac624b8b70101',1,'XwDev::drawing_xhairs()']]],
   ['drv_5fopt',['drv_opt',['../plargs_8c.html#ad42924d347ff680f9d8e7eb36415f079',1,'plargs.c']]],
   ['dum_5fuchar',['dum_uchar',['../plr_8c.html#ae41f387fd9b07755f1b68ea2b834786f',1,'plr.c']]],
   ['dum_5fushort',['dum_ushort',['../plr_8c.html#a7379e9a3346908d1d9c0eac320a065f4',1,'plr.c']]],
   ['dvalue',['dvalue',['../structswig__lua__const__info.html#ac50e848b2a6a628fa1eeb4924f608cee',1,'swig_lua_const_info::dvalue()'],['../structswig__const__info.html#a74e477f1dbf515bcb7e2ef07a1d34c35',1,'swig_const_info::dvalue()']]],
-  ['dx',['dx',['../structplplot__types_1_1plgraphicsin.html#abc57524390f4a7fc09af693f02beaece',1,'plplot_types::plgraphicsin::dx()'],['../structIMG__DT.html#a96c130e4360f7780f2d161c0a3f32108',1,'IMG_DT::dx()'],['../structplplot_1_1__N2.html#ac646480593d84982db2b8e860117d475',1,'plplot::_N2::dX()'],['../structPLGraphicsIn.html#ae15d582003fed123c0d48d422bffd144',1,'PLGraphicsIn::dX()'],['../namespacePlframe.html#a2def17e5a9cb1392e4f4fa30fd6de33e',1,'Plframe.dx()']]],
+  ['dx',['dx',['../structplplot__graphics_1_1plgraphicsin.html#ac3f083e4645ed568195d759a57fb6816',1,'plplot_graphics::plgraphicsin::dx()'],['../structIMG__DT.html#a96c130e4360f7780f2d161c0a3f32108',1,'IMG_DT::dx()'],['../structplplot_1_1__N2.html#ac646480593d84982db2b8e860117d475',1,'plplot::_N2::dX()'],['../structPLGraphicsIn.html#ae15d582003fed123c0d48d422bffd144',1,'PLGraphicsIn::dX()'],['../namespacePlframe.html#a2def17e5a9cb1392e4f4fa30fd6de33e',1,'Plframe.dx()']]],
   ['dxma',['dxma',['../structplplot_1_1__N3.html#a5fa61330c619cd69264439d602c5efd2',1,'plplot::_N3::dxma()'],['../structPLWindow.html#aa7846632259bd8ddb2cf695b4112232a',1,'PLWindow::dxma()']]],
   ['dxmi',['dxmi',['../structplplot_1_1__N3.html#aefe9237accf83fb06db55ab6a10e7ee8',1,'plplot::_N3::dxmi()'],['../structPLWindow.html#afa3570309e945c264e79ba2a3a566fec',1,'PLWindow::dxmi()']]],
-  ['dy',['dy',['../structplplot__types_1_1plgraphicsin.html#a12f70f731321a02c45ae6e30fa1eacda',1,'plplot_types::plgraphicsin::dy()'],['../structIMG__DT.html#a18206f1e64d54e345fcde39d067e6ad7',1,'IMG_DT::dy()'],['../structplplot_1_1__N2.html#ae6c62648845e3d0ba49ea02faabc4127',1,'plplot::_N2::dY()'],['../structPLGraphicsIn.html#a90a08dfcb5e486ac4ce34507a6004c11',1,'PLGraphicsIn::dY()'],['../namespacePlframe.html#a392c52a1b0b0b952bb2a7fada883e13a',1,'Plframe.dy()']]],
+  ['dy',['dy',['../structplplot__graphics_1_1plgraphicsin.html#ad029a91a4f2d101ea0c7d428762eae5e',1,'plplot_graphics::plgraphicsin::dy()'],['../structIMG__DT.html#a18206f1e64d54e345fcde39d067e6ad7',1,'IMG_DT::dy()'],['../structplplot_1_1__N2.html#ae6c62648845e3d0ba49ea02faabc4127',1,'plplot::_N2::dY()'],['../structPLGraphicsIn.html#a90a08dfcb5e486ac4ce34507a6004c11',1,'PLGraphicsIn::dY()'],['../namespacePlframe.html#a392c52a1b0b0b952bb2a7fada883e13a',1,'Plframe.dy()']]],
   ['dyma',['dyma',['../structplplot_1_1__N3.html#a8c0d51fd26029f65910eb9473627381c',1,'plplot::_N3::dyma()'],['../structPLWindow.html#a4d0b980695e01367e50079521e61fc24',1,'PLWindow::dyma()']]],
   ['dymi',['dymi',['../structplplot_1_1__N3.html#af0e5799d84888b318e2995e04ea8d1a8',1,'plplot::_N3::dymi()'],['../structPLWindow.html#ac5a88aaabbd32564239f8a3f62f8892b',1,'PLWindow::dymi()']]]
 ];
