@@ -4,6 +4,6 @@ var searchData=
   ['key',['key',['../structht__bucket.html#a29f598025fca935a60c2720c004bd690',1,'ht_bucket']]],
   ['keyeh',['KeyEH',['../structPLStream.html#a855b9cd8ab925cccacad4ea057c12f8f',1,'PLStream']]],
   ['keyeh_5fdata',['KeyEH_data',['../structPLStream.html#af33021308e7252fc444851616dda077c',1,'PLStream']]],
-  ['keysym',['keysym',['../structplplot_1_1__N2.html#abccb2986a94be486bb0fb8b2f83506bc',1,'plplot::_N2::keysym()'],['../structplplot__types_1_1plgraphicsin.html#a65b8226749d6f02edd84861014c618c9',1,'plplot_types::plgraphicsin::keysym()'],['../structPLGraphicsIn.html#ad70616982f7224261873697c93e48ee4',1,'PLGraphicsIn::keysym()']]],
+  ['keysym',['keysym',['../structplplot_1_1__N2.html#abccb2986a94be486bb0fb8b2f83506bc',1,'plplot::_N2::keysym()'],['../structplplot__graphics_1_1plgraphicsin.html#abd078589a26b68b5a000f2e7a7ec1cb6',1,'plplot_graphics::plgraphicsin::keysym()'],['../structPLGraphicsIn.html#ad70616982f7224261873697c93e48ee4',1,'PLGraphicsIn::keysym()']]],
   ['klass',['klass',['../structSwigPyClientData.html#a482d64908147c310a56d1541476079dc',1,'SwigPyClientData']]]
 ];
