@@ -65,6 +65,7 @@ var structPLStream =
     [ "dev_clear", "structPLStream.html#a5ffd0f763c8d12a0912ebc4355377329", null ],
     [ "dev_compression", "structPLStream.html#a0b1b2bd10b03c184910e90aac79dddce", null ],
     [ "dev_dash", "structPLStream.html#a537ff4fef08a7f0978ac8f285739b54d", null ],
+    [ "dev_data", "structPLStream.html#a64a27bd343528519bc7b9172ac9ae43b", null ],
     [ "dev_di", "structPLStream.html#ae84e24623a23d971c07e914557276808", null ],
     [ "dev_eofill", "structPLStream.html#ae43fbab5ba68a7c71f4cf5385178b2ff", null ],
     [ "dev_fastimg", "structPLStream.html#a7055c5f16dfa3de7f6c70fe69f846360", null ],
@@ -178,6 +179,8 @@ var structPLStream =
     [ "mar", "structPLStream.html#ab8ac2cfcc7c89b3cb21006ec7090a73b", null ],
     [ "mark", "structPLStream.html#a79ee5c5d824a379d4f425f2b0f59b0ce", null ],
     [ "member", "structPLStream.html#a47c3d2d47d3c0b105beb0981c5634d15", null ],
+    [ "mf_infile", "structPLStream.html#a8697ddd687cd34315ba3765b196a778d", null ],
+    [ "mf_outfile", "structPLStream.html#afbc50e220f997c43679386a043a25ec2", null ],
     [ "mindef", "structPLStream.html#a3877166126904e55715aebbcf84e6ed6", null ],
     [ "minht", "structPLStream.html#ae7f22f1bf0f3acd6c4293c40bb8ac0a6", null ],
     [ "n_polygon", "structPLStream.html#a11fa5890f9ead979aa101e5ecea4373e", null ],
