@@ -1,5 +1,3 @@
-// $Id: wingcc.c 12965 2014-01-28 20:23:52Z arjenmarkus $
-//
 //      PLplot WIN32 under GCC device driver.
 //
 // Copyright (C) 2004  Andrew Roach
@@ -78,15 +76,17 @@ PLDLLIMPEXP_DRIVER const char* plD_DEVICE_INFO_wingcc = "wingcc:Win32 (GCC):1:wi
 
 typedef struct
 {
-    PLFLT scale;                     // scaling factor to "blow up" to the "virtual" page in removing hidden lines
-    PLINT width;                     // Window width (which can change)
-    PLINT height;                    // Window Height
+    PLFLT        scale;              // scaling factor to "blow up" to the "virtual" page in removing hidden lines
+    PLINT        width;              // Window width (which can change)
+    PLINT        height;             // Window Height
 
-    PLFLT PRNT_scale;
-    PLINT PRNT_width;
-    PLINT PRNT_height;
+    PLFLT        PRNT_scale;
+    PLINT        PRNT_width;
+    PLINT        PRNT_height;
 
-    char  FT_smooth_text;
+    PLGraphicsIn gin;
+
+    char         FT_smooth_text;
 //
 // WIN32 API variables
 //
@@ -131,6 +131,7 @@ void plD_polyline_wingcc( PLStream *, short *, short *, PLINT );
 void plD_eop_wingcc( PLStream * );
 void plD_bop_wingcc( PLStream * );
 void plD_tidy_wingcc( PLStream * );
+void plD_wait_wingcc( PLStream * );
 void plD_state_wingcc( PLStream *, PLINT );
 void plD_esc_wingcc( PLStream *, PLINT, void * );
 
@@ -230,6 +231,7 @@ void plD_dispatch_init_wingcc( PLDispatchTable *pdt )
     pdt->pl_tidy     = (plD_tidy_fp) plD_tidy_wingcc;
     pdt->pl_state    = (plD_state_fp) plD_state_wingcc;
     pdt->pl_esc      = (plD_esc_fp) plD_esc_wingcc;
+    pdt->pl_wait     = (plD_wait_fp) plD_wait_wingcc;
 }
 
 static TCHAR* szWndClass = _T( "PlplotWin" );
@@ -834,68 +836,6 @@ plD_eop_wingcc( PLStream *pls )
     dev->already_erased = 2;
 
     NormalCursor();
-
-    if ( !pls->nopause )
-    {
-        dev->waiting = 1;
-        while ( GetMessage( &dev->msg, NULL, 0, 0 ) )
-        {
-            TranslateMessage( &dev->msg );
-            switch ( (int) dev->msg.message )
-            {
-            case WM_CONTEXTMENU:
-            case WM_RBUTTONDOWN:
-                TrackPopupMenu( dev->PopupMenu, TPM_CENTERALIGN | TPM_RIGHTBUTTON, LOWORD( dev->msg.lParam ),
-                    HIWORD( dev->msg.lParam ), 0, dev->hwnd, NULL );
-                break;
-
-            case WM_CHAR:
-                if ( ( (TCHAR) ( dev->msg.wParam ) == 32 ) ||
-                     ( (TCHAR) ( dev->msg.wParam ) == 13 ) )
-                {
-                    dev->waiting = 0;
-                }
-                else if ( ( (TCHAR) ( dev->msg.wParam ) == 27 ) ||
-                          ( (TCHAR) ( dev->msg.wParam ) == 'q' ) ||
-                          ( (TCHAR) ( dev->msg.wParam ) == 'Q' ) )
-                {
-                    dev->waiting = 0;
-                    PostQuitMessage( 0 );
-                }
-                break;
-
-            case WM_LBUTTONDBLCLK:
-                Debug( "WM_LBUTTONDBLCLK\t" );
-                dev->waiting = 0;
-                break;
-
-            case WM_COMMAND:
-                switch ( LOWORD( dev->msg.wParam ) )
-                {
-                case PopupPrint:
-                    Debug( "PopupPrint" );
-                    PrintPage( pls );
-                    break;
-                case PopupNextPage:
-                    Debug( "PopupNextPage" );
-                    dev->waiting = 0;
-                    break;
-                case PopupQuit:
-                    Debug( "PopupQuit" );
-                    dev->waiting = 0;
-                    PostQuitMessage( 0 );
-                    break;
-                }
-                break;
-
-            default:
-                DispatchMessage( &dev->msg );
-                break;
-            }
-            if ( dev->waiting == 0 )
-                break;
-        }
-    }
 }
 
 //--------------------------------------------------------------------------
@@ -957,11 +897,74 @@ plD_tidy_wingcc( PLStream *pls )
     }
 }
 
+void
+plD_wait_wingcc( PLStream * pls )
+{
+    wingcc_Dev *dev = (wingcc_Dev *) pls->dev;
 
+    Debug( "Wait for user input\n" );
+
+    dev->waiting = 1;
+    while ( dev->waiting == 1 && GetMessage( &dev->msg, NULL, 0, 0 ) )
+    {
+        TranslateMessage( &dev->msg );
+        switch ( (int) dev->msg.message )
+        {
+        case WM_RBUTTONDOWN:
+        case WM_CONTEXTMENU:
+            TrackPopupMenu( dev->PopupMenu, TPM_CENTERALIGN | TPM_RIGHTBUTTON, LOWORD( dev->msg.lParam ),
+                HIWORD( dev->msg.lParam ), 0, dev->hwnd, NULL );
+            break;
+
+        case WM_CHAR:
+            if ( ( (TCHAR) ( dev->msg.wParam ) == 32 ) ||
+                 ( (TCHAR) ( dev->msg.wParam ) == 13 ) )
+            {
+                dev->waiting = 0;
+            }
+            else if ( ( (TCHAR) ( dev->msg.wParam ) == 27 ) ||
+                      ( (TCHAR) ( dev->msg.wParam ) == 'q' ) ||
+                      ( (TCHAR) ( dev->msg.wParam ) == 'Q' ) )
+            {
+                dev->waiting = 0;
+                PostQuitMessage( 0 );
+            }
+            break;
+
+        case WM_LBUTTONDBLCLK:
+            Debug( "WM_LBUTTONDBLCLK\t" );
+            dev->waiting = 0;
+            break;
+
+        case WM_COMMAND:
+            switch ( LOWORD( dev->msg.wParam ) )
+            {
+            case PopupPrint:
+                Debug( "PopupPrint" );
+                PrintPage( pls );
+                break;
+            case PopupNextPage:
+                Debug( "PopupNextPage" );
+                dev->waiting = 0;
+                break;
+            case PopupQuit:
+                Debug( "PopupQuit" );
+                dev->waiting = 0;
+                PostQuitMessage( 0 );
+                break;
+            }
+            break;
+
+        default:
+            DispatchMessage( &dev->msg );
+            break;
+        }
+    }
+}
 
 
 //--------------------------------------------------------------------------
-// plD_state_png()
+// plD_state_wingcc()
 //
 // Handle change in PLStream state (color, pen width, fill attribute, etc).
 //--------------------------------------------------------------------------
@@ -989,14 +992,89 @@ plD_state_wingcc( PLStream *pls, PLINT op )
     dev->pen = CreatePen( PS_SOLID, pls->width, dev->colour );
 }
 
+//--------------------------------------------------------------------------
+// GetCursorCmd()
+//
+// Handle events connected to selecting points (modelled after xwin)
+//--------------------------------------------------------------------------
+
+static void
+GetCursorCmd( PLStream *pls, PLGraphicsIn *gin )
+{
+    wingcc_Dev *dev = (wingcc_Dev *) pls->dev;
+
+    HCURSOR    crosshair;
+    HCURSOR    previous;
+
+    plGinInit( gin );
+
+    crosshair = LoadCursor( GetModuleHandle( NULL ), IDC_CROSS );
+    previous  = SetCursor( crosshair );
+
+    while ( gin->pX < 0 )
+    {
+        GetMessage( &dev->msg, NULL, 0, 0 );
+        TranslateMessage( &dev->msg );
+        switch ( (int) dev->msg.message )
+        {
+        case WM_LBUTTONDOWN:
+            if ( dev->msg.wParam & MK_LBUTTON )
+            {
+                gin->pX = dev->msg.pt.x;
+                gin->pY = dev->msg.pt.y;
+                gin->dX = (PLFLT) gin->pX / ( dev->width - 1 );
+                gin->dY = 1.0 - (PLFLT) gin->pY / ( dev->height - 1 );
+
+                gin->button = 1; // AM: there is no macro to indicate the pressed button!
+                gin->state  = 0; // AM: is there an equivalent under Windows?
+                gin->keysym = 0x20;
+            }
+            break;
+        case WM_CHAR:
+            gin->pX = dev->msg.pt.x;
+            gin->pY = dev->msg.pt.y;
+            gin->dX = (PLFLT) gin->pX / ( dev->width - 1 );
+            gin->dY = 1.0 - (PLFLT) gin->pY / ( dev->height - 1 );
+
+            gin->button = 0;
+            gin->state  = 0;
+            gin->keysym = dev->msg.wParam;
+
+            break;
+        }
+    }
+
+    // Restore the previous cursor
+    SetCursor( previous );
+
+//    if ( GetCursorPos(&p) )
+//    {
+//        if ( ScreenToClient( dev->hwnd, &p ) )
+//        {
+//            // Fill the fields, but actually we need to run the event loop
+//            // We need to call GetMessage() in a loop. Unclear as yet to the
+//            // actual interface: key/button presses?
+//        }
+//    }
+}
+
+//--------------------------------------------------------------------------
+// plD_esc_wingcc()
+//
+// Handle PLplot escapes
+//--------------------------------------------------------------------------
+
 void
 plD_esc_wingcc( PLStream *pls, PLINT op, void *ptr )
 {
-    wingcc_Dev *dev = (wingcc_Dev *) pls->dev;
+    wingcc_Dev   *dev = (wingcc_Dev *) pls->dev;
+    PLGraphicsIn *gin = &( dev->gin );
+
 
     switch ( op )
     {
     case PLESC_GETC:
+        GetCursorCmd( pls, (PLGraphicsIn *) ptr );
         break;
 
     case PLESC_FILL:
