@@ -1,5 +1,3 @@
-// $Id: plplotP.h 12831 2013-12-09 14:35:42Z andrewross $
-//
 //  Internal (private) macros and prototypes for the PLplot package.  This
 //  header file must be included before all others, including system header
 //  files.  This file is typically needed when including driver specific
@@ -79,11 +77,7 @@
 //
 // Some of the macros set during configuration are described here.
 //
-// If HAVE_TERMIOS_H is set, we employ POSIX.1 tty terminal I/O.  One purpose
-// of this is to select character-oriented (CBREAK) i/o in the tek driver and
-// all its variants.  It is usable without this but not as powerful.  The
-// reason for using this is that some supported systems are still not
-// POSIX.1 compliant (and some may never be).
+// If HAVE_TERMIOS_H is set, we employ POSIX.1 tty terminal I/O.
 //
 // If STDC_HEADERS is defined, the system's libc is ANSI-compliant.
 // ANSI libc calls are used for: (a) setting up handlers to be called
@@ -314,7 +308,7 @@ int plsnscanf( const char *buffer, int n, const char *format, ... );
 #define LPAGE_Y     ( PIXELS_Y / VDPMM ) // virtual page length in y in mm (192)
 
 // This defines the first argument of the plRotPhy invocation that is made
-// in a number of device drivers (e.g., found in ljii.c, ljiip.c, ps.c,
+// in a number of device drivers (e.g., found in ps.c
 // and pstex.c) to rotate them "permanently" from portrait mode to non-
 // portrait mode.  ORIENTATION of 1 corresponds to seascape mode (90 deg
 // clockwise rotation from portrait).  This is the traditional value
@@ -326,12 +320,15 @@ int plsnscanf( const char *buffer, int n, const char *format, ... );
 
 // Switches for state function call.
 
-#define PLSTATE_WIDTH     1             // pen width
-#define PLSTATE_COLOR0    2             // change to color in cmap 0
-#define PLSTATE_COLOR1    3             // change to color in cmap 1
-#define PLSTATE_FILL      4             // set area fill attribute
-#define PLSTATE_CMAP0     5             // change to cmap 0
-#define PLSTATE_CMAP1     6             // change to cmap 1
+#define PLSTATE_WIDTH     1            // pen width
+#define PLSTATE_COLOR0    2            // change to color in cmap 0
+#define PLSTATE_COLOR1    3            // change to color in cmap 1
+#define PLSTATE_FILL      4            // set area fill to a standard pattern
+#define PLSTATE_CMAP0     5            // change to cmap 0
+#define PLSTATE_CMAP1     6            // change to cmap 1
+#define PLSTATE_CHR       7            // change character height
+#define PLSTATE_SYM       8            // change symbol size
+
 
 // Bit switches used in the driver interface
 
@@ -648,34 +645,61 @@ plsave_set_locale( void );
 PLDLLIMPEXP void
 plrestore_locale( char * save_lc_numeric_locale );
 
+// Writes the Hershey symbol "ch" centred at the physical coordinate (x,y).
+void
+plhrsh( PLINT ch, PLINT x, PLINT y );
+
 // where should structure definitions that must be seen by drivers and core source files, be?
 
 // structure to be used by plcore.c and anydriver.c, related to plP_text()
 
 typedef struct
 {
-    PLINT          base;           // ref point at base(1) or center(0) of text. Currently plplot only use 0
-    PLFLT          just;           // continuos justification, 0 left, 0.5 center, 1 right
-    PLFLT          *xform;         // transformation (rotation) matrix
-    PLINT          x;              // raw reference point--after any transformation
-    PLINT          y;
-    PLINT          refx;           // processed ref. point--after justification, displacement, etc, processing
-    PLINT          refy;
-    char           font_face;      // font face OPTIONALLY used for rendering hershey codes
+    // Indicates the type of text stored in the structure.  This flag
+    // is used by the plot metafiles to correctly store and then render
+    // the contents.
+    enum { PL_STRING_TEXT, PL_STRING_SYMBOL } text_type;
+
+    // Positioning settings
+    PLINT base;                    // ref point at base(1) or center(0) of text. Currently plplot only use 0
+    PLFLT just;                    // continuos justification, 0 left, 0.5 center, 1 right
+    PLFLT *xform;                  // transformation (rotation) matrix
+
+    // raw reference point--after any transformation
+    PLINT x;
+    PLINT y;
+
+    // processed ref. point--after justification, displacement, etc, processing
+    PLINT refx;
+    PLINT refy;
+
+    // font face OPTIONALLY used for rendering hershey codes
+    char  font_face;
+
     // The following 3 fields are used by the alternative text handling pathway.
+    // The alternative text handling pathway allows the driver to process
+    // each character individually for unicode font handling
     // See drivers/cairo.h for details about how this works.
-    PLUNICODE      n_fci;          // font storage for unicode font handling
-    PLUNICODE      n_char;         // character storage for unicode font handling
-    PLINT          n_ctrl_char;    // control character code storage for unicode font handling
-    PLUNICODE      unicode_char;   // an int to hold either a Hershey, ASC-II, or Unicode value for plsym calls
+    PLUNICODE n_fci;               // font storage
+    PLUNICODE n_char;              // character storage
+    PLINT     n_ctrl_char;         // control character
+
+    // Used by plsym to store a unicode character for use by plfreetype
+    PLUNICODE unicode_char;        // an int to hold either a Hershey, ASC-II, or Unicode value for plsym calls
+
+    // Used to store a processed unicode string.  Used by plsym and
+    // text rendering by the driver
     PLUNICODE      *unicode_array; // a pointer to an array of ints holding either a Hershey, ASC-II, or Unicode value for cached plsym
     unsigned short unicode_array_len;
+
+    // Non-unicode strings and unprocessed string in the unicode case
     const char     *string;        // text to draw
+    PLINT          symbol;         // plot symbol to draw
 }EscText;
 
 //
-// structure that contains driver specific information, to be used by plargs.c and anydriver.c,
-// related to plParseDrvOpts() and plHelpDrvOpts()
+// structure that contains driver specific information, to be used by
+// plargs.c and anydriver.c, related to plParseDrvOpts() and plHelpDrvOpts()
 //
 
 typedef struct
@@ -1016,7 +1040,7 @@ plP_polyline( short *x, short *y, PLINT npts );
 
 // Fill polygon
 
-void
+PLDLLIMPEXP void
 plP_fill( short *x, short *y, PLINT npts );
 
 // Render gradient
@@ -1073,6 +1097,11 @@ plP_esc( PLINT op, void *ptr );
 void
 plP_swin( PLWindow *plwin );
 
+// Wait for user input
+
+PLDLLIMPEXP void
+plP_wait( void );
+
 // Return file pointer to lib file.
 
 FILE *
@@ -1231,6 +1260,10 @@ pl_create_tempfile( char **fname );
 PLDLLIMPEXP char *
 pl_create_tempfifo( const char **p_fifoname, const char **p_dirname );
 
+// Read a meta file
+PLDLLIMPEXP void
+plreadmetafile( char *infile );
+
 #ifdef __cplusplus
 }
 #endif
