@@ -1,11 +1,9 @@
-// $Id: plargs.c 12677 2013-11-12 00:54:54Z airwin $
-//
-//  Copyright 1993, 1994, 1995
 //  Maurice LeBrun			mjl@dino.ph.utexas.edu
 //  Institute for Fusion Studies	University of Texas at Austin
 //
-//  Copyright (C) 2004  Maurice LeBrun
-//  Copyright (C) 2004  Andrew Ross
+//  Copyright (C) 1993-2004 Maurice LeBrun
+//  Copyright (C) 2004 Andrew Ross
+//  Copyright (C) 2015 Alan W. Irwin
 //
 //  This file is part of PLplot.
 //
@@ -115,10 +113,6 @@ static int  GetOptarg( const char **, int *, const char ***, int * );
 static void Help( void );
 static void Syntax( void );
 
-#ifndef PL_DEPRECATED
-int plSetOpt( const char * opt, const char *opt_arg );
-#endif
-
 // Option handlers
 
 static int opt_h( const char *, const char *, void * );
@@ -167,6 +161,9 @@ static int opt_cmap1( const char *, const char *, void * );
 static int opt_locale( const char *, const char *, void * );
 static int opt_eofill( const char *, const char *, void * );
 
+static int opt_mfo( const char *, const char *, void * );
+static int opt_mfi( const char *, const char *, void * );
+
 // Global variables
 
 static const char *program = NULL;
@@ -652,6 +649,24 @@ static PLOptionTable ploption_table[] = {
         "-drvopt option[=value][,option[=value]]*",
         "Driver specific options"
     },
+    {
+        "mfo",                  // Metafile output option
+        opt_mfo,
+        NULL,
+        NULL,
+        PL_OPT_ARG | PL_OPT_FUNC,
+        "-mfo PLplot metafile name",
+        "Write the plot to the specified PLplot metafile"
+    },
+    {
+        "mfi",                  // Metafile output option
+        opt_mfi,
+        NULL,
+        NULL,
+        PL_OPT_ARG | PL_OPT_FUNC,
+        "-mfi PLplot metafile name",
+        "Read the specified PLplot metafile"
+    },
     {
         NULL,                   // option
         NULL,                   // handler
@@ -721,6 +736,7 @@ static DrvOptCmd drv_opt = { NULL, NULL, NULL };
 
 static int       tables = 1;
 
+#ifdef PL_DEPRECATED
 //--------------------------------------------------------------------------
 // plSetOpt()
 //
@@ -739,6 +755,7 @@ plSetOpt( const char * opt, const char *opt_arg )
 {
     return ( c_plsetopt( opt, opt_arg ) );
 }
+#endif //#ifdef PL_DEPRECATED
 
 int
 c_plsetopt( const char * opt, const char *opt_arg )
@@ -860,9 +877,8 @@ int
 c_plparseopts( int *p_argc, const char **argv, PLINT mode )
 {
     const char **argsave, **argend;
-    int        i, myargc, status = 0;
+    int        i, myargc, myargcsave, status = 0;
 
-    pllib_init();
 
 // Initialize
 
@@ -888,18 +904,51 @@ c_plparseopts( int *p_argc, const char **argv, PLINT mode )
     if ( myargc == 0 )
         return 0;
 
-// Process the command line
+    // Process the command line
+
+    // Special hack to deal with -debug option before
+    // pllib_init() is called.
+    argsave    = argv;
+    myargcsave = myargc;
+    for (; myargc > 0; --myargc, ++argv )
+    {
+        // Allow for "holes" in argv list
+        if ( *argv == NULL || *argv[0] == '\0' )
+            continue;
+
+        if ( ( !mode_nodash && !strcmp( *argv, "-debug" ) ) || ( mode_nodash && !strcmp( *argv, "debug" ) ) )
+        {
+            //fprintf(stderr, "Found debug option in argv\n");
+            // Loop over all options tables, starting with the last
+            for ( i = tables - 1; i >= 0; i-- )
+            {
+                // Check option table for option
+
+                status = ParseOpt( &myargc, &argv, p_argc, &argsave,
+                    ploption_info[i].options );
+
+                if ( !status )
+                    break;
+            }
+            break;
+        }
+    }
+    // Restore pointers to condition before the above loop
+    // Although array length and content stored in those pointers
+    // is likely changed.
+    myargc = myargcsave;
+    argv   = argsave;
+
+    pllib_init();
 
     argsave = argv;
     for (; myargc > 0; --myargc, ++argv )
     {
         // Allow for "holes" in argv list
-
         if ( *argv == NULL || *argv[0] == '\0' )
             continue;
 
         // Loop over all options tables, starting with the last
-
         for ( i = tables - 1; i >= 0; i-- )
         {
             // Check option table for option
@@ -1821,14 +1870,14 @@ opt_freeaspect( const char * PL_UNUSED( opt ), const char * PL_UNUSED( opt_arg )
 //! Performs appropriate action for option "portrait":
 //! Set portrait mode.  If plsc->portrait = 1, then the orientation for certain
 //! drivers is changed by 90 deg to portrait orientation from the default
-//! landscape orientation used by PLplot while the  aspect ratio allowed to
+//! landscape orientation used by PLplot while the aspect ratio allowed to
 //! adjust using freeaspect.
 //! N.B. the driver list where this flag is honored is currently limited
-//! to ljii, ljiip, psc, ps, and pstex.  A 90 deg rotation is just not
+//! to psc, ps, and pstex.  A 90 deg rotation is just not
 //! appropriate for certain other drivers.  These drivers where portrait
 //! mode is ignored include display drivers (e.g., xwin, tk), drivers
 //! which are subequently going to be transformed to another form
-//! (e.g., meta or pbm), or drivers which are normally used for web
+//! (e.g., meta), or drivers which are normally used for web
 //! publishing (e.g., png, jpeg).  That said, the case is not entirely clear
 //! for all drivers so the list of drivers where portrait mode is honored
 //! may increase in the future. To add to the list simply copy the small
@@ -2815,3 +2864,53 @@ opt_eofill( const char * PL_UNUSED( opt ), const char * PL_UNUSED( opt_arg ), vo
     plsc->dev_eofill = 1;
     return 0;
 }
+
+//--------------------------------------------------------------------------
+// opt_mfo()
+//
+//! Sets the filename of the PLplot metafile that will be written.
+//!
+//! @param PL_UNUSED( opt ) Not used.
+//! @param opt_arg  Output PLplot metafile.
+//! @param PL_UNUSED( client_data ) Not used.
+//!
+//! returns 0.
+//!
+//--------------------------------------------------------------------------
+
+static int
+opt_mfo( const char * PL_UNUSED( opt ), const char * opt_arg, void * PL_UNUSED( client_data ) )
+{
+    if ( ( plsc->mf_outfile = (char *) malloc( (size_t) ( 1 + strlen( opt_arg ) ) * sizeof ( char ) ) ) == NULL )
+    {
+        plexit( "opt_mfo: Insufficient memory" );
+    }
+
+    strcpy( plsc->mf_outfile, opt_arg );
+    return 0;
+}
+
+//--------------------------------------------------------------------------
+// opt_mfi()
+//
+//! Sets the filename of the PLplot metafile that will be read.
+//!
+//! @param PL_UNUSED( opt ) Not used.
+//! @param opt_arg Input PLplot metafile.
+//! @param PL_UNUSED( client_data ) Not used.
+//!
+//! returns 0.
+//!
+//--------------------------------------------------------------------------
+
+static int
+opt_mfi( const char * PL_UNUSED( opt ), const char * opt_arg, void * PL_UNUSED( client_data ) )
+{
+    if ( ( plsc->mf_infile = (char *) malloc( (size_t) ( 1 + strlen( opt_arg ) ) * sizeof ( char ) ) ) == NULL )
+    {
+        plexit( "opt_mfi: Insufficient memory" );
+    }
+
+    strcpy( plsc->mf_infile, opt_arg );
+    return 0;
+}
