@@ -1,8 +1,6 @@
-// $Id: plfill.c 12008 2011-10-28 12:50:46Z andrewross $
-//
 //      Polygon pattern fill.
 //
-// Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009  Alan W. Irwin
+// Copyright (C) 2004-2015 Alan W. Irwin
 // Copyright (C) 2005, 2006, 2007, 2008, 2009  Arjen Markus
 //
 // This file is part of PLplot.
@@ -312,6 +310,7 @@ plfill_soft( short *x, short *y, PLINT n )
     PLINT  xp1, yp1, xp2, yp2, xp3, yp3;
     PLINT  k, dinc;
     PLFLT  ci, si;
+    PLINT  plbuf_write;
     double temp;
 
     buffersize = 2 * BINC;
@@ -322,6 +321,10 @@ plfill_soft( short *x, short *y, PLINT n )
         return;
     }
 
+    //do not write the hatching lines to the buffer as we have already
+    //written the fill to the buffer
+    plbuf_write       = plsc->plbuf_write;
+    plsc->plbuf_write = FALSE;
 // Loop over sets of lines in pattern
 
     for ( k = 0; k < plsc->nps; k++ )
@@ -403,6 +406,8 @@ plfill_soft( short *x, short *y, PLINT n )
             plP_draphy( xp1, yp1 );
         }
     }
+    //reinstate the buffer writing parameter and free memory
+    plsc->plbuf_write = plbuf_write;
     free( (void *) buffer );
 }
 
@@ -1919,14 +1924,15 @@ fill_intersection_polygon( PLINT recursion_depth, PLINT ifextrapolygon,
 }
 #endif
 
-// Returns a 0 status code if the two line segments A, and B defined
+// Returns a 0 status code
+// if the two line segments A, and B defined
 // by their end points (xA1, yA1, xA2, yA2, xB1, yB1, xB2, and yB2)
 // definitely (i.e., intersection point is not near the ends of either
 // of the line segments) cross each other.  Otherwise, return a status
 // code specifying the type of non-crossing (i.e., completely
-// separate, near one of the ends, parallel).  Return the actual
-// intersection (or average of the x end points and y end points for
-// the parallel, not crossed case) via the argument list pointers to
+// separate, near one of the ends, parallel).
+// Only if status = 0, return the actual
+// intersection via the argument list pointers to
 // xintersect and yintersect.
 
 int
@@ -1971,34 +1977,6 @@ notcrossed( PLINT * xintersect, PLINT * yintersect,
             status = status | PL_NEAR_PARALLEL;
         else
             status = status | PL_PARALLEL;
-        // Choice of intersect is arbitrary in this case.  Choose A1, A2,
-        // B1, or B2 (in that order) if any of them lie inside or near
-        // the other line segment.  Otherwise, choose the average point.
-        if ( ( BETW_NBCC( xA1, xB1, xB2 ) && BETW_NBCC( yA1, yB1, yB2 ) ) )
-        {
-            fxintersect = xA1;
-            fyintersect = yA1;
-        }
-        else if ( ( BETW_NBCC( xA2, xB1, xB2 ) && BETW_NBCC( yA2, yB1, yB2 ) ) )
-        {
-            fxintersect = xA2;
-            fyintersect = yA2;
-        }
-        else if ( ( BETW_NBCC( xB1, xA1, xA2 ) && BETW_NBCC( yB1, yA1, yA2 ) ) )
-        {
-            fxintersect = xB1;
-            fyintersect = yB1;
-        }
-        else if ( ( BETW_NBCC( xB2, xA1, xA2 ) && BETW_NBCC( yB2, yA1, yA2 ) ) )
-        {
-            fxintersect = xB2;
-            fyintersect = yB2;
-        }
-        else
-        {
-            fxintersect = 0.25 * ( xA1 + xA2 + xB1 + xB2 );
-            fyintersect = 0.25 * ( yA1 + yA2 + yB1 + yB2 );
-        }
     }
     else
     {
@@ -2010,30 +1988,33 @@ notcrossed( PLINT * xintersect, PLINT * yintersect,
         factor      = ( xB1A1 * yB2A1 - yB1A1 * xB2A1 ) / factor;
         fxintersect = factor * xA2A1 + xA1;
         fyintersect = factor * yA2A1 + yA1;
+        // The "redundant" x and y segment range checks (which include near the
+        // end points) are needed for the vertical and the horizontal cases.
+        if ( ( BETW_NBCC( fxintersect, xA1, xA2 ) && BETW_NBCC( fyintersect, yA1, yA2 ) ) &&
+             ( BETW_NBCC( fxintersect, xB1, xB2 ) && BETW_NBCC( fyintersect, yB1, yB2 ) ) )
+        {
+            // The intersect is close (within +/- PL_NBCC) to an end point or
+            // corresponds to a definite crossing of the two line segments.
+            // Find out which.
+            if ( fabs( fxintersect - xA1 ) <= PL_NBCC && fabs( fyintersect - yA1 ) <= PL_NBCC )
+                status = status | PL_NEAR_A1;
+            else if ( fabs( fxintersect - xA2 ) <= PL_NBCC && fabs( fyintersect - yA2 ) <= PL_NBCC )
+                status = status | PL_NEAR_A2;
+            else if ( fabs( fxintersect - xB1 ) <= PL_NBCC && fabs( fyintersect - yB1 ) <= PL_NBCC )
+                status = status | PL_NEAR_B1;
+            else if ( fabs( fxintersect - xB2 ) <= PL_NBCC && fabs( fyintersect - yB2 ) <= PL_NBCC )
+                status = status | PL_NEAR_B2;
+            // N.B. if none of the above conditions hold then status remains at
+            // zero to signal we have a definite crossing.
+        }
+        else
+            status = status | PL_NOT_CROSSED;
     }
-    // The "redundant" x and y segment range checks (which include near the
-    // end points) are needed for the vertical and the horizontal cases.
-    if ( ( BETW_NBCC( fxintersect, xA1, xA2 ) && BETW_NBCC( fyintersect, yA1, yA2 ) ) &&
-         ( BETW_NBCC( fxintersect, xB1, xB2 ) && BETW_NBCC( fyintersect, yB1, yB2 ) ) )
+    if ( !status )
     {
-        // The intersect is close (within +/- PL_NBCC) to an end point or
-        // corresponds to a definite crossing of the two line segments.
-        // Find out which.
-        if ( fabs( fxintersect - xA1 ) <= PL_NBCC && fabs( fyintersect - yA1 ) <= PL_NBCC )
-            status = status | PL_NEAR_A1;
-        else if ( fabs( fxintersect - xA2 ) <= PL_NBCC && fabs( fyintersect - yA2 ) <= PL_NBCC )
-            status = status | PL_NEAR_A2;
-        else if ( fabs( fxintersect - xB1 ) <= PL_NBCC && fabs( fyintersect - yB1 ) <= PL_NBCC )
-            status = status | PL_NEAR_B1;
-        else if ( fabs( fxintersect - xB2 ) <= PL_NBCC && fabs( fyintersect - yB2 ) <= PL_NBCC )
-            status = status | PL_NEAR_B2;
-        // N.B. if none of the above conditions hold then status remains at
-        // zero to signal we have a definite crossing.
+        *xintersect = (PLINT) fxintersect;
+        *yintersect = (PLINT) fyintersect;
     }
-    else
-        status = status | PL_NOT_CROSSED;
-    *xintersect = (PLINT) fxintersect;
-    *yintersect = (PLINT) fyintersect;
 
     return status;
 }
