@@ -1,8 +1,6 @@
-// $Id: plfreetype.c 12661 2013-11-05 16:24:11Z airwin $
-//
 // Copyright (C) 2002, 2004, 2005  Andrew Roach
 // Copyright (C) 2002  Maurice LeBrun
-// Copyright (C) 2002-2012  Alan W. Irwin
+// Copyright (C) 2002-2014 Alan W. Irwin
 // Copyright (C) 2003, 2004  Joao Cardoso
 // Copyright (C) 2003, 2004, 2005  Rafael Laboissiere
 // Copyright (C) 2004  Andrew Ross
@@ -65,9 +63,8 @@
 //
 //
 
-#if !defined ( WIN32 ) || defined ( __GNUC__ )
-  #include <unistd.h>
-#else
+#include "plConfig.h"
+#if !PL_HAVE_UNISTD_H
   #define F_OK    1
   #include <stdio.h>
 int access( char *filename, int flag )
@@ -84,6 +81,8 @@ int access( char *filename, int flag )
         return 1;
     }
 }
+#else
+  #include <unistd.h>
 #endif
 
 #define makeunixslash( b )    do { char *I; for ( I = b; *I != 0; *I++ ) if ( *I == '\\' ) *I = '/';} while ( 0 )
