@@ -1,6 +1,4 @@
-// $Id: plpage.c 11680 2011-03-27 17:57:51Z airwin $
-//
-// Copyright (C) 2004  Alan W. Irwin
+// Copyright (C) 2004-2014 Alan W. Irwin
 //
 // This file is part of PLplot.
 //
@@ -25,6 +23,7 @@
 //!
 
 #include "plplotP.h"
+#include "drivers.h"
 
 //--------------------------------------------------------------------------
 //! Advance to subpage "page" or to the next page if "page" = 0.
@@ -48,6 +47,7 @@ c_pladv( PLINT page )
         if ( plsc->cursub >= plsc->nsubx * plsc->nsuby )
         {
             plP_eop();
+            plP_wait();
             plP_bop();
             plsc->cursub = 1;
         }
@@ -84,10 +84,10 @@ c_plclear( void )
         short x[5], y[5];
         int   ocolor = plsc->icol0;
 
-        x[0] = x[3] = x[4] = plsc->sppxmi;
-        x[1] = x[2] = plsc->sppxma;
-        y[0] = y[1] = y[4] = plsc->sppymi;
-        y[2] = y[3] = plsc->sppyma;
+        x[0] = x[3] = x[4] = (short) plsc->sppxmi;
+        x[1] = x[2] = (short) plsc->sppxma;
+        y[0] = y[1] = y[4] = (short) plsc->sppymi;
+        y[2] = y[3] = (short) plsc->sppyma;
         plcol0( 0 );
         plP_fill( x, y, 5 );
         plcol0( ocolor );
@@ -108,6 +108,7 @@ c_pleop( void )
 
     plsc->cursub = plsc->nsubx * plsc->nsuby;
     plP_eop();
+    plP_wait();
 }
 
 //--------------------------------------------------------------------------
@@ -157,13 +158,13 @@ plP_subpInit( void )
               ( plsc->phyyma - plsc->phyymi ) / plsc->ypmm ) / 200.0;
 
     // Take account of scaling caused by change of orientation
-    if ( plsc->difilt && PLDI_ORI )
+    if ( plsc->difilt & PLDI_ORI )
     {
         theta = 0.5 * M_PI * plsc->diorot;
         rat   = ( ( plsc->phyxma - plsc->phyxmi ) / plsc->xpmm ) /
                 ( ( plsc->phyyma - plsc->phyymi ) / plsc->ypmm );
         rat    = MAX( rat, 1.0 / rat );
-        rat    = fabs( cos( theta ) ) + rat*fabs( sin( theta ) );
+        rat    = fabs( cos( theta ) ) + rat * fabs( sin( theta ) );
         scale /= rat;
     }
 
@@ -175,10 +176,10 @@ plP_subpInit( void )
     size_maj = 3.0;
     size_min = 1.5;
 
-    plsc->chrdef = plsc->chrht = size_chr * scale;
-    plsc->symdef = plsc->symht = size_sym * scale;
-    plsc->majdef = plsc->majht = size_maj * scale;
-    plsc->mindef = plsc->minht = size_min * scale;
+    plschr( size_chr * scale, 1.0 );
+    plssym( size_sym * scale, 1.0 );
+    plsmaj( size_maj * scale, 1.0 );
+    plsmin( size_min * scale, 1.0 );
 }
 
 //--------------------------------------------------------------------------
@@ -203,6 +204,9 @@ plP_setsub( void )
     plsc->sppyma = plP_dcpcy( plsc->spdyma );
 
     plP_sclp( plsc->sppxmi, plsc->sppxma, plsc->sppymi, plsc->sppyma );
+
+    if ( plsc->plbuf_write )
+        plbuf_setsub( plsc );
 }
 
 //--------------------------------------------------------------------------
