@@ -1,9 +1,7 @@
-// $Id: plsdef.c 11973 2011-10-17 21:16:39Z andrewross $
-//
 //      Routines to set various plplot parameters, such as char height,
 //      symbol size, tick length, line and fill patterns, etc.
 //
-// Copyright (C) 2004  Alan W. Irwin
+// Copyright (C) 2004-2014 Alan W. Irwin
 //
 // This file is part of PLplot.
 //
@@ -108,6 +106,7 @@ static struct line
 
 // Fill pattern defaults
 
+#define NPATTERNS    8
 static struct pattern
 {
     PLINT nlines;               // Number of lines in pattern (1 or 2)
@@ -206,6 +205,9 @@ c_plschr( PLFLT def, PLFLT scale )
         plsc->chrdef = def;
 
     plsc->chrht = scale * plsc->chrdef;
+
+    if ( plsc->level > 0 )
+        plP_state( PLSTATE_CHR );
 }
 
 //--------------------------------------------------------------------------
@@ -251,6 +253,9 @@ c_plssym( PLFLT def, PLFLT scale )
         plsc->symdef = def;
 
     plsc->symht = scale * plsc->symdef;
+
+    if ( plsc->level > 0 )
+        plP_state( PLSTATE_SYM );
 }
 
 //--------------------------------------------------------------------------
@@ -307,6 +312,7 @@ c_plpat( PLINT nlin, const PLINT *inc, const PLINT *del )
             return;
         }
     }
+    plsc->patt = NPATTERNS;
     spat( inc, del, nlin );
 }
 
@@ -325,7 +331,7 @@ c_plpsty( PLINT patt )
         plabort( "plpsty: Please call plinit first" );
         return;
     }
-    if ( patt > 8 )
+    if ( patt > NPATTERNS || patt < 0 )
     {
         plabort( "plpsty: Invalid pattern" );
         return;
@@ -333,17 +339,14 @@ c_plpsty( PLINT patt )
     if ( patt != plsc->patt )
     {
         plsc->patt = patt;
-
-        if ( plsc->level > 0 )
-        {
-            plP_state( PLSTATE_FILL );
-        }
     }
     if ( patt > 0 )
     {
         spat( &pattern[patt - 1].inc[0], &pattern[patt - 1].del[0],
             pattern[patt - 1].nlines );
     }
+    else
+        spat( NULL, NULL, 0 );
 }
 
 //--------------------------------------------------------------------------
@@ -363,4 +366,7 @@ spat( const PLINT inc[], const PLINT del[], PLINT nlin )
         plsc->inclin[i] = inc[i];
         plsc->delta[i]  = del[i];
     }
+
+    if ( plsc->level > 0 )
+        plP_state( PLSTATE_FILL );
 }
